(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    922640,      17118]
NotebookOptionsPosition[    907356,      16601]
NotebookOutlinePosition[    907877,      16623]
CellTagsIndexPosition[    907789,      16618]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["SpinThreeHalfDynamics", "Title",
 CellChangeTimes->{{3.6304085343957233`*^9, 3.6304085393113747`*^9}}],

Cell["\<\
This notebook simulates the effect of strong, weak, and amplitude-modulated \
rf pulses on an isolated spin-3/2 system experiencing a small quadrupole \
interaction. \
\>", "Text",
 CellChangeTimes->{{3.6304085428779583`*^9, 3.630408578744969*^9}}],

Cell[CellGroupData[{

Cell["initialisations", "Chapter",
 CellChangeTimes->{{3.630408584989607*^9, 3.630408599142152*^9}}],

Cell[CellGroupData[{

Cell["load SpinDynamica", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.630408601843251*^9, 3.63040860644421*^9}}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SpinDynamica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.619787875844488*^9, 3.619787896637553*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["set the spin system", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.630408601843251*^9, 3.6304086139256907`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetSpinSystem", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"3", "/", "2"}]}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6197879014128313`*^9, 3.6197879084323673`*^9}, 
   3.619875382411748*^9, 3.6301362503049726`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetSpinSystem", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the spin system has been set to \[NoBreak]\\!\\({\\({1, \
3\\/2}\\)}\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.619787909041266*^9, 3.619875388125195*^9, 
  3.619933044160872*^9, 3.630134312150526*^9, 3.6301356043026047`*^9, 
  3.6301358206806183`*^9, 3.6301362547420883`*^9, 3.6301589576748347`*^9, 
  3.630164096266466*^9, 3.630168259184057*^9, 3.630169109166678*^9, 
  3.6301691569258375`*^9, 3.630215920427802*^9, 3.630221657534582*^9, 
  3.630222363994841*^9, 3.630223499521574*^9, 3.6302246718995*^9, 
  3.6302999457012167`*^9, 3.63039507055128*^9, 3.630397151630144*^9, 
  3.630397247655137*^9, 3.630401271163642*^9, 3.630408632787321*^9, 
  3.630408662872787*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["set the basis states", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.630408601843251*^9, 3.630408622790959*^9}}],

Cell["The default Zeeman basis has labels {1,2,3,4} for the states", "Text",
 CellChangeTimes->{{3.630397251603724*^9, 3.630397266768981*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BasisKets", "[", "]"}]], "Input",
 CellChangeTimes->{{3.630397269137018*^9, 3.6303972716305923`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["1", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{"\[LeftBracketingBar]", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"-", 
       FractionBox["3", "2"]}],
      DisplayForm], "\[RightAngleBracket]"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.6303972723954782`*^9, 3.6304012711810293`*^9, 
  3.63040866289673*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ket", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.6303972855023603`*^9, 3.63039728640246*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[LeftBracketingBar]", 
   TagBox[
    FractionBox["3", "2"],
    DisplayForm], 
   TagBox[
    RowBox[{"+", 
     FractionBox["3", "2"]}],
    DisplayForm], "\[RightAngleBracket]"}],
  DisplayForm]], "Output",
 CellChangeTimes->{3.630397286882691*^9, 3.630401271218565*^9, 
  3.630408662929715*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ket", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.6303972925887613`*^9, 3.630397293445421*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[LeftBracketingBar]", 
   TagBox[
    FractionBox["3", "2"],
    DisplayForm], 
   TagBox[
    RowBox[{"-", 
     FractionBox["3", "2"]}],
    DisplayForm], "\[RightAngleBracket]"}],
  DisplayForm]], "Output",
 CellChangeTimes->{3.630397293861129*^9, 3.6304012712530413`*^9, 
  3.6304086629631147`*^9}]
}, Open  ]],

Cell["\<\
It\[CloseCurlyQuote]s a bit more convenient to use the M values as labels for \
the states. This can be done as follows\
\>", "Text",
 CellChangeTimes->{{3.630395532249344*^9, 3.63039554202556*^9}, {
  3.6303973109285583`*^9, 3.630397328568652*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetBasis", "[", 
  RowBox[{"ZeemanBasis", "[", 
   RowBox[{"BasisLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "/", "2"}], ",", 
      RowBox[{"1", "/", "2"}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], ",", 
      RowBox[{
       RowBox[{"-", "3"}], "/", "2"}]}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.630395091718814*^9, 3.630395144766636*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the state basis has been set to \
\[NoBreak]\\!\\(ZeemanBasis[\\(\\(\\(\\({\\({1, 3\\/2}\\)}\\)\\), \
\\(\\(BasisLabels \[Rule] \\(\\({3\\/2, 1\\/2, \
\\(\\(-\\(\\(1\\/2\\)\\)\\)\\), \
\\(\\(-\\(\\(3\\/2\\)\\)\\)\\)}\\)\\)\\)\\)\\)\\)]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{3.63039511516256*^9, 3.630395145501739*^9, 
  3.630397205650641*^9, 3.630397333503098*^9, 3.630401271366805*^9, 
  3.6304086630772343`*^9}]
}, Open  ]],

Cell["\<\
The M value may now be used directly to access the Basis kets and bras. This \
is used in some calculations below.\
\>", "Text",
 CellChangeTimes->{{3.630408668671053*^9, 3.630408685445868*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ket", "[", 
  RowBox[{"3", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.630395078814641*^9, 3.6303950802776413`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[LeftBracketingBar]", 
   TagBox[
    FractionBox["3", "2"],
    DisplayForm], 
   TagBox[
    RowBox[{"+", 
     FractionBox["3", "2"]}],
    DisplayForm], "\[RightAngleBracket]"}],
  DisplayForm]], "Output",
 CellChangeTimes->{3.6303950808197117`*^9, 3.630395149008374*^9, 
  3.630397337773773*^9, 3.630401271403212*^9, 3.630408663098839*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Bra", "[", 
  RowBox[{
   RowBox[{"-", "1"}], "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.6304086890680523`*^9, 3.630408691139009*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"<", 
   TagBox[
    FractionBox["3", "2"],
    DisplayForm], 
   TagBox[
    RowBox[{"-", 
     FractionBox["1", "2"]}],
    DisplayForm], "|"}],
  DisplayForm]], "Output",
 CellChangeTimes->{3.6304086916465607`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["explore some operators", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.630408601843251*^9, 3.630408622790959*^9}, {
   3.630408723305243*^9, 3.630408729795727*^9}, {3.630408781279407*^9, 
   3.6304087830000887`*^9}, {3.630408910504702*^9, 3.630408914868578*^9}}],

Cell[CellGroupData[{

Cell["population operators", "Subsection",
 CellChangeTimes->{{3.6304089197740088`*^9, 3.630408922597739*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PopulationOperator", "[", 
  RowBox[{"3", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.6304088646810303`*^9, 3.630408866694098*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   RowBox[{"\[LeftBracketingBar]", 
    TagBox[
     FractionBox["3", "2"],
     DisplayForm], 
    TagBox[
     RowBox[{"+", 
      FractionBox["3", "2"]}],
     DisplayForm], "\[RightAngleBracket]"}],
   DisplayForm], ".", 
  RowBox[{"(", 
   TagBox[
    RowBox[{"<", 
     TagBox[
      FractionBox["3", "2"],
      DisplayForm], 
     TagBox[
      RowBox[{"+", 
       FractionBox["3", "2"]}],
      DisplayForm], "|"}],
    DisplayForm], ")"}]}]], "Output",
 CellChangeTimes->{3.630408867098721*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"PopulationOperator", "[", 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630408697393071*^9, 3.63040871152596*^9}, {
   3.630408755364497*^9, 3.630408788558239*^9}, 3.630408877373508*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "1", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {1, {{0, 0, 0, 1, 1}, {{3}}}, {1}}]]]]], "Output",
 CellChangeTimes->{
  3.630408704876278*^9, {3.6304087616137247`*^9, 3.630408789013051*^9}, 
   3.6304088780316057`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["coherence operators", "Subsection",
 CellChangeTimes->{{3.6304089197740088`*^9, 3.630408929348167*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"CoherenceOperator", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], ",", 
      RowBox[{"1", "/", "2"}]}], "}"}], "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630408697393071*^9, 3.63040871152596*^9}, {
  3.630408755364497*^9, 3.630408788558239*^9}, {3.630408877373508*^9, 
  3.6304088936054*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "1", "0", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {1, {{0, 0, 0, 1, 1}, {{2}}}, {1}}]]]]], "Output",
 CellChangeTimes->{
  3.630408704876278*^9, {3.6304087616137247`*^9, 3.630408789013051*^9}, {
   3.6304088780316057`*^9, 3.630408894298658*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["single-transition operators", "Subsection",
 CellChangeTimes->{{3.6304089197740088`*^9, 3.630408941757689*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "SingleTransitionOperator"}]], "Input",
 CellChangeTimes->{3.63040895245827*^9}],

Cell[BoxData[
 StyleBox["\<\"SingleTransitionOperator[{r,s}, \[Mu]] defines a single \
transition operator within the current basis. Allowed values of \[Mu] are \
\\\"x\\\", \\\"y\\\", \\\"z\\\", \\\"+\\\",\\\"-\\\". The state identifiers \
{r,s} must be members of the BasisLabels for the current basis. The most \
general form is SingleTransitionOperator[{{r,s},basis}, \[Mu]] which \
constructs a single transition operator for kets within any basis. \\n\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6304089530112753`*^9},
 CellTags->"Info3630408952-7254327"]
}, Closed]],

Cell["central transition:", "Text",
 CellChangeTimes->{{3.6304089744855947`*^9, 3.6304089769947577`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"SingleTransitionOperator", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}]}], "}"}], ",", "\"\<x\>\""}], "]"}], "]"}], "//",
   "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630408697393071*^9, 3.63040871152596*^9}, {
  3.630408755364497*^9, 3.630408788558239*^9}, {3.630408877373508*^9, 
  3.6304088936054*^9}, {3.630408944880066*^9, 3.630408959511806*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", 
      FractionBox["1", "2"], "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 0, 1, 2, 2}, {{3}, {2}}}, {
      Rational[1, 2], Rational[1, 2]}}]]]]], "Output",
 CellChangeTimes->{
  3.630408704876278*^9, {3.6304087616137247`*^9, 3.630408789013051*^9}, {
   3.6304088780316057`*^9, 3.630408894298658*^9}, 3.630408960277371*^9}]
}, Open  ]],

Cell["a satellite transition:", "Text",
 CellChangeTimes->{{3.6304089744855947`*^9, 3.630409003152216*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"SingleTransitionOperator", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], "/", "2"}], ",", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", "\"\<x\>\""}], "]"}], 
   "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630408697393071*^9, 3.63040871152596*^9}, {
  3.630408755364497*^9, 3.630408788558239*^9}, {3.630408877373508*^9, 
  3.6304088936054*^9}, {3.630408944880066*^9, 3.630408959511806*^9}, {
  3.630408993196299*^9, 3.630408997269343*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "0", "0"},
     {"0", "0", "0", "0"},
     {"0", "0", "0", 
      FractionBox["1", "2"]},
     {"0", "0", 
      FractionBox["1", "2"], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 0, 0, 1, 2}, {{4}, {3}}}, {
      Rational[1, 2], Rational[1, 2]}}]]]]], "Output",
 CellChangeTimes->{
  3.630408704876278*^9, {3.6304087616137247`*^9, 3.630408789013051*^9}, {
   3.6304088780316057`*^9, 3.630408894298658*^9}, 3.630408960277371*^9, {
   3.63040899417726*^9, 3.63040899776891*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["set the quadrupolar Hamiltonian", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.630408601843251*^9, 3.6304086528638372`*^9}}],

Cell["Set up the quadrupolar Hamiltonian", "Text",
 CellChangeTimes->{{3.630397345242763*^9, 3.6303973534435177`*^9}, {
  3.6304090455568943`*^9, 3.6304090461182737`*^9}}],

Cell[BoxData[
 RowBox[{"HQ", ":=", 
  RowBox[{"\[Omega]Q", "*", 
   RowBox[{"Sqrt", "[", 
    RowBox[{"2", "/", "3"}], "]"}], 
   RowBox[{"opT", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6197879174446583`*^9, 3.619787949542801*^9}, {
   3.6197880058715343`*^9, 3.6197881376597023`*^9}, 3.6304090493075933`*^9}],

Cell[CellGroupData[{

Cell[BoxData["HQ"], "Input",
 CellChangeTimes->{
  3.619787946062029*^9, {3.6304090540236893`*^9, 3.6304090547016697`*^9}}],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   FractionBox["2", "3"]], " ", "\[Omega]Q", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       TagBox[
        SubsuperscriptBox["I", "1", "-"],
        DisplayForm], ".", 
       TagBox[
        SubsuperscriptBox["I", "1", "+"],
        DisplayForm]}], 
      RowBox[{"2", " ", 
       SqrtBox["6"]}]]}], "-", 
    FractionBox[
     RowBox[{
      TagBox[
       SubsuperscriptBox["I", "1", "+"],
       DisplayForm], ".", 
      TagBox[
       SubsuperscriptBox["I", "1", "-"],
       DisplayForm]}], 
     RowBox[{"2", " ", 
      SqrtBox["6"]}]], "+", 
    RowBox[{
     SqrtBox[
      FractionBox["2", "3"]], " ", 
     RowBox[{
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "z"}]],
       DisplayForm], ".", 
      TagBox[
       SubscriptBox["I", 
        RowBox[{"1", "z"}]],
       DisplayForm]}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.6197879465954933`*^9, 3.61978795235201*^9}, 
   3.619875391274548*^9, 3.619933044309251*^9, 3.6301343179195967`*^9, 
   3.6301356129947643`*^9, 3.630136265947289*^9, 3.6301589621009636`*^9, 
   3.6301640963905535`*^9, 3.6301691569518557`*^9, 3.6302159265481277`*^9, 
   3.6302216576537066`*^9, 3.630222364115945*^9, 3.6302234996436787`*^9, 
   3.6302246719165115`*^9, 3.6302999459784946`*^9, 3.630395070719244*^9, 
   3.6303971517938013`*^9, {3.6303973585765142`*^9, 3.630397365284306*^9}, 
   3.630401271441039*^9, {3.6304090391190968`*^9, 3.630409055312397*^9}, 
   3.6304091050880833`*^9}]
}, Open  ]],

Cell["set the default quadrupolar coupling to 100Hz", "Text",
 CellChangeTimes->{{3.630409072433681*^9, 3.630409080579082*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]Q", "=", 
  RowBox[{"2", "\[Pi]", " ", "100"}]}]], "Input",
 CellChangeTimes->{{3.6304090653678093`*^9, 3.630409070015093*^9}}],

Cell[BoxData[
 RowBox[{"200", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.630409105108975*^9}]
}, Open  ]],

Cell["simulate the spectrum", "Text",
 CellChangeTimes->{{3.630409072433681*^9, 3.630409095587438*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "@", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
       "}"}], ",", "HQ"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
  3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
  3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
  3.630409100880068*^9, 3.630409101449707*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"SetOperatorBasis", "::", "set"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"the operator basis has been set to \
\[NoBreak]\\!\\(ShiftAndZOperatorBasis[\\(\\(\\(\\({\\({1, 3\\/2}\\)}\\)\\), \
\\(\\(Sorted \[Rule] CoherenceOrder\\)\\)\\)\\)]\\)\[NoBreak].\"\>"}]], \
"Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303973588441277`*^9, 3.6303973691847*^9}, 3.630401271603232*^9, 
   3.630409108977874*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303973588441277`*^9, 3.6303973691847*^9}, 3.630401271603232*^9, 
   3.630409109128414*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303973588441277`*^9, 3.6303973691847*^9}, 3.630401271603232*^9, 
   3.630409109241473*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVXWdYFEnXbXPWwYhiGLNiGiOIqBdETIgjSaI0OeOQg4Re02IeFROmURFR
Uccc0WtOuI4Z88gaMI8ZxfDVbtW71Z9/fO5zurrqND3d1VX3ntM+cIpLSFWB
/KstCP/+T/6prLNRUKe8zZt5d9g/sagisWJxduXxkmP/xNpuJBbwwVaGo5LE
+MeGEoabzEmc37T4IsOVZiReUT4ji+HqOiS+VTn/O8OlKiTOq9PRjOH6b1ko
xB13sZlFceN7En/fnDLjGMUVL0ncLabhHIZDGYk71cooLaa45i6Jd906/YLh
umtZKBW+6NqA4YaLWYjqxelef1JcOEXw2dq4DkcprjpCcIvKAXcYLu4h+PdD
482PMP7bSHyv7/fwHMZ/I4ltdDvfHmL8V5H+s9pcrT2b8c8l8aiKnE0HGf95
JH4QdeIgw6UZJG5lumB7gPHPIOe7tPh66hzGP5Hgz3sG7N3H+MeQ+LpBMWYu
4x9Cjs++MKT+Xsbfj+BWvad3n8f4u5O4rttIh92M//gshGZZA1vNZ/wdCV50
KcxXz/gPy0LDKf/+FgsY/0FZaDRfO9dtB+PfOwtVhuGzey5k/LuQ6zVk0/Ke
RYx/2ywUd3o5OGsZ/xYktu8U92QL498oCzVnDsZLixj/WuT8M09XTt3M+P/O
RCHHpuOpxYz/10zUzVrc8mM+42/KRMXhhSHNcxn/8kwU137fOmYD42/MROOQ
YWPTlzL+pZko2Z9ZkL2O8Tdkosl8Y9nbZYz/hUyEgiYbclcz/icyUWn/CRJX
MP6HSLzQB3NWMv67yPk22afWzWP8t5D+qwad8lnG+K/PRE12xupdqxj/PHL+
RbbTGyxh/BeT4ydMORmxhvGfQ3Ab+1trFjL+0zLRIF383W8d459O+NQ1W1R/
HuOfkIkr1rSParCe8Y8i46k1Y5ZXDuMfRI7v+87i2wbG3+ef8e38c8YMxt81
E8tbL7f8ks/4O2WiyudO0HyJ8XfIRO2mCH31zYy/LWnvl1qekMH4D8hENRSc
67SF8e9Jxh/Y/bFVKuPfibRfmTXXYxvj34acP2dbizsJjH+zTMTLLc3ztjP+
Dcj579xxnTSF8a+RiTl7ls95t5Px/5mB0pJ8n92RjP+XDDR1b1pl0m7G/20G
6qrW/fgihPF/loGq+VvzDHsZ/4cEd1Tc/yky/rcyENenpfgeYPyvZKDYpvjW
Gx/G/xyJm2w++P0Q43+c9F+l0fpDHoz/gQzUbg6Sth1l/HeS4y9/+iJOZPw3
k+OV797HHmf8daS/lo6L/x7H+K/IQGXq6r4jTzL+WoLPOmxp58j452Sg0f5W
cO8zjL+UgaB4nJQGjH8aif077rY8z/jHkf6at+g6z4bxjyB4nx52NpcY/4AM
FMKz36UOYPy9yPHPDtv4/cX4uxD829fM4b0Z/7EkHnTx/JKrjL89iSVF9qOu
jL8NiXdIzR/eYPz7kbji92rP9oy/JYnRRm1byvh3JPHPldlbWzH+FiTWLdy4
4x7j34TE+hElN5ow/vVIvNtj+MBHjH81EqtedL5dn/H/MZWMZ7uroYzx/0Ti
46aeu2ow/q+nooQ/zaRnjP8Tgv/RJzvw1yXK/z7BddW2O7xk/G+S+Pj9Ay+/
UFx1eSpirxuebd8y/mcI/mvGlDHvKK4tnoqi2ZOxDT4w/vvI+Z//GJL1nOKm
7aR9YMPDZl8Y/wLSfrSrPucRxdVrp6LxzqqHPb4z/svI8TanfMNvU1y/YCrC
hzEffH4x/rNIe/9Nf7W+QnFFNjm+yEW1oeo9yj+F9P9W1G46S3HNFNLeNfHm
r5oU14UR/J5P96rHGH9/gk/91i6+HsUFT4KrX7Xpt4/xVxPc/cSEH40oLo4m
+Cz7dwOKGH8g/fceXbCmKcXRmuCRgRZ1NzL+KtJ+hj7UoyXFld0JPrBWm10r
Gf/2pP2XSze7tKW41JLg35dFddcy/mZTUbugk02jjhQ31vnn/A2nxs9i/KtO
ReWpmvcbdWP8v6ejlPPmyNwMxv9DOqL33BrdezH+L9NRsOi0KjGe8S8j8Z71
VX36Mf73SJz+44+e4Yz/dRLPbNW+wIrxv0TiSzVv7fZj/E+R/p7v1tcdyvgf
IfHnqt9qujL+e0gstas2257xLyLt71wY3W00459PYsk8uv1oxn81iesOatd8
KOOfS+JFIXY3xjP+80hcvf61K30Z/5kkJjfvelfGP5PEa4273bow/kkk7rpn
8Rwvxj+GxAOERvmtGP8QEpdVPbPAn/GfTOJ81z7FDRl/DzL+j/6GHSGMvzPB
24z0XFeV8XdMR2i8sdmrKMZ/GDn+6MYLY75cpPwHpaOYWaNiRDzj34ccf3rW
sSMvKK7uSv4+Q1QPDqUy/u1I+/Q+MZ/uU1zfIh11D8f1Gp/N+DdKR2Xsi5of
r1BcUTsdFeMVrr9mMv4CwV1eHdh/kuKaijQUp908cnke429KQ8WkgZuH7aO4
oTwNU+/k3z6yhPF/nIbqOlO+zN5McdWdNMxZM7blhTzG/2oa6nudPrF8JcW1
F9JQCg3/8nk9438iDSuMx9uFzWX8D6Xha2XOc/stjP/uNNRadm3/NYPx35qG
K0L6hOv1jP+GNDS0v2ZwjGX889Kw9cePX4YdZPwXk/aNp/d392f856bh6pHa
Zu+OM/7T01CZWzyqvZrxn5qGpTHfRp84x/gnkPHXX1VjKzD+UWR8E5Na7r/C
+AcT/nlrJ79VMf6+aVg4ZVfjv24z/m5pKCybNfSNkvF3ItfX+t6pOkbG3yEN
IafNrE0Kxt+WxI4Hj0eUM/4DSXy6drPmAuPfKw2xOa5+a2L8O5Pz+y09PvTd
Bcq/TRoaJw/6vOIb49+M4L1nuFo8pLiiYRpqAhzDIqrep/xrEv54bdn2Eopr
fqWivk67pWI9iuu+pKIxevqoj4cpbnhL4o6KztlNKS48T0XVg0CLV4UUVz1K
Rd2dwhNn2lBcvJ2Kyu+Xji9ZRnHtlVQU1t1qObArxfEcOd/AiDuvplPcdJwc
f63G48sqiisPpiL0/VTtg4bian0qioNHXNHaUFwqTEXp0Yer+X6Mv47EByav
z3KguHFFKuLsuJKqYxn/RWR8lo1arnBm/GeT8Yw7Gl93EOP/B8Gbm/984Mn4
pxHcponN4faMfxwZ374pLScGMf6RqVixaPJ8RQPGPzAV1c5hwz/EMP7e/4z/
YUm9ivOUvwsZ/44bI0+mMv5jCT789vitZRQ32ZPr8dS2zsnpjP8Qwsc01Ptl
CcXV/cnxVatEf1jA+Pcg/O74qi7up7i+I4kD5nm45TH+FmT8R1KrjtZRXNGU
jH/QjAPlmxj/+gQv0XwJmE1xTXXS/vC36fpdjP+PFMRRPp2bx1Pc8CkF1d5r
DhQVM/5vUlA40HZVoDfFVU9TUAz45PbwAuP/IAWhoqbHSHvG/2YKKjO1IY63
GP/LKSiZezge7c74nyH9xY/5/rSM8T9Gzr/96vgzCsZ/P4mvpvY49o7x30Hi
a2OHT/56jvIvIPFk65aGH4z/WhI/bv9wxgOKK5aT2GbDq9Z1H1D+C0l8/syD
QacorvmTxIlNr29qQXFdNomVvR/HFVLckEJiMbl2dGeKC5oU3N5sQnr/+RRX
haegv/UflzX9KS6KKXhPM7t7WhzFtZ4pWL9FvZh9dhRHdQrW1DXxA3eKm0an
4GB0HzJETXGlXQr+ivXTzLKmuHpwCkYf8V9WzZ/iUt8UXPElettoC8a/ewq+
/m79rFEsxY3tSX/eA+1n/DxL+bdKweSBPmsCMhn/xinoVPDMddAjimvqpmBw
XI3B3+cx/lXJ39N+0EsfpLjhezJqMlbZ3VvN+H9MxvNl6yre6yiuepWMpW51
xtXczvj/nYzdeq3z+SxRXHsvGcUNlp8zihn/68mob2y8HShS3HQpGff+Meg1
/MX4n05GrXdYS6vhFFcfTcamn/u8cH3E+O9NRsX7Xbtj21BcX5SMB9d57z5g
Yvzzk1FKuWhRs/IM5b+G9P97r0Vs1YeU/1LS3s5917fbFNfMJ+M9m1IrrSnF
dTMJX6dFe0bupbghMxmtm+WF3u1CcSE5GVeMmzDy2UKKq2KT0TjOd3DuYIqL
oeT8Afcib0dSXDuZ4LVLFxY6URw9ktEQ8qB2s5EUNzmT69l/+ZyWIsWVo8j4
i7r/ndeW4urhyahr0tfnRQLFJSvSXvXnquCvpyn/PslYsfWtQ6scihu7kv4q
g/UxVyiuUCaj59jkNTtWM/7myQiJ06fuKqC4RkGu382sy4W7GP/ayYiJ81Q9
MiluEMj1GzR3Yr1zjP+3JIQaq+/ddKG46n0S5jTYcbj0PuP/IgnR54B/UVeK
ax8noWKbx84mHxn/OwTf1C9pS+Upyv9qEta26fr6WJ1HlP/FJNRWq1Z47i+K
q08mYbeyGw4PlBSXDiehMPyne5X1FNfvTkJTYONNcdYUN24leKffRep4iis2
JqHu8EyzbDXFYRXpP6Hqlp32FNcsScKKehcKa0dQXDc3CY3eLRubN6a4YXoS
GnSp+WbTKC5kkPOVTEyfbjxJ+ScmYeESJ+81qyguRpPx2GQNebWd4trgJCy1
sRu6cx/F0TcJpeK/E0enU9zkloQlrS4/HGtg/McnoXnMpdq5IymuHknGs7eL
KeEV4z+UjDfu08qzjSiuH5iEA06VtF9ezUj590pC69BnOaWlJyj/LknYOPvL
s2NmFIe2Saj5qHx/QkdxTfMk7N33rWt/JcV1DUn7ft0K0sMobqiZhN4trv75
pTfFhd+JqA2IVH3vSXHV10R03zluX91hFBffJaKx6s8LVu+R8n+eiFVeJnSM
H09xfJSIJdf6+FjupbjpdiLOmLOjdx8/iisNiVjR8EPy+SSKq88nYvES3RiH
GIpLmIhCaa1JtQdRXH8wEcuUvX7tyWT89YkIFq30x18cp/y3JKLHKumttIDx
X5+InurpL3OCKa5ZmYgNrCxvbV/H+C9KRE3XITke949R/rMTcaafw9yhuxj/
aYTfV+dHZhMprkpPxJ0vin73O8X4xyfi6I3NwzaeLKb8IxOxcJ+z/aKbjH9g
IhoKS7d/UFHc5J2IBfMzJJ9yxt+VXN/4++OfrTpK+Y9LxKKP/rWWVjL+I8j4
4sseB1WjuH5IIg5YOnWkXaPHlH//RNSdraiYEHaE8u+ZiPMujCgJ6khx6JRI
fp9r6yw4d5jyb02u/9vLEwVriuuakut3plew0InihvqJ2C1oxe5W4yku1EhE
qe8fnXIyDlH+PxNw9Kzoj/sDKS5+TkDIPNGhxtWDlP+bBKxd4DviTirF8WkC
CuXuf7u3p7jpQQKKRY9+zlxIceUt0r7K45mTYg5Q/n8loCms/vYTBRSXziag
FD90z9O9+yn/YwQ/9aXeomOM/35yfu/wOXe/7qP8dyagbmTfOt9uMf6bSfvu
o+Y1HERxzTqCP0u88Osd47+ctO/Zd5bnlL2U/8IEVOXHb91cp4zyzyH4455T
52/cQ/lLCajteXXkt44UF1MJbnFmrnRtN+WvSUC85JX4bRjFMZzgFd73q/7Y
RfmLZDxRnhN3eFNc6UXwOca0v9tRXD2RjO9I32FtUygujSG47w3bd0P1lL9d
Ahr/7v9sQi7FjYMJPrHE7fG2HZR/vwRUX91kP3Y3xcGS4BetNvtfKaL8OySg
8mnLdU2vUlzXiuC7twU/ebqV8m9Mxv+69tr9Jsa/HsFta9f+/LaQ8q9Gxv/g
8FBrs78p/8p4Mp+6MMLsZQHl/zGePG+nP1jfj+L4iuAVfbbvvpVP+f9N4vOe
I364UVx5n8QHtwc47d1A+d8gcf9L69WpFJdKSIwdC8ZO01H+p0n8KWRt4WqK
G4+SWCj/1UlaTfnvI/FeybPhSYrD9n9ww59V7y6n/DeR+OpczbxyiuvWkFid
OaZUsYTyXxqP0qJHjXornlD+Cwgu6YqzHOdR/rPiEQZYvP9lTXExi+Aqp+aZ
7aZR/snxaDzVJqJeEMUxluDQ+MDogljKP5TE2ws04gKKK/3/4VexvMsnz39j
9aR4VF/etqPeEYpLE/5pf2ppTGrGv7F+VDyKIxOnW7yguHE4wX9UT2i/Z/a/
scKa9D94dtN15k8pfxXBF5b3n3Nq8b+xpls8avou9CoYQ3GdkuBFOwbVfbji
39hgHo+Ghq0t7TMoLpgRPMcxvU+Pdf/Gqjok3qZzmqGnuFiFXK/j+Wmrbm34
N9Z+i0O1OmtW9jOK4/s4lJJc3g3rX/BvbHoRh7g5aPuots8o/zISK29Xnija
QvnfjUMn60aH30+iuHQtDsFWeJvssJ3yvxiHhrEr7i9ZQnHjyThUVvEpf5yp
p/yPxKFua9DikVcpDnvI+SdsLzeL3E35b4vD1j1eF7cze075b4xDo415YG7Y
Xsp/VRxq8+ehrSvFhVxy/hu3g4el7Kf858VhkUPmsoPLKS7OIPx616z/YeVB
yj+DHJ875LP+IcUxkfQ/zjZ5neEw5R8dh55hq6JHdiun/EPiUPjD/MbI1sWU
v18clu47M2d5IsUld4L/frjgU+Zxyn98HCrWx1W7dIrixpHk+hTcdQitRMp/
WByer73jbo3mLyj/QXEormmLgsNJyr83Ob921RJNFMV1XeJQc+L2yZiVpyj/
tnH4Y9O0oEGnKS60IPyGfnX1/XGa8m8Uh9P2FUfMVL6k/GvFYX7lcL8/Y85S
/r81WCP/9+sFEsXxqwZNTcsL9r85R/m/0yCkLlj75xOKK8s1qOx699XxzAuU
v5Ecf7/Nk81Oryj/UoLbBNTJaXuJ8jdo0HNXve49D1HceJ7g5SHjq18tofxP
aFB8UWrlbvma8j9EYrOrz4Ys+4vy36VBTcLt1eE6iuu2kPG8qH8s38pA+a/X
oGp/5ya7LN5Q/nmk/Vzn5B29r1L+i0n/x6x+Zq2muDhHg8bTFbqHqmuU/zQN
jj7v9bJbx7eUfzoZ35jlUU+HXaf84zVYeuqiZX09xZVRZDypKQ8lrxuUfxCJ
XcYkzh/xjvL30aDO45Uq64+blL+rBhWj+q1s+ZDixnFk/EHgcOTALcrfQYPB
6yZYNgET5W9L8PTZY7v9vE35D9Bgt8bdl7dcSnFdTw1Kz9qsu+Byh/LvpMGD
WddtQ95SXGhD+OPK24fYfo+qmQYNf20YbOf0nvJvQPDcwc169qff49oaGsQz
7+H3DopLlVNQMm5fF4vse+3VFNSumDuhovkHOr77BK/9/fqbQDYfL5mCsLlW
yvwZFBeK/8HvHrJg8zlx+xTEOpmnulVQHNdMQaHNzL6/k9l8YgHBX84aPiz+
I+0/i+C3BiU0imHvy1gS6+wtxn+kOPiT2LL00MQ49j6YQGKbU5XGqZ9o/zAF
B4hfmz+dwZ73KoKvjktbUv8z7V/5T/xqSY0t9HmnNCPxiCo3GxRQXKpC4rPS
2UaP2PPqfSzirkav6475Qvsvi0UhetXrGex5oLsWi8ZI+1SvLxQXTsUiXKpZ
0OhP+nsU98SiMvTGpoc7vtL+NxI8a2D47B/s95QbiwqbVmYrEypo/zNiUYr1
vCzMpfe7MTEW9Td2Ds0f+Y32H0Lwmi2e4wB6P+rcyXiKX62x7fKd9u9I8MKD
Z7x+0PtNHETa/67jeLp5Je2/Syx6GrVW7h/o/aJsQeLwmdHnzX/Q/mvFoqlt
q1HJFfR+MH6NQeWblcZavX/S/stjUJd0rWVAY/r30JWS+LHvlnTPX7T/C+T4
t4p6He3p30M8FING91P1fPJ+0/63xKCYUxndaA693sq8GJRmze5gPlUY/m//
c2JQO/9D9Uuv6fU0pseQ+f7o7TFWVf7FIYocn/nsolcMvV46nxg836uu7fVq
Vf/FBacYhJUr4/o0otdDtI3BDlN2HOlRRnHsGYM/2hwOGHGLXg9lmxi08TJ2
33ijGu2/QQyG5x4Qup+jfI0/ozExYor90QfVaf9vo7HoUE3vXs8pH93DaOxn
PGAXINSk/V+JxrN9L1wY2paOVzwejU3/rLugYngt2v/OaHw7/02VzmF0PEpd
NHbo9907S1eb9q+NxrLf1pazr9HxGKVoLP+t3ZXfpS7tPy4aT88v+hAVUuPf
WBcQjVmejU5U3q5H+3eJxgrNZT/sTPsT7aPxSe6uqp2PNKD994vGxt/vBW1s
VYf23zEa542YkN+0tBHtvwnBW78/kO9Ez2esFo3Tmz2v7NfajPb/KQptG53u
2vksPZ/uSRTmPrU6/iShMe3/ZhTet/Fp+2KMgvZ/JgotXlZ5NfZ7E9r/vijs
HBr0Pb+Mnk9ZEIWNNTYBDgeb0f6XReEM9bvGlfvp8cZZUbi/ZfnRpwdb0P5T
onD+4gPtLa7T43VhUbhVuaJ3j7qtaP+eUTg5q9aaDEdz2v/oKPz906Hju+LW
tH/rKOzRekvnn50saP/do9DVPv/ByFftaP8to7Cf97JdKTltaf91ovD0g+AG
1qXtaf/fI1H72Kbj7DE01r2MxPvzarjcbdWJ9n8vEvUNS+u5HupI+78UiT+C
N5y4WtqF9n8kEqvX7Hz7424aK4si8e4n26wrVpa0/9WR+LDPNfuBgTQ2zovE
X1bPNzeN6U37z4zEWcsPNTxSow/tPyYSlzqc3fGyrC/tf3IkOvqoJl/L6Ef7
d47EDW96SLu8B9L+h0Xi5bIOXd4HD6L994nEvunLLjb+Opj23y4SUzzuTi3c
MoT23ygSt17JS6nsCLR/gYzfOf7CUcmO9m+KwDa1H/sYdA60/8cRuGld3kC8
6Uj7vxqBDr371LzkPI72fyICh9T+enr0b2fa/+4IjLh1T2n+zoX2vyECfauv
bDilnwftf3EERudMdZj/04f2Pz0C+3z6I6N+1wDaf0IETj82rX/qgVDaf3AE
/lH74trskzG0f7cI1C+6GnbUP4n27xCBL8/b/D4+Jpv2PzACw9ssa37292za
f+cIjGzWvq1Ps+W0/2YRmBu08MPGygLaf80ItC50HZOYpaf9fwnHjmPPu+cz
XHgejpVtBm70Ze3F2+G49otv8UV2fjwXju+qjelW8r/+D4bj2Hp/vbjExicV
hmPhrlat89n4jStInDJnw0bGD2aHY8tBq7oO/R//tHAcVPfyrx/s+giR4dhv
yPBz5ez6id7hWGYx6biOXV8cG44PzoXUjxEm0P6HhGPWk6ttG6rp30fqEY7h
Gx+FNbtN/35GC4KPaRY2cgP9+0L9cBTGH/tlP439/X+Eoer+rYUbOtP7Q3gT
ht1rPenYYju9f8QHYXix2qCJZ77T+wsvhyH6NRx7Mpzdf8fC0LaGne78ZHp/
SjvCsChq5oiaf9D717g2DHfOebw79Dm9v2FhGN60Wvi5vCG7/7PDsO/yVxa3
k+nvQ9CE4RQ/7Zvu0fT3I4phaHd8gcLPnsaoDsMxNvV/7Cxmvz+7MHxZW9e/
xxMaS33D8EPe5Sm3T9Pfr7F9GHa43ihR6Ep/39A4DMXub1becme//6okHl/j
eI+nNBY+hqJbyK7ZBRvo80P8OxQXj3/SNqSakvZ/PRSDL766dALY8+d0KJ5c
J2Q2vkefT9LeUHR6rGlyJ4g+v4z5oWjo9X3Nu270+QZLQ/FJyoDZZh/Y829m
KL6+fzxz/B36fBSSQzG3D26bf5s+P8XQUFTPn3Zl4l16PHqEor4gp9Ot6vR5
rRwViuZNXKYLbZvS/q1CcV5ZLe8jMfT5bewaiqYBQ9uNXEmPB/NQNCpeVjMz
a0j7rx2KOOjvMhhBn+fCtxA07fmW8SCPvj/EFyEoVk9Zf74pPR/eCUHoMOJO
72j2/rkYgvjrd1ptBT2fdDgEjasWLcxPp+8v49YQFPy0/k6q+rT/VQQ/mdZv
ZzF7/80NQaV1eoOIafT9KGSQ/ltuVPTrTd/XYjQ53jnDtfg3fb+ibwiqLQ5P
sTnL3r/jQ7D0+xanQxtof9LQEKyIGPPirETf38ZeIeir2j9kWyh9v0PbEHx9
IOtjnhedr+gahqB0YKTN8lF0PMLvYFRMbuFvlUfnQ+K7YHxy5JKqhT0dDz4K
xtb5n/RhejrfUhqCcexK5/52rmz+gcFoWzJZk26i8xejPhhX925SujiVjhfW
B+OO1nPu3nen80HdomDceXlUknEnHa8wLRidT1X0XHGfzjfF+GC0sziRMOor
HS8GBuNJr78mD/6Dzq+UrsHkc35As47j2fxrRDDu0j/qXAx0fmbsH4wdG6kD
aop0vgOdgjG51ZrYbHM6v9M1DUaP+4k1xwxl878awbj/8IvVvWrS+aH4OQhH
TflLe6MPnU/h0yCMjX3U6Egt+j2gvBWEmz9dOLRrIJt/ng3CJ269siZZsPnn
/iDcXy81pcN4Ol+DzUGYPtfqVuhw9j20PAiDfLb45SWy+W9OEDodO3nk0xM6
PxZTg7DVmI1dD26l1wvDg1DRutv+paH0e1DpFYSqqoI1vGXz7zFB5Hvuoyqs
Cpt/Dw7C0cOPP20xjOJgGYQHy0c5+O6h83ddqyAstTBLsltJr7dQLwi1NR5Y
r0ln8//KQAy2jNCV/qLXG18FotAsfPAf7mw94X4gpl4euqpRLMWlkkDUZgc9
yrGn6xHGo4FYZHVias9n9O8B2wPRM/tymhfQ7xPdmkBcITT4MSuU4sKCQMxY
2+LDwfFsvScrEBWRV2bOekv/XhgbiNaPm1rPifjfelYg5jwvyNRlUlyaEIjn
E5PbX1zM1uuGk/62Njvj0YTioApEHJBdNO88W49UBmLPeyFRg3bSv7dgRs7/
veOK72w9VqwSiPN+1vzzlpri+D4AK3zfjpzgwb7/ygIwR3rR9/ZXej9I1wJQ
8erQvVtFbL/gJInX9Mk3bmTfn3sCUPr0YPXr+mw/YGMA6tfYRGxwY9+fuQEY
/EL5/MMrtt81IwCf+Ozcdq0O+/5MDECxfM/op//bzwwJwNLbOUt7nWLfv+4B
KIhrnHadYPvVIwPI8+XgiUSJ4jAoAOFYNavoUywfpUsAav6yLI61o7jQIgB1
TrMvDb3O8u1qkfEv9Vr6rAbF8auIcG9l4WQT/X5XlovouehM/LbL9H6WSkUU
+mz6q3krihvPiyjOrhyqXcHWBw6JaIyydD46oZT2v0XEvduej48KZd//eaT9
sQ7mu7V0/UCcI+L5+Mi2za0ojukiKq++eB16/xZbzxCx2wu7hjF1Wf8+ZHw9
7ULd+t1i6xXk+BMmx7X4jq1PiCitSG75a9FNth4hIn5y3DYk7h1bfyB4cpMr
pu832HoDiZ9tPpzWha2PVPqjdPfS5RPRN9h6gj8KBjdFJ+Nbtn5A4vZbBzV8
fp2tF5Djp/XoUHftW7Y+QPDquzTpEdfZegCJb6+u+OXP2oM/vnQK2rDr4zX2
ve+PulG+b0o7s/ZV/NFl/19WITOvse/5yRg6q50m7h1bPzo1Gf3ePUpwasva
b5yMe1/eNOQffcO+zydj38iX9Todu8q+xyfjl3PXG7rMZ+0dJ+ONDdEl24Ov
su/tyXj2fVqRdwBrX2sytjo50FFvxtqX+2H/dNOsDdas/QU/fNnEcvqX0wb2
veyHHYTluxo1Ye3n+KFwpuLEhCyKQ5Qfhlfccptjos8rwckP67fsbr1wKGvf
0w/vt2mo/WGguNTAD+dlfL4ztypr/9YXV8Q7T3bZy9pf8UXN2U/OkHeFtt/p
ixt2HMpMy2Pttb6o0q346WpDcYjzxWkjRngFTGftXXzR9Ljb06ZP6fod9vPF
G4e2fvoey9o38UWYd2TMuDyKwycf1AfMvGvtx9rf9EGT5/xxZ7xY+30+OG9Y
v/qNnFn7ZT6orlO4zaMja5/ig623rfgYb8fae/pg+C3X5aVfLtP21j5YejLX
w8eKtW/pg6p9r9O636A4fPfG2mUV47APa3/PGxWH8UbPI6z9EW8cYGrYbxVb
n5RWeyM+K2x9aRtrn+mNFadnFTzrytpP9kbVW/M17zex9sO8MXHeiey1DJfa
eaNwJUZcvIW1F7yx56qYc8e7s/aPvVBXzalN/n7W/oQX7l0Stn90b9Z+gxdK
Fi+6dbjM2k/3+me/cpf1QNY+2AtxXofY+m9YewcvtH00d4x2GGvfmeDR6oiw
5uz61fTCbsnJVhPHsvbPPRHPnu1mO4Zd/3OeaBsVJ2Z5svaFnqg9Wc1lxUzW
frYnlmzpdMsigrWP9EQpZ2GPBZdY+7GeWFiny93eGax9D0+EuFXbBliw+6e+
J5o/VZcVL2Lt30xCaXrS3M2J7P67PAlzF/quNWxh7XdMQl26yb9WKWu/cBKa
Sg7/mnKatddMQjDE3zvagd3/6klYMu+CbcFj1r7vJEytWWVN7mR2/zeehImK
kCdZVdjv76MHwtx5rzasY+2ve2Beq1cPa3Ziv7+9HvjDW5lS9Rlrv9QDT58/
ke00hrVP9kCHrdVOGfqy378HiU0pi/3jWHsr0j660Yje09nv39wDnxUsj5zI
1qeFb+7o2SY+Y9hd1v6OOzr+PerzgIus/WF3zIhoY9nNij2/VrnjguL7JW0r
WfsMdzyfpwxplseeX77u+OlAunPnPuz5N9QdVXk2V/tXY8/Ptu6oP/F5lxjK
np+/3bBm/4rLe+PZ8/eRG84LbtnplY61Rzc82re46HI5a7/eDR2y5/9tfMja
T3NDXNfh9YEQ+nzHQDc8FqcVRSV7/o9wQ8U5ZdquF+z538kNI8ec858Twt4f
NdzQ3GP2lx+J9P2CT12xafUo5bQdrP1ZV1ztFFavrBZ9P8FmV2wd1nFWTCVr
n+OKBx++OLh9A8Ux3BVTixI32nRh77cxrqi4lntw90j6fgRLVyxx2LqgTM3e
n/VcMTH+z7/HvKc4vnLB6Jdlv89ksvYlLvjkw8mN1zbR9y9sd8G6tZN7/ypi
7Re44OqBKZo9QfT9jbEu2GWPeZ+Ch6z9BBfstn+qh3cPlu+vcsG7PyaZ32vM
5g9mLqgfbLdg6E+Wj/9+Iq4t11seHcPmJ9cmosFup/L+HZYvu2cizlu69Ufk
dNY+dyIaHyxefYzNXzBxItbfELytHv5vfjMRtUWpD1P2sXyzQROxKKCV4szv
/81fJqI4uu6bTftYPtBXNarG9KxEezY/KyWxwvn1h5MsX+eQGiv83ZJ6zmbz
rzw1Gv62bVZvCsunSFdjuBFrWV9n7X3UKO3dnf+yGtvvt1WjNv5FPfP2bP7Y
Ro36SfVPT9OxfILKCaj1MKteI4HhxRNQKum/wnEk22/PmoA5C+b8HHKB4TAB
xezFy3Z/YHiVCXjww+efvzqy/YFTzqh8Vi9s/Ba2Xz3DGY2bX2Qsnc5wR2eU
PA2PCtn8WKrljEKnNa+cyhl+YTzCG03boAFP2ft4PGrNUp3SXNj822k84hnl
ya512X5og/Fo+rDlftJJhl9xQjTbOm7XK4ZrnVAZ6HhtkzXbP3BxQmNLt8KL
d56z96UTmiLO9E3ax/Cb41C8efGN+ibbb1w2DkE17JjXYPb94TkOhRnNnQc+
esHed+MQtUNr3zjN8HtjUYq5Oy674iV7n41FeHZ8ncazgr2/CN400XpCh/+9
r0jcIC/2wieGPx6DQp3BtR77sefRBhLXzbH7M+8be/+Q2LP29IVF7HnRmcQq
1Z9BY9n32fPRKCgefX9Vi/0eCkmcf3i8ZY1K9v4g8Y/P3XeeZngPEl9TzT56
ieFvRqHUT10lbT67n3eMQqHm6R2N1/1gz3+Cb88tHBPE7re+oxCbROwZLv1k
z3dHxKaPymxHsf2mvY4oBNbLTtSw79dkgt9ssGu+DfsesnJE6UbdF9XifrPn
80gUf42blTeM7RcdHompJ9K27bET2PoDwYft6f7SjX3PDSXx4wsNNtxg+G8H
Mv/RhvTN/sqepw5YvmXGA+v4/32/O2BhUtk2r+Pse3SEA87L6auTLNj+Rg0H
1M/QGHNafGfPwxFYHYvfbLjK8JwRqO7+YLrlnEr2vBuByryOM98tpesLQr0R
eKPsbc73lj/Z88weD9/3UZdF0PUJYYE9Pql2t3fji7/Y88oeczfbzbWcwNY3
zOwxOeRWYaUzWy+4Zoe3Xn8av2cU2//ItcNyX7X/bSfKR3K3wxm7Si9td6fr
K0ILOyxskdXuhUjHK5UCqp4e2L5mKl2fEfIAHdX11t6cz9ZDfADvbpxeJ/wo
XS8S2gCamtxasOUWG2/xcKxdfnBtiAXb/4DhGHq8QdSbYWw8p4ahw7EHvdNW
0/UjwXEY2i49c6z4IhvPhaEIS37W6eFA158Ep6Fo2W6z1Yss1t8VWxz58dba
p/Xo+pXgYosH21uZNQ9g/d0cgptOO3f+qyFb//IcgqVf9lR5n0L3R4R7Nrgi
4FT8jN5sf2SyDT45d2p6+KVGbL18MLbcGdkkcUoTtn49GIdX9eqV0Y+d77k1
NltzIODlraZsfdcaH9Zb5VSjkJ3vjRW26rze4BzVnK1/WmG3CqsjNuPZ8R8H
oXOrqaOjB5iz9cFBmGDh1FhryY7/NhD7xTc+c3UI2z/JGIg27+IWxI5lx/8e
gIlL9DVd57dm9+cA7Djw/cRzh9jxNQZg6hSLVvut2rH7rz9uLEkpv5PTht1v
/VHd2W64oQtbH13QD+eENT3ZIVTJ7qd+WPZGqKr52IHdP31RteVY/IgJLG7R
F8fV92rfxqwzuz9UmBwYta7eIrbf0kaFj982PlI1tyv7+/fBAPMhdsPtWezY
Gx/u/rzu+zJL9vfthZuOrms15Q8Wu/TEGc/eXwoextaPPXvgt8JXV8NTWTzZ
EvO883zsJrP9leDuqF60eNI5PYsju2FpwZFXlj0HsOvfFRMH/r7e7zyLk7vg
6sN3OocdtWLXtzNuO7G0z+Pj1ux6dkLhjZvplo8tu34dsc+OIEWbz0PZ9eqA
Nc/t67QP7Nj1aY8Dk++NW5xpz66HEo0RD25JySMZ/3a43qaR5+bAUYxvG9zZ
eGJx5/hxjJ8Fvu+y5/ecLGfGpyWWWs6a/6unCxt/C5zTb0mJjd6NjbcZmpWv
ce1r5cXG1wQ9glN+z1/rx8Zjhs177sb+mwJZ/43QMuFVa/1jth/jWQ+lfQ9U
5o6x7Py18LxrbuPk0gR2vmq4yzG5+p7MDNb+9/GHyxonL7g/gx3/9fjg65u/
6d0WMfzd8bL+FXuzz61l8aPjYwNHDliVv4PG5F+ZdYvqtX7t+x8+/P/h8G74
/2uv+Trc5v+d//fwR/L+c6rBHvn4NLXgknz8nvVgtpwfNIL/xz/XDFrLr09O
E/CTX7+MZmAuv76aFrBAfv2DW8Jt+d/H0wLK5H8/pzaQJ//7QjsolP/985Rw
Q35/5LYHW/n9s6AD1JLfXzkdYYj8/pvWCerL78+MzrBbfv8md4FC+f2t6Qqi
/P6P7AZv5b+P4O4QKP/9TLaEfPnvy7MHtNoi+/259ARR/vt06gU58t+vY2+Y
I/99Qx8Q5b//NiqIlT8f8lTgK39+tOgL/eTPl9y+4CV//pj1g7/lz6cF/eCY
/PlVrz+4yZ9vOf3hqvz5V2MAoPz5OG0AjJM/P38PgEXy52vGQBgqf/5+Gwi/
4mTP5+RB4CR/fn8cBNny57vGCtrKn/9vrKCsk+z9EGkNz+Xvj+fWcHC17P0S
PBj85O+fx4Nhufz9NNkGos/L3l/3bGC//P3mOQR+yN9/N4fAGvn70cUWFneQ
vT+v2ELeB9n71WkonG8re/9eGAqr5e9nx2HQKlf2/j41DH4ekb3fYTi8OSZ7
/xcPh8YvZPODNgAvZfMHMr+Auvmy+UUeQIZ8/lEK0O+ZbH7Swg7WmMvmL+52
YL1bNr/JtQNL+fznmh28l8+PzOxhdKhs/jTBHobJ51cL7KFIPv8qsYcC+fys
3gjo+bds/jZmBBxcKZvf5YyAG91k87+zI+D1cdn8sIYDGOTzxxEOsPtP2fxy
mgPcSJTNP9EBtPL56W8HOD9fNn8dOhJOy+e3GSOh21DZ/PfwSLh/XDY//jYS
KuTzZytHMNyRza+THUEln3/vJbi/bH7+0RGE5rL5e99RoGsum99rRoGxSDb/
3zEKpBqy74M3o0BQyb4feowG6ars+yJyNAjfZN8fhSTWyb5Pno8GXSPZ90vn
MSAMkH3fBJPYTfb9s2EMSLVl30ePCV5d9v3UbiwICtn31eSxAPLvr9VjQSn/
Prs3FjBK9v3WchwoF8q+7zxJLP/+WzYOTPLvw5vjQLwu+35s4gSe8u9LFycA
c9n3p9YJ9KLs+/SKExibyb5fG4yH1E+y71un8aA+J/v+nTMetArZ9/GF8aB7
Kft+ruUMqq6y72tHZxB8ZN/fM5xBWyD7Pj/lDPBI9v1eZQKo5d/3MAEESfb9
nzUBtPNk6wPFBD8pWz+onACqSbL1hTZqEGTrD2CrBrVsfULyUQMc5OsXmK4G
0yO+viHkEfwxX/+AQ2pwEPn6iFSqBqkxXz/Br2oYPZqvrwgtJgLK1l9g0ETQ
BvL1Gcl9Igib+foNJk4EUba+I+ROBEm2/gN7yPly+fqQdI3gQ/j6Eb6fCLoX
fH1JMHMBsOXrT6ByAfEnX5+SJriAJFu/wlgSy9a3hAUuIAzl61+w3QWwAV8f
k0oIXvPUf+tn+IrEL/j6mlDPFYQEvv4Glq6AI/n6nDSG4Lf4+h2Gk1jP1/eE
HBKX8fU/2Ezaa/j6oHTWFaQJfP0Qn7qCsipfXxRquAHK1h+hkxuoxvL1SWmE
GxjP8PVLDCTxFL6+KUwj7dfy9U9Y7wbqqXx9VEI3MA3g66f4yA1qh/L1VeE3
wQfy9Vdo6w7y9VlpqDukruLrt+jrDkcP8fVdIcMdPFfy9V9Y5Q6nZevD0mF3
6BbO14/xjjvgE76+LHxzh+pKvv4M5h6QLFuflqw84KCGr1+jhwc4yda3hWQP
WLGDr3/DUg9oeIWvj0t7SXsPvn6O1wnenK+vCx89QDOTr79D40lQ1JCvz0t9
J0Fhfb5+j+pJ8EW2vi9oJkHpFb7+DwsngdsVvj8g7ZgEwhS+f4CXJ4FKtr8g
vJkEmMb3H6C+J+he8f0JqYcnYAjfv8CxnqBU8P0NIdITBC3f/4DZnqAq5Psj
UiHBz/P9EzznCdYxfH9FeO4JxmN8/wVqeoF5Et+fkTp7gTKF79+ggxdoHvL9
HSHYCwyy/R+Y7gXqAr4/JG3wAmNjvn+EJ7wAZftLwmNy/kZ8/wkEbzCs4ftT
UjtvQOT7VzjMG/Sy/S1hsjdIz/j+F2SS42X7Y9JqbwDZ/hke8Qb1Z76/Jtzz
BuEI33+D7wR/zPfnpJY+IBTx/Tu09gHFWb6/J3j6QO27fP8PUnygm57vD0rL
fAAb8/1D3OcD+qF8f1G4SXBnvv8In3xA4833J6UmviDF8f1L7OcLuoN8f1Nw
8SUTTL7/CXG+IMr2RyWtL3l+8/1T3OkLit18f1W4QvBjfP8V3vqCMY7vz0oN
/ECZyfdvsacfFLbk+7uCkx9IFnz/F6L8QFXJ94elOX5gPM73j3GLHyhk+8vC
BT9A2f4zlPuBmMb3p6Vak0E6x/evsQuJTXx/W3CcTPjx/W8IIfFlvj8uzSDH
R/H9c9xI8Bd8f104ReJyvv8OZSSW7c9LVfxBOMr371FJYge+vy+AP5wdx/f/
wd8fDFd4foCU5Q+xAs8fwDX+kC7LLxCK/aGaJc8/gPv+EHyR5ydIlf6Q/ZDn
L4gNRBj7mOc3CG1EKJnK8x90PUW4+JHnR4CtCLOW8vwJ4zgROp/i+RWSjwhd
LHn+hTJKhFHPeX4GpotgKOH5G+IcETol8vwOIU+EJ8U8/0O3RYStRTw/BA6J
4BbD80eM50Uwz+H5JVKpCKWWPP9EWS7CdVl+Cn4VYfQdnr8i1gqAIbk8v0Vo
EQA5E3j+i65LACyW5cfAoADAkzx/xjgyALrJ8mskd9Lel+ffKEMCIPkWz8/B
xACwfsvzd8QZAeAymef3CLkBcFqW/6PbGADSCp4fBHsCwOENzx8yngyA8lU8
v0i6FgA3XvP8I2VZAOzI5PlJ+D4AdD48f0msEgjWv3h+k2AWCG6fef6TThkI
d+/w/ChQBUJ4X54/ZRweCFW38fwqaUIg6BJ4/pXSPxDmyPKzMDYQwMjzt8Ss
QDBG8PwuYUEgCGt4/pduTSA4y/LDYHsgaLJ4/pjxaCDkD+L5ZVIJOZ8s/0x5
PxCWlfD8NHwVCDNa8Pw1sTIQ/pLltwn1gkBTi+e/6VoFgUMbnh8HlkGgeMXz
54yDg6A+8Pw6aUwQmFx5/p3SKwiuVef5eRgeBKPb8fw9MTUIuo3l+X1CDum/
mOf/6ZYHwX5ZfiBsDoJh83n+oHF/ENjI8guls0GAsvxD5a0gmP+V5yfi0yCo
NYXnL4qfg8Ayluc3CjWCYYss/1HXNBg6POD5kdApGA7I8ieN/YPhUkOeXymN
CIYCWf6l0jUYPsjyMzEwGLJl+ZtifDCUtOL5ncK0YLCX5X/qFgVDiCw/FNaT
49vw/FGjPhgG9OH5pRIGQ5ks/1RpCIYoWX4qPgqGdrL8VfFdMKw/zPNbhd/B
oPLn+a+6hiHk/cjzY6FtCFQ9yPNnjb1C4GJfnl8rDQ2BoEief6scHwIPZPm5
6BsCPWX5u2J0CPwez/N7hYwQyJbl/+rmhkCuFc8PhlUhcFiWP2zcGgLLfHl+
sXQ4BBxX8/xj5UWC/+T5yXgnBG605/nL4osQmCPLbxa+hUDTfTz/WVc7FL7L
8qPBPBQGyvKnjV1D4Zcsv1qyCoV1svxr5ahQEGT52egRCvNl+dtiaCjcm8fz
u4XkUCiQ5X/rZobCJVl+OCwNhUOy/HFjfihUyvLLpb2h0FaWf648HQo/ZPnp
eD0UXGX56+LfoRAly28XPoaCiyz/XVc1DLxk+fHQOAzk+fPG9mHQW5ZfL/UN
g3ey/HulXRg8lOXnozoMTIN5/r4ohkF3WX6/oAmDxbL8f112GDSR1QfAwjB4
K6sfMK4Ng3xZfYG0IwzmyeoPlMfCwFtWn4CXw2CarH5BfBAGNarz+gbhTRg0
ldU/6H6EgaWsPgLqh0MVWf2E0SIcsmX1FVKPcAiU1V8oh4RDqqw+A8eGw0VZ
/YboHQ73ZPUdQmQ4WMrqP3Rp4dBPVh8Cs8Ohuax+xLgiHPJl9SVSIYll9SfK
g+HgKKtPwXPh8FpWvyLeDodVsvoW4Xk4yOtfdF/CoYOsPgZqRoCVrH7G2CwC
5PU1UucIiJLV3ygHklhWn4MOEfBWVr8jukXAbll9jxAcAfL6H11CBCyQ1QfB
9AgYIKsfMi6OgHhZfZG0IQKCZPVHyt0RECurT8ITEdBLVr8kXo2A3rL6JuFx
BBTI6p90pgiwltVHgRAJrWT1U8ZGkbBCVl8ltYsESVZ/pewTCbay+iwcFgmX
ZPVbonMk7JfVdwmTI8FBVv+li4mEDbL6MMiMBL2sfsw4LxK6WPP6Mml1JNyV
1Z8piyJB+Mzr0/BIJDSV1a+JlyLhk6y+TbhHxi+rf9O9jIQkWX0cfI8ES1n9
nLFOFCyQ1ddJLaNglKz+Ttk9CtbJ6vPQOgpmyOr3xNFRsENW3yd4RoGfrP5P
FxYFd2X1gZASBXWX8PpB46wocGjF6wulZVFgJas/VBZEQZSsPhH3RcEKWf2i
eCYKjrzg9Y3CzSg4Lat/1D2Jgr2y+kj4RPqT1U8aq0XDeFl9pdQkGhxl9ZfK
jtFwV1afif2i4fE3Xr8p2kdDyFJe3ym4REOerP5TFxANTrL6UIgj51/A60eN
UjTck9WXStpoaC8M/q/+VKmLBpDVp+LOaOiwgNevisejoWIWr28VrkSDpaz+
VfcwGobJ6mPhbTQ82c/rZ40/o8EUzutrpQYxcFpWf6tsEwP1ZfW52DMGDK15
/a5oGwOfYnh9r+AUAxUreP2vzicGjsnqgyEqBgqzef2wMT0GWsnqi6U5MZAz
h9cfK/Ni4IusPhm3xIBuFq9fFg/FQKkHr28WLsRA+Gte/6wrJXEZr4+GcjL+
ZF4/bfwaA7Vl9dVSrVhQtOP118oWJJbVZ2OXWNDJ6rfFQbGgkdV3C46xgAW8
/lvnTo4/yuvDIYTgsvpxYyKJZfXl0oxYEGT158pcgg/m9em4MRbk9eviHoLL
6tuFU7Egnef177prBA/n9fFQRs4fwevnje9JLKuvl6pMAeEkr79XmpHYgdfn
o5LEubx+X1SRWFbfL8AUKPHn9f+6CQS35foA4E/iAVw/wBhL4o1cX0DKIrFM
f0C5YArgK65PgGsI3prrF4jbp4CxPtc3EIqnAFTj+ge6kimgLOT6CHB/Csj1
E4yvpoBiJddXkCrJ+Z9y/QVtDQ3oz3J9BrGBBoSlXL9B1YzEV7i+g9CGxCe4
/oOhE2mfyfUhdD01ID7n+hGaARrwbML1JcBWA5jJ9ScUDhrQyfQpjOM0IIVz
/Qq9qwZgDNe3kHwI7sb1L9RB5Hxqro+hjCL4VK6fYYon4z3K9TUwnZxvGNff
0E4j7c9yfQ5xDjn+JNfvUC3WgPIQ1/cQ8ggu0/8wrNdAzhauD6LbogGTieuH
aHZpIDyO64vAIdK/BdcfUZzQgKGc65MYz5Pr1yD0P/0SvUED53dyfROplOCW
XP9EbdSA2sj1UZTlGjB24voppncaqJ3O9VXwK+HTnOuvaH+TeDPXZxFrxQH8
4PotqkZxkLqf67sILeJAGs71Xwxt40Ah04fRdYkj14vrx2h6x4F+EdeXgUEE
38z1ZxTD4sC8BtenMY6MA1zD9Wv048nx+VzfRnKPA+Ed179R+8WB5wGuj6MM
IeOfz/VzTNFxMC+S6+tgImnvzvV3tBlxoNJyfR5xBmk/lOv3qObFgZsz1/cR
cuNA94jr/xhWkeuzgesD6TaS8bfl+kGabWR8Pbm+EOwh18+D6w8pjsSBtUyf
yHiSjK8b1y/SXyTHj+b6RtI1Eltz/SP1XdLfQK6PpCwj7Wtz/STTizgIL+T6
SvietP+D6y9pv5HrL9NnEqvEg3SC6zep6sSDrojrOwlm8SCs4PpPBvN4UCi4
PpROSfC9XD9K0y0elP24vhSoCG7L9acU1uT8Nlyfyjic4NY1/tOv0o+KJ79/
rm8lTSC4jutfqSeR9le4PpbSn+DSh//0s0yhhI9MXwtjCS40/09/S5tMYpk+
l5hFYuT6XapZJLbi+l7Cgn9wrv9lWEriPK4PplvzT/9Z/+mHaTaRuJTri8H2
f/rn+mOKff+cj+uTGY/+g7/89T/9Mv1pEpu4vplU8g/O9c/UN0jcj+ujKe//
c324fprpbxKf5vpq+IrE5Vx/TfuRXJ94rs8mVhJcw/XbVNUSAGX6bkK9BPJ+
4vpvhsYEf8n14XStCF7E9eM0HRJAri8HlgQv4Ppzin4JIMr06YyDCT6M69fp
7RJAJ9O3k8YQPJ7r36knJoB0iOvjKb0IvpXr55nEBIBorq+H4eT4aj7/6e9p
NQlgvMj1+cRUgrfi+n0qKQH0Xbm+n5BD8Ntc/8+wMAHk+oC65QQ35/qBmnVk
/M+5viBsJuPrxfUHFTvJ9RnN9QmN+wmu5fqF+mNk/Oe5vqF0luDZXP9Q/VcC
FMr0EZW3CF5p/E8/0fQgARQyfUV8SvD3XH9R+4bEm7k+o/iZxAlcv1H1k1yf
aVzfUaiRCEJHrv9oqJ8IkkwfUteU4Ke5fqSmdSKATF8SOhF8PNefVPQk7c9x
fUpjf4Lv5fqV+iEklulbSiNIPJnrX6rHkfg918dUupLYk+tnmrxJvIjra2Ig
iaO5/qY2ksR7uD6nGE/iIq7fqUon43vN9T2FaQT/xfU/DbNJ7M71QXWLSNyF
64dqViaCcQjXF4X1BPfj+qOKLYmgWcn1SY160l9vrl+qP5gI2JHrm0pI8Mtc
/1R9PhEUS7k+qtKQCEozrp9qup0I4TJ9VXxE8Btcf1X7nPT/hOuziu8SQfvz
x3/6raqviXBUpu8q/Cb9eXH9V0PNJJhhzvVhdQ2TQNOH68dqmieB1JPry0Lb
JEj9wvVnFV2SoCCL69MaeyWBIZjr1+oHJkH0aa5vKw1NAvVkrn+rHpkErY9y
fVzl+CTQenL9XJMbwXtwfV30TQJRz/V3tcFJ4GnL9XnF6CRQ9eH6varEJHDK
5fq+QgYZ32Wu/2uYngTlq7g+sG5uEkAQ1w/WLEkCoT7XF4ZVBPfg+sOKjWQ8
27g+sXErid//+k+/WL87CXQi1zeWDpP2I7j+sfpkEugfc31k5UXSX22un2y6
SuJBXF8Z75C/x2auv6x9TPjK9JnFF0mgnMT1m1XvyXjqcH1n4Ru5/r9W/af/
bBCSyfm5PrSudjIok7l+tEaRDOINri8N5slgTOL60wolwR24PrWxazJI77h+
tb5PMih2cH1ryYq078X1r9XDk8HQlOtjK0eR8+3h+tkmZzKevlxfGz2SAcK5
/rZ2Mhl/Da7PLYaSWMP1u1WxZDxqru8tJCfDwbFc/9uQScbXkeuD62aS8/tz
/XDNfDKek1xfHJaS8zlw/XHFGnJ83X3/6ZMb8wk+leuX64uSAedyfXNpL4lf
c/1z9VHS/i3XR1eeJu1duH666RK5XtO4vjpeJ/yacv117T0Sr+P67OLf5HwD
uX676hW5vh5c3134SI5/wvXfDd+TQSfTh9dVTQG04frxmropoNNwfXlonALS
eq4/r2iVAmDF9emN7VNAmMT16/XdyfEVXN9e6kvw91z/Xj2YxDJ9fKUdiadw
/XzTaBIf5fr6qCbxVq6/r/UksQXX5xdFEqu5fr8qnMQ2XN9f0KTAHguu/29I
SYET4dwfQJedAptac/8AzZ8pMCCb+wvAwhQ4fJf7DyiWp8ByK+5PYFybAoFn
uX+BviAFmnpwfwNpRwoUlnD/A/X+FPh0jfsjKI+R/rZx/wTTmRTwTuH+Cng5
BW605P4L2pspYJvF/RnEB+Tv94H7N6iepoBK5P4OwpsUMN/F/R8Mn1LgvA/3
h9D9SIEV47h/hKZ6KmiLub8E1E8FzXXuP6FomgpHh3J/CqNFKqgOcv8KfcdU
+OHN/S2kHqlgesT9L9T9U8FT5o+hHJIK8JD7Z5jsU0H3hPtr4FjSHrj/htYl
Fcpl/hyidyqoZf4dqsBUGO3I/T2EyFRIXcD9PwxxZLz7uT+ILo3Efbl/iOYP
wrch9xeB2eR6jOb+I4pFqWDek/uTGFekAmq5f4leR44/yP1NpMJU0D/g/idq
PRmPFfdHUR4k/Idz/xTT8VSobeD+KnguFcT+3H9Fe4W0l/mziLdJ+8/cv0X1
iMR3ub+L8DwVhPvc/8XwllyfLtwfRveFjF/mH6P5Ra5nTe4vAzXTQCjm/jOK
hmlQHsj9aYzN0kDRk/vX6NukwfkA7m8jdU4DDOL+N+peaaBvxf1xlAPJ+bdx
/xyTbRroxnF/HXRIA+lP7r+jdUoDcyvuzyO6pYFYxP17VL5poE3l/j5CMMFX
cv8fQxQZvyf3B9IlpIHJjPsHaaamQWki9xeC6WR8G7j/kGJuGpTI/ImMi8nx
Vbl/kT6PHP+W+xtJG9LAWuZ/pN6aBuHB3B9JuTsNUvtx/yTToTSY0Yb7K+EJ
Mr5S7r+kvZAGvhHcn0m8Ss4v829S3UmDT+u5v5PwmPx9GnD/J0N5Gry8x/2h
dKY0MHpy/yhNRRrYz+L+UiCkQ4k7959S1E6H0eO4P5WxUTqkxnH/Kn2LdPh+
j/tbSe3SQZjF/a/UXdPBYRz3x1L2SQfdPe6fZRqUDj2Tub8WDiPxMe6/pXVM
h7sK7s8lOqeDdWPu36XySIeLn7i/lzA5nczXuf+XISQd2j7k/mC6mHToZMP9
wzRJ6WBozf3FIDMdynO5/5hiZjo4OXN/MuO8dDhfh/uX6XPToXQh9zeTVpPx
NeH+Z+r8dAjP5P5oyqJ0UJdw/zTTnnRYkc391fBIOog/uf+a9lQ65JRxfzbx
Erl+Jdy/TXWdjF/m7ybcSwfM5v5vhrJ0UOzj/nC6l6R9U+4fp/lAcB/uLwff
yd/vD+4/p6g6FfAM96cz1pkKOpl/nd5sKoiLuL+d1HIqgMz/Tt2e4JXcH0/Z
fSoII7h/nklFzr+I++uhNYmncP89LZB4IPfnE0eT9uncv0+lJuf34P5+gudU
kCZy/z+DPxnvH9wfUBdG8IfcP1AzhZzPk/sLQgqJn3D/QUU2OX4v9yc0ziK4
O/cv1C8gfF9zf0NpGcGHcv9D9Voy/lLuj6gsIPEY7p9o2k7GF8H9FXEf6e81
91/UFpPjZf6M4hmCV5/5n3+j6jLpT+bvKNwk8Wnu/2i4T+J87g+pe0LiNO4f
qXlNzneS+0vCJ4Kf5f6Tih8knsH9KY3VMkDozf0r9fVIvJX7W0pNSIzc/1Jt
QeIV3B9T2ZHEQt5//pkmSxIf5P6a2O8fXFjzP/9NrQ2JZf6coj2J13L/TtVY
Eo/j/p6CC4mrVvzn/2nwygDpBfcH1QUQPIX7h2oiMsj9xf1FIY7gPbn/qCKN
xJO5P6lRInEV7l+qz8kA4wjubyppCT6b+5+qV5BYw/1RlTrSXwvun2ranAHQ
jvur4s4M8vvm/qvaAxkgbuX+rOJxwudXw//8W1XnMkDZnPu7ClcIruT+r4Zb
JF7H/WF1D8n5RnL/WM0zMp653F8W3hI+tbj/rOILOX9X7k9r/JkB2uncv1Zf
IxMO7ub+tlKDTNAYuf+tulkmKK9yf1xlG4IncP9cU6dMEOZwf13smQk6b+6/
qx2QCStsuD+vaJsJCmfu36tyIO0LuL+v4JQJKl/u/2twzQRPJfcH1vlkAjTm
/sGaINLehvsLQ1QmiAL3H1YkZII6n/sTG9PJ8TL/Yv00gqdyf2NpTiZIfbn/
sXox4ePG/ZGVeZmAS7h/sml9Jhgk7q+MW8j1qsL9l7W7yPUq5P7M4qFM0Mv8
m1UnMuG8zN9ZuJAJRpn/s8GQCbatuD+0rjQTnjhx/2iNMRO+DOb+0lBOzr+E
+08rTGS8O7g/tfEr4aPl/tX63+R6/cn9raVaWaCczv2v1Y2yQF3M/bGVLbJA
N5b7Z5vaZoGwhftrY5csEK24/7a2dxYY73J/bnFQFkgNuX+3ahg5fg/39xYc
swC3cv9vw/gsMDXl/uA69yyAStf//MM1flmgH8D9xSGEtE/h/uOKmCzQ3uD+
5MZEMp533L9cn0H4GLi/uTSDtG/B/c/V88j47nJ/dGUuGb8z9083rSL9p3N/
ddxIcFvuv67dRvp7yP3ZxT0Er3r4P/921RHSfwfu7y6cIv3P4/7vhov/9Mf9
4XXXCP/t3D9ec5dc/4PcXx7KSNyb+88rXpLju3B/euN7glcr/M+/Xv+NxGnc
316qkk3mz3U6mh1n/OuQ+EHl/O8zGX8zEheVz8hiuMmcxMVNiy8yHJUkPv/H
hhKGa7uRuDY+2MpwUUVi68XZlQxXWZN4dMrbPIYLQGLBs209LDn2f+SuA9U=

      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-3.4272872990737113`*^-6, 
   0.08590740060683147}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630397361119725*^9, 3.630397369764679*^9}, 3.6304012719115677`*^9, 
   3.6304091096179047`*^9}]
}, Open  ]],

Cell["\<\
Note that the quadrupolar splitting between adjacent peaks is 2\[Omega]Q = \
200 Hz\
\>", "Text",
 CellChangeTimes->{{3.6303974057372093`*^9, 3.630397418719994*^9}, {
  3.630409122398425*^9, 3.630409127730555*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hard pulse", "Chapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}}],

Cell["\<\
A hard rf pulse has an rf amplitude larger than the range of spectral \
frequencies (in this case 4 \[Omega]Q, i.e. 400 Hz).\
\>", "Text",
 CellChangeTimes->{{3.630409145372348*^9, 3.630409176378265*^9}}],

Cell["\<\
In this regime, the rf field couples to all 3 single-quantum transitions at \
the same time. \
\>", "Text",
 CellChangeTimes->{{3.630409178932012*^9, 3.630409192657748*^9}}],

Cell[CellGroupData[{

Cell["set rf fields and pulse sequences", "Subchapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}, {
  3.630409216531904*^9, 3.6304092216056004`*^9}, {3.6304094827899113`*^9, 
  3.6304094837227907`*^9}}],

Cell[CellGroupData[{

Cell["rf amplitude", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.630409276272395*^9}}],

Cell["Rf field amplitude, expressed as a nutation frequency", "Text",
 CellChangeTimes->{{3.630395292959406*^9, 3.630395300834734*^9}, {
  3.630409246076763*^9, 3.6304092476958227`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]nutH", "=", 
  RowBox[{"2", "\[Pi]", " ", 
   SuperscriptBox["10", "3"]}]}]], "Input",
 CellChangeTimes->{{3.63039521497709*^9, 3.630395224826025*^9}, 
   3.6304092505882893`*^9}],

Cell[BoxData[
 RowBox[{"2000", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{
  3.630395227638023*^9, 3.630395307440235*^9, 3.630395720968466*^9, 
   3.630397847078607*^9, 3.63040920612573*^9, {3.6304093422302847`*^9, 
   3.630409359745715*^9}}]
}, Open  ]],

Cell["\<\
This is much larger than the width of the quadrupolar-split spectrum. Hence a \
\[OpenCurlyDoubleQuote]hard\[CloseCurlyDoubleQuote] pulse\
\>", "Text",
 CellChangeTimes->{{3.630395246314694*^9, 3.6303952694452133`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["hard pulse durations", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.630409286566934*^9}}],

Cell["duration of a 360\[Degree] hard pulse:", "Text",
 CellChangeTimes->{{3.630395311174177*^9, 3.630395319578122*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]360H", "=", 
  RowBox[{"2", 
   RowBox[{"\[Pi]", "/", "\[Omega]nutH"}]}]}]], "Input",
 CellChangeTimes->{{3.630395232771331*^9, 3.630395242221376*^9}, 
   3.630395275252533*^9, 3.630395717091453*^9, {3.63040925466089*^9, 
   3.6304092567420063`*^9}}],

Cell[BoxData[
 FractionBox["1", "1000"]], "Output",
 CellChangeTimes->{
  3.630395242882451*^9, 3.63039530756124*^9, 3.630395721142517*^9, 
   3.630397861680743*^9, 3.630409206322336*^9, {3.630409347224757*^9, 
   3.630409359930263*^9}}]
}, Open  ]],

Cell["duration of a 180\[Degree] hard pulse:", "Text",
 CellChangeTimes->{{3.630395311174177*^9, 3.630395319578122*^9}, {
  3.630397904837789*^9, 3.630397904982959*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]180H", "=", 
  RowBox[{"\[Tau]360H", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.630395232771331*^9, 3.630395242221376*^9}, 
   3.630395275252533*^9, 3.630395717091453*^9, {3.630397910907054*^9, 
   3.6303979175505257`*^9}, {3.630409260882577*^9, 3.630409263301152*^9}}],

Cell[BoxData[
 FractionBox["1", "2000"]], "Output",
 CellChangeTimes->{
  3.630395242882451*^9, 3.63039530756124*^9, 3.630395721142517*^9, 
   3.630397861680743*^9, 3.630397917956274*^9, 3.630409206352903*^9, {
   3.6304093474040194`*^9, 3.630409359944181*^9}}]
}, Open  ]],

Cell["duration of a 90\[Degree] hard pulse:", "Text",
 CellChangeTimes->{{3.630395311174177*^9, 3.630395319578122*^9}, 
   3.630397921116646*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]90H", "=", 
  RowBox[{"\[Tau]360H", "/", "4"}]}]], "Input",
 CellChangeTimes->{{3.630395232771331*^9, 3.630395242221376*^9}, 
   3.630395275252533*^9, 3.630395717091453*^9, {3.630397926446413*^9, 
   3.630397931613872*^9}, {3.630409266215269*^9, 3.6304092684875727`*^9}}],

Cell[BoxData[
 FractionBox["1", "4000"]], "Output",
 CellChangeTimes->{
  3.630395242882451*^9, 3.63039530756124*^9, 3.630395721142517*^9, 
   3.630397861680743*^9, 3.630397932061482*^9, 3.630409206368334*^9, {
   3.6304093474365597`*^9, 3.630409359976338*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["hard pulse sequences", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.6304092994486933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hard360", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Omega]nutH", " ", 
     RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]360H"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.630409229985642*^9, 3.630409234094507*^9}, {
  3.630409302467342*^9, 3.630409315605977*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2000", " ", "\[Pi]", " ", 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "x"}]],
     DisplayForm]}], ",", 
   FractionBox["1", "1000"]}], "}"}]], "Output",
 CellChangeTimes->{3.630409359995097*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hard180", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Omega]nutH", " ", 
     RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]180H"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.630409229985642*^9, 3.630409234094507*^9}, {
  3.630409302467342*^9, 3.630409329060882*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2000", " ", "\[Pi]", " ", 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "x"}]],
     DisplayForm]}], ",", 
   FractionBox["1", "2000"]}], "}"}]], "Output",
 CellChangeTimes->{3.630409360009178*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Hard90", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Omega]nutH", " ", 
     RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]90H"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.630409229985642*^9, 3.630409234094507*^9}, {
  3.630409302467342*^9, 3.6304093356453123`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2000", " ", "\[Pi]", " ", 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "x"}]],
     DisplayForm]}], ",", 
   FractionBox["1", "4000"]}], "}"}]], "Output",
 CellChangeTimes->{3.630409360033029*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["observable trajectories during hard pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630409368213925*^9, 3.630409373331704*^9}, {3.630409457544689*^9, 
  3.630409458172489*^9}}],

Cell[CellGroupData[{

Cell["set initial density operator", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304093850105877`*^9, 3.630409388914083*^9}, {
   3.630409450636348*^9, 3.6304094511635103`*^9}}],

Cell["\<\
assume thermal high-temperature Boltzmann distribution, and omit the inactive \
unity operator part\
\>", "Text",
 CellChangeTimes->{{3.6304094035733433`*^9, 3.630409424904491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]ini", "=", 
  RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.630409390964274*^9, 3.630409394832224*^9}}],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6304094014855957`*^9, 3.630409428015237*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", "\[Rho]ini", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630409433790999*^9, 3.630409442219749*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["3", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["3", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{1}, {2}, {3}, {4}}}, {
      Rational[3, 2], Rational[1, 2], Rational[-1, 2], 
       Rational[-3, 2]}}]]]]], "Output",
 CellChangeTimes->{3.6304094427443953`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["track the trajectory of z-magnetization during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trajz", "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ",", "Hard360", ",", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
  3.6303956858216133`*^9, 3.630395724549844*^9}, {3.6304094761119833`*^9, 
  3.6304094984532213`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"TrajectoryFunction", "["}], 
   TagBox[
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"0\"\>",
        0,
        Editable->False], ",", 
       InterpretationBox[
        RowBox[{"\<\"1.\"\>", "\[Times]", 
         SuperscriptBox["10", "\<\"-3\"\>"]}],
        0.001,
        AutoDelete->True]}], "}"}], "}"}],
    EngineeringForm], "\<\", <>]\"\>"}],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, {
   3.630395712241858*^9, 3.630395726102973*^9}, 3.630398100508581*^9, 
   3.6304095009290047`*^9, 3.630410230556115*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"trajz", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "Hard360", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, 
   3.630395752643961*^9, {3.630410221038526*^9, 3.630410226625946*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13k8VF8bAHA7EUnIUioSWkSL3X3u2HdjSaKyJKQsSSWpJEWRLUspUkmR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->NCache[{{0, 
      Rational[1, 1000]}, {-0.9705696873829202, 0.999999999999992}}, {{
     0, 0.001}, {-0.9705696873829202, 0.999999999999992}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, {3.630395728971292*^9, 3.630395753143238*^9}, 
   3.6303981054413433`*^9, 3.630409504468165*^9, 3.6304102307830267`*^9}]
}, Open  ]],

Cell["The z-magnetization nutates at the expected frequency", "Text",
 CellChangeTimes->{{3.630409507654352*^9, 3.63040951897099*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["track the state populations during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trajp1", ",", "trajp2", ",", "trajp3", ",", "trajp4"}], "}"}], 
  "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PopulationOperator", "[", 
        RowBox[{"3", "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{"1", "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{
         RowBox[{"-", "3"}], "/", "2"}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", "Hard360", ",", "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.630395432866467*^9, 3.63039547736121*^9}, 3.630395744054966*^9, {
   3.630398163355588*^9, 3.630398164199418*^9}, {3.6304095400696163`*^9, 
   3.630409550163752*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, 
   3.630395478421029*^9, {3.6303957341222*^9, 3.6303957480936413`*^9}, 
   3.6303982188138123`*^9, 3.6304095554560413`*^9, 3.630410259029072*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"trajp1", "[", "t", "]"}], ",", 
     RowBox[{"trajp2", "[", "t", "]"}], ",", 
     RowBox[{"trajp3", "[", "t", "]"}], ",", 
     RowBox[{"trajp4", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "Hard360", "]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Purple"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, {
   3.630395486202817*^9, 3.630395495394308*^9}, 3.630395738636546*^9, {
   3.630398235967197*^9, 3.630398320687645*^9}, 3.630410248566897*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwV1nk8VN8bB3DZkl2WRBtZW2RLDeM+d+zLmJlEu12SEkmSVJKiLCF7FCoh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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwV1nc81P8fAHArske2IjOjVCL7XneS7e5C0lBWUlFoSbKiREWyUkqUrCQr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     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV1gk0lN8bB3BbZMuSXZE1S6lE9nlmJLuZCUmLsiUVhTZJtihRkWwpJUq2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     "]]}, 
   {RGBColor[0.5, 0, 0.5], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwV13k8VN8bB3DZkl2WRKusLbKlhnGfO/ZlzEyitNglKZFUkkr2EiF7FCoh
X6koWx2laLUlLdYoiWSbO1dIv/ubf+b1ft3XnXvOeT7nOXfWegY47Ofn4+NL
XMTH9/9vN4EXql6BD03e/Pv/h0TmRsvy3NJSsbX/Wcn9pVwzwUF6aTexcC+H
7VzKDubpZZV9ZVjWHpVH3ykTb8ZYK9IqsMvmtRZtlOuPJzW61FRjpL3K34eU
L63Wx673PcHaV7r2pFMu/TayJ5D/GZb04cRQIOUUWp2CTNpzTETmhKIF5ZDE
hPZ7Gk3Y6SGfY7KUXQddEx1qXmFJQ05k1wI1vm06ttPMtxhzxfab1yivT1gk
nNrXjElI+IbupSxy9Ke7UnUrdrnqzqmllE8rtz/x42/HejK1Cxr+ksgj8Eao
WFoHdt7MLECOcofSpU97ez9gTvsXyVXMk8jyRbBhqcZHbNBv14A95Y1KllPM
ms9YtLTBfMAcia4/1+bkCnRhtz9PWc3MkmhpwLKyMWY3lvip+nEo5ZmG4YOJ
fb3YI5GvGkf+kMjw0bBXgFw/Fq8fvaJvhkQB4j0py6r7sY2x1ca2lAcevpg4
wD+AYZ/9ZiVJEr0UyygVSfuGfVpz+IwDl0T8HvFd5bTv2B0DgTep0yQyfnhO
dHfvd6xh83nztikSlbn7+hZr/MDqGX9qt02SKLWSpmpb8xNL35j37OkYiZpF
tXdMuY5gm8+tP/7hF4kWu6tEZAuMYvofOU6DoyQKFRXrH2H+wvRUfa+P/SSR
u1v31fi+35hzaJtH3XcSZVe0vtaPGseUJhlx+d9INBI1MO8vN4F5v/boDR8k
0bovnRsUqiewKIsPStpfSZQehS748E9hiVLfu027SRT2OclicRoXixq3fOfU
RqK0pIwN1r+52EjR2JYnLdT4ra7JXLAiME+n5JbVzST6WnmnR3SWwD55Pslo
fk3VI6XxuKQbibWfLrrwpYFEMnbzt+S1ZrHnDWp+pRVU/fkFLu2MmMV2ZzSt
KbpP5aN6SVBG1yym9lNMJrecRCc0lmHLE+ewlp+jeUGlJOoW0OtcMT2P7ZG8
cPntDRIV1h0QVn38D1u5/7URPZlE/bStJ/TE+GDXhk+f3iSS6HCa0c/2rXzw
Okun1vESiWKYjBbZZD4wOHuP7RBLoqoa1tU0s0Wgf3z67XwYiVZlHNTPKuKH
+yV8TVIHSDTMvu6VFyQE/btK0vQNSST+KeCZXY4Q1Dkcl1bTJ9Fmd3wt+UII
kpM0n0vrUOMN/Nprv1wYBF1Pfe7UIpFg8ro9c0gYDpoHta9cSaK17bc5OyVE
wG5YqiqDn0R7HMtNxItE4XK+YBDjFQ+d7Q7PedQmCrGNzfdOv+ChfO/tc55z
ovDidq9l+VMeGg6eqqpmiQGW8jhYpIaHTqQZGBwgxGBWwm4uuISHrnRWrX9m
KgE6uxfS4SIPvXV+uiykRwpWO1kFFFjwkKjYcmUtAWnQ7DPuBQYPlR3cvj59
mTQ8s7g995HOQ4T6M+tAXBrmQ8wsZ/R5KCr/RrRqijR4M8Jpf9by0I10n3+X
tshAyoPGK3/nCdQf/mvKJWwpQI41TfEugXY7zXz+t0QehlWbYr4IEGjFx/cr
NNfIQ1Tt5Sv3/nJRr/NdN46hPLzxT6yLILnIe5/P9zxPeah64uknO8pFgV4d
E4xaeTgbucX3dxsXxR0tXxx1WAFSL5yIu3SNix4l+G4RaVkGli6bUk7oc5F8
46ck6VQlmMkd+xzInEZlr1yfnkWrYeNncQlX70kU93rnWHepCnhFDuUvlfqN
TkUsCh46rAaLpWYOdA8No88C5x5d+6sBAaEbcxMqB9HKn+4Bj1+sh2i1ksKV
kV2oNUP+20XXTaAxqxX7b6oFNWS+czAf2Qxts1q2FU33UPMCV+n+Tl1I08Yl
SrbWw2TaL7+sPD24+Uc140vpexB2UyD0hQ3g4tLekq8f+8C4jRFmvn8LbPHX
8viV/R00izo9SksN4S+umxV9eQQW38s93yS1DY78KsyNCRmH3FXN/2h7abDa
0jMs/cUkrCi+m97pToN9F1xD2t9NQrZ+8qZjPjQ42+hruKRzEtKtHfeWHqVB
rhY+7jM0CYlBXx6uiqNBXWH40kHhKTjXOOQvUEkDciZHsdtyCjyO/Ot6K2kE
MYQM4+mzKVB7olPl9swIjnTO4b3F02DNFtYYaDKCR+M3dmWVT4Nff1ea9zsj
GB+Z6GI9moZy/thjBz8ZwTHdterFz6fByKpH+9hvI6i+8jpBqW8aOK0XbsUo
GcPAJpFl40u5EDowkPJfkDH4W79763CCCznHqhbphBjDtsGvGs5hXECCiYH3
zxgDn9RU1a4ILghq0FiP4oxBz/3sCYtELlw+dHnJ02vGwEwgdLtuceEm1zi8
4zVl1Z0Wv99zoVk4zX9OhQ5mS45KFm0gIMrkG221Jh1ci21j0nUIoAXrC5tt
ooOQdtOrc1sIuPm17drFrXQYTRO/awoEhNZJti5n0sHU8G37BQcC1IPi9LYd
p0OeZnzkihACzvacJoOb6JDCHpmyQwQYyL1pyHxLh+6UPXXJDQT8tFVKqmuj
g7aUzOb2JgIcq6o0BbvpoJLtKm7WSsD6K8TuKxN0oH3UjP/WT0CndUDdveUm
4NfBaVBbxAPtCs/zvw+ZwHjWnwfZJjy48yBb6fxRE8iY+KlxnsEDzQftD2RP
msALz5X6HhY8WHffdGhbhAkcrlMTk7TngWK5il1kpgnQ+aRvKe3jAX/pgJzi
CxPA32zKXwjhwbk7SmUlr03g2MZM6bNhPJgvcbAyaTUBJjdyMXmOB2Txs1Oe
XSbQ568X9yGGB79uF/SWTprAZH9WrXkqDz7e8CxirMIg86qr+uh/PHC8kc3o
WIfBjOzlG/z3eNBe0P7FRwuDSzWHsmUrePA231TikgEGySIzk2trePDsukpQ
py0GNyuP6E284EHp1QHjQycxiE9vYjt08yD8imdLaisG1mM0JU1BEpK2yTW+
/IDBh+WZolbCJOT1vKib/4JB/89vW91FSKjX0Crx/o4BTTHM6rw4CYvqxqMM
Zqnfm2Zrn5UjIeJbmFHHOoCZ4ck6z3UkpFzQ1hXRAshXVrNRUyOhQLtfg64N
8Ma8VmxAnYSGEDP5m9sAFGUK9GzXkyAoITpxzB5gX2fR3w4dEqK3ZNySPQnQ
f0IQ76CTkP7FOscqDEAv64qoEUZC4bnZlNPnAZwiQ4WzgYTGVy7hg/EAv9MY
ydamJAi7qu59kEfdH1A46mZFgoJA5/YftwD+/PtCy7AmQb0o1lr5DoD27qBH
L21IsJoa2RJZCSCfNApKTBLiYu5J73gNIP7ALvwkh4TMDV6LY1sA3l1vMQvf
TkJRq9xCTQfA5qG1WyIdSHipFDKq0gdQSkbmnXQkYcldrHFqGmDNko40JWcS
lBwn6tT/AESL72zgUl7/J//BngWAddeDVr7aTcKt/AiOhyAONoyFne57SXgx
+t3klSQOjQ1W3dauVD2eblPbKYOD8TlP5UnKoRnx4oOyONSo2ddfcSNB20y3
a14Rh+hcG+OX7iSILI96dkEZB8N8I5k9HiQM/u4sVliFA+JWM4coZ2aHheis
w6HJTpc75klCUGCL22M1HGT+k3U/6EUC01LFylYTh4blu3X7KC+aapL33oRD
1MZJgRpvErqblP5ObMYhfy9NaPV+Eh7m+n87o4cDo6jl0FnKfjayDzK24sBa
/NV3ow8J5qt9slWNcKh7t+9fKOXVRNX5e3QcipdrzjVQnn0tdhADHDyeWe5b
fICEjjxXzhsGDscFn6hYUC47cW+rszkO9edTWWcoxzEFV3+3xMGB0d53l7Kn
yi7hIBscgu+Gd3ZTNpkpHluww+FabomeoC8Jis3zHfEsHAJN93HVKE/dYNcp
bsfhNu2Gsinlt6cKbtzagYNSVGKRM+VCNnFRbycOZbHaVw9SDlezDkLO1Hyk
0qaDKe+dy97N3ItDv+2He6GUDdvG8M8uOOAtAp3/t/RtXNPHHYdN6YbuxymP
hF2Rmvak6rsQxfGj/NxhiHduPw7Cbxbf3k35miatV9wXh1zVz15mlE8txL/I
8sOBP1MuVoOyY0dvqbo/Dp8UPkoLU9Yu0U19EIDDARJb1EfNVyQ86jQehEMM
95DzfcoDTh893wXjkL3pnEI45boN6233nMThtPpVY2vKGYvO6P44hUNQ02CT
KOWgjy2KwWE4rHE5W9tE1YP5nwrfonM4nMhMVjhHWT3y+I+E81S9Ey0+61Dm
2/2yWSkKh7mqBoEeqt6VgkdyDS7goBn1JkmVctKX+qin8TgsiN2dRlRe/Mpl
D7MScRhKk0ZOlFftqzbyvYLDfy+lkwKpfM3oiqsQaThYnZRLJ6g8vl/stiQi
EwfQdxc6TjnugeCnq7k4mKoXr/Gi8ut5YRfSzMPB+ZzCuzYq73S3ksLKAhye
apUOGlGeFOUcb7mNQ84scOap/bLH8+pSgfs4ZI4PbqLvo/Kf4+neVIGD0cnP
bf7Ufuvs1CqLf4TDzbt+3zP3kLDDrspG7jEO9++/2ddF7VemwYdwtZfUen8a
TJdxIuHikZzmn69xqGIJPZOk9vvLIq8VZe9w2Gz1xk1oBwkWK6ceGb7HQTF2
jNtL9Q9MWGrcqpfav++uJJtR/SUM76SLf6Xmf6rDRdyOhJrQ3IutgzjcGKbn
NVP9aOv4BvXdP3EQ5fpdAKp/6XyydvHj4pDXND7bziBhbUnEm0uiDPiRfbq5
fgsJ7t9slm+XYEBqupLRWgMqT6tkDshLM8D/PyfV03pU/7lynf+aPAP6Hv47
obyZhKVhdbS7axjwbUFLXVKT6r8s3u02QwbMzOFGdYokmMY9JtJoDDBtffyl
QoHK/7Mosz10BjiK6wjepvr9X0PZvgEGA+oW3nJPSpPAW62jwGUyoKLO2OPt
YhKGJw9GKXgxgPuqWAoneDCxMBZ+Zz8DOiV0POamqPNPLOgM7suAZ/P8K+5N
8EBYPfSEnz8DRGjQKvaLB2p7Lvo+OckAeome5dkBHng+K2H6XGJAhO5dIedm
HvSkjMo9rGSAZn7Pkm/5PPh2PUDGrooBl56P/hq7Rp2npdMS/TUMUNxzfPvU
Ver8bZwTFq1nQPRPl4KRNB4ozYn9cXlNjUc39nTWBR44e23sEepjwKPz7S0T
AdT5qu9/y0nElOqvQ4cvbeMBdmu/iIqYKeyoterJMuBBsYLrod8SpjB0+vR8
ng51nv5h6cbKmoLtrjhmjib1foF0HletMgW69I9dVoo8iLfldihvMYUxWTOr
QB4B5h6nBQc8TEH9sYDFsjICytuPHSjzNoU6j2VbXIoJUDY//Dr0gCmcT5vi
y71JwJS6S5KsvykE1izTE71KQN4vbIVFiClkBGmpXY0lYP4kv0FRoimUy94q
zXQjoDLxgteRWlMQjYi4LCFGQJBA2P1NT6j7NyXV3BEiQCfkyKKxelPYFRe6
0ZyPgFKPHdcPNZpC8NUzo14E9b5nsLLLt426frpe0K2PCylfyh28fpiC1Gz0
Sov7XDii/onhLGsGY2u+C/bs4ILmE/U1pofMoNlEMy8/ZhruCnWubPc3AzfR
qSWO4dNgaB+t7BloBvdP2fYtCp0Gi+5BhYjjZoBtoL9n+0+D52yexLNzZvBO
LUiycsc05BgqzzFSzWDRks3WhaunQequVCfjsRlUgNW9zRVTwLs+E8+QMofD
5ppijNZJeJI9mKr01Bz+fBzOjXQch69WAvarD1iAjhyn2/LjCKS+uiHQt8QS
GmM47XrSQ4B7u+wKqbEEl73D8zMX+8H6nt0eEzcrmE9R8bnr0Ak2y3bMdslY
g6MF48bmB8+hcPNlm8Iqa8CvjA91tCSgKyuYGRv22cB9Iu199vsmdEpFJeKi
hC1YlxxclRb/EdV+2bhC/oEtaHXv+u0/1494dzg7TvnYQfdwed4DuyH0dDsR
l6nAhECT+J3XFEbRcHGz/2ANE8RjakMeKY+j0mOd/+48ZoL0diGP5RvH0VGT
3uTgeiYwl7MmjtLH0WzrWKVQIxNs8wWmhF3GkfiM+IJGGxNKT5QK1eeOIx1L
u8TDP5jQN7vdtlJyAoUMNJURsvaw6PbaxKcXJ5CI8tPxxf724P2yqPvXsUmU
/ihaJz/AHhLbiocPhU4iVUfbo0ZB9pBl4BQwFD6J8IT3U4dP2oM87erQu4RJ
FPLvO9F23h4cqh45+NyeRD8GReevptvD7Nj997WfJ1FjqaOITr09/MkPsxs3
mkKR2PAaZ1kW6C8vuLl+fAp59xbaf5NngaS0XaAndwqZn90fGqjIgnKV1Mtp
f6aQ4JOB93ErWRCnH/J8TGAaRZn0xFRrsGAN+e3HfsVpFENv/6VEZ4FatMKK
YHwaXTCqq+rxZgGjE8r4EqaR35fQ7wcPsMBHyLIlL3ka2YbSlvIOsuDx9tq1
9PRpJFrz8JBkAAv4bf/u9L4+jS7S7q2CUyxYKPD9EXpvGl3aVhiVl8CCWCf1
l6hjGl02TOJ4PWRB0a0QsYJlXNRh1DCoXs0Cz9q+4r/KXKQIvBMjtSzg+a88
s2MNF+VZ7cs9+pQFLjGdj8c0uajcWXPk3FsWCOdWXOymcVFraH1kzgALytz9
DxXs4aKlaOLhB0k2XPLt9X+ZwUU7G9bZZsmwYUt+aaXvVS7KbtrZs0+ODbNV
frIC17lIpbVO4NtyNqxbw5JQL+Qiva9xnClVNvUeTRtUreCiHQJrRySN2RDr
mu0h1MJFqVbbV1ofYMPN1jpHJh+BClYx3LoPsiE8IfbBPD+B7hI6+YGH2dT/
aIOPt4UI9PqGtFrWUTbErFM/9FuUQHx8rRtHTrPhTKfDI7o8gQ5XseiXktjg
nhMR3KNJoNDL2Nk1V9iwvjJ5iLaBQLE+2vUVaWxI6xuST95EPU9O0rwnmw2B
5XdKNusR6FPgOzvtW2ww4/+et8mYQBZazL2t1dT9/g99NjIJ5MBHz/WuY4N0
1+EwAxaB3D9u6Jt5woa1tzRstnIIFBYt5rX2ORvEXWyENzkS6P7X135BzWzo
6xsQ+ryXQKuybULlBtkwcEy6Q8+PQBuP0uqKvrOhiheuP3SIQDRrrQX6MBs8
WqUsUv0J5MgTidg/Rj2v5OyZ/kACXXR4eeEhyQYfnSI67SSBTkffYG4U5oC3
SU/9aASBSuwL23MWc6AeH0kIiqLmI1/sLLGEA6KRATVT0QQyLCzz/i3GgaXd
ozp9cQSaaqwOK5fhQOtGzwTfRAKtvVzHv1aWA+y8T+yaywTi7EJxyXIcaM+S
DhRKJlDZj+epQcs4YCe89FXsFQIdFGktNVjJgaBXo5/omQTKbG3Xu7WKA2eu
TkTtziJQY+aHKvk1HEjqiU0IyCaQqlbXc54KB7oOLTyIzSFQv81Qd5UmB9yP
n9zhm0cgqaU/PbXWc6C78vBXdj6BsC+jw1kbOICmmW90CgiU4zfJDdXmQMtE
wf3eGwTaFT8vbmLAgfvs0eaRQgLF7PiX8t8WDigJBxrn3iZQhTL/8lVbObC+
FwnYFBFoaelitX80DtAZn29fKiYQI1j0ToAxByZNKiJVSwgUSJfQ7adT44Uz
tZWUm98uNXkKHNgWJgvP7xDob6p8gy6DAwkKAvGMUqp+Loo2BaYcYASr6VdR
3qum3LLUnAM5kslbNf+j6jW20inSggNaYa6ZyZSrK9d0TVty4E5gkROX8vCZ
dR7e1hxYqIsP4JRReZPU8rewo9ZTN6eaSzm4c8N0JZMDw/ESI/S7VF6vaZ9S
Z3EgvyDv5FnKbT66/9LZHDjSGeZZTZlvs0H04u0cKLj5pmSM8mbSUCzEgVrv
wiqOcjmBXBEteXgHB/6mHHU0pZwQS1+224kD80bqDz0pU9HOfbWTA82XRE6E
UR5dZrrOyJkDWAoz9TJlpX7z4pLd1PVATZkcyjZFVpuV93Ig9WDHr3zKIYG2
lfH7qPX/fFHj/769zd543oUD2lvjnmZR7uTjPD3sxoFXCmK18ZQFXzlY9bhz
YEjNUe4kZf1kp3f2nhzYuanw3V7K/wMPG003
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->NCache[{{0, 
      Rational[1, 1000]}, {-1.4999999999999882`, 1.4999999999999882`}}, {{
     0, 0.001}, {-1.4999999999999882`, 1.4999999999999882`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, 3.630395496235725*^9, {3.630395734190292*^9, 
   3.630395748162326*^9}, {3.630398227045518*^9, 3.630398290611651*^9}, 
   3.630398321328656*^9, 3.6304095607102737`*^9, 3.630410259291492*^9}]
}, Open  ]],

Cell["\<\
All 4 populations are driven by the pulse, oscillating at the nutation \
frequency. \
\>", "Text",
 CellChangeTimes->{{3.630409585125308*^9, 3.630409600819336*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["track the single-transition operators during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}, {3.630409623164311*^9, 
  3.6304096243668633`*^9}, {3.6304098777997227`*^9, 3.630409882017585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trajCs1", ",", "trajCc", ",", "trajCs2"}], "}"}], "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], "]"}], ",", 
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], 
        "]"}], ",", 
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "3"}], "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], 
        "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", "Hard360", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.630395432866467*^9, 3.63039547736121*^9}, 3.630395744054966*^9, {
   3.630398163355588*^9, 3.630398164199418*^9}, {3.6304095400696163`*^9, 
   3.630409550163752*^9}, {3.630409629830656*^9, 3.630409691897702*^9}, {
   3.630409824146407*^9, 3.630409867617508*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"1.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.001,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, 
   3.630395478421029*^9, {3.6303957341222*^9, 3.6303957480936413`*^9}, 
   3.6303982188138123`*^9, 3.6304095554560413`*^9, 3.630409695773494*^9, {
   3.63040984682828*^9, 3.630409869201507*^9}, 3.630410263025065*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"trajCs1", "[", "t", "]"}], ",", 
     RowBox[{"trajCc", "[", "t", "]"}], ",", 
     RowBox[{"trajCs2", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "Hard360", "]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Purple"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, {
   3.630395486202817*^9, 3.630395495394308*^9}, 3.630395738636546*^9, {
   3.630398235967197*^9, 3.630398320687645*^9}, {3.63040970121209*^9, 
   3.630409731329905*^9}, {3.630409776387455*^9, 3.63040980568364*^9}, {
   3.630409854197014*^9, 3.630409858314198*^9}, 3.630410254653983*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwVlnk4VG0YxkkkS4tdIfvOjDUVHomZM0MMLZaEiGRLpSgKpRShBUmlXUjI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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwVlnk4Vd0Xx4mQKMmUzEOGDNeYIZYM9x7z7apIplAkFK9CvEVJUpleJJVQ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     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwVlnk4VG0YxkmWRGWnUPbdjDUVHomZM0MMJUuSUMkSlaIotEeWCkmFNiEh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->NCache[{{0, 
      Rational[1, 1000]}, {-1.9819731528531912`, 1.8410900212964525`}}, {{
     0, 0.001}, {-1.9819731528531912`, 1.8410900212964525`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, 3.630395496235725*^9, {3.630395734190292*^9, 
   3.630395748162326*^9}, {3.630398227045518*^9, 3.630398290611651*^9}, 
   3.630398321328656*^9, 3.6304095607102737`*^9, {3.6304097133960733`*^9, 
   3.630409732179648*^9}, {3.630409783077269*^9, 3.6304098062452927`*^9}, {
   3.6304098500129347`*^9, 3.630409871111631*^9}, 3.630410263273527*^9}]
}, Open  ]],

Cell["\<\
The single-transition coherences are excited by the pulse, with maximum \
amplitude at the 90\[Degree] and 270\[Degree] conditions, as expected.\
\>", "Text",
 CellChangeTimes->{{3.630409585125308*^9, 3.630409600819336*^9}, {
  3.630409891121662*^9, 3.63040992008985*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["spectrum after a hard pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}, {3.630409933570064*^9, 
  3.630409938023226*^9}, {3.6304110094899473`*^9, 3.630411017477832*^9}}],

Cell["\<\
A hard 90\[Degree] pulse excites all 3 single-quantum coherences, giving \
signals which may be simulated using Signal1D\
\>", "Text",
 CellChangeTimes->{{3.6303985624702578`*^9, 3.6303985786813927`*^9}, {
  3.630398808185258*^9, 3.630398819085018*^9}, {3.630409942502898*^9, 
  3.63040996096321*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "@", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"InitialDensityOperator", "\[Rule]", "\[Rho]ini"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Preparation", "\[Rule]", "Hard90"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
  3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
  3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
  3.630396027075295*^9, 3.6303960409823837`*^9}, {3.6303986168297997`*^9, 
  3.630398660220437*^9}, {3.630398702294038*^9, 3.630398710640931*^9}, {
  3.630409971284046*^9, 3.630409996325594*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.630409997178832*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxU/XdcE+vz/w8v9oIa7N2oiKiIUVGxj4qKghJpIiIsvUOAEEIo7rF3oyJ2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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-0.0004054232598972025, 
   0.08505310816526736}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630396042375787*^9, 3.6303960716595783`*^9}, 3.6303986852682743`*^9, 
   3.630398737135955*^9, {3.630409988583632*^9, 3.630409997325322*^9}}]
}, Open  ]],

Cell["\<\
The small phase errors are due to the finite amplitude of the rf pulse, \
relative to the quadrupole coupling\
\>", "Text",
 CellChangeTimes->{{3.630398780957326*^9, 3.6303987931408978`*^9}, {
  3.630410004290997*^9, 3.630410009228343*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Weak pulse", "Chapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}, {
  3.6304100520609903`*^9, 3.630410052509768*^9}}],

Cell["\<\
A weak rf pulse has an rf amplitude much smaller than the quadrupole \
splitting (in this case 2\[Omega]Q, i.e. 200 Hz).\
\>", "Text",
 CellChangeTimes->{{3.630409145372348*^9, 3.630409176378265*^9}, {
  3.630410054917211*^9, 3.630410072434702*^9}}],

Cell["\<\
In this regime, the rf field only couples to the central transition\
\>", "Text",
 CellChangeTimes->{{3.630409178932012*^9, 3.630409192657748*^9}, {
  3.630410076351671*^9, 3.630410083268825*^9}}],

Cell[CellGroupData[{

Cell["set rf fields and pulse sequences", "Subchapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}, {
  3.630409216531904*^9, 3.6304092216056004`*^9}, {3.6304094827899113`*^9, 
  3.6304094837227907`*^9}}],

Cell[CellGroupData[{

Cell["rf amplitude", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.630409276272395*^9}}],

Cell["Rf field amplitude, expressed as a nutation frequency", "Text",
 CellChangeTimes->{{3.630395292959406*^9, 3.630395300834734*^9}, {
  3.630409246076763*^9, 3.6304092476958227`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]nutW", "=", 
  RowBox[{"2", "\[Pi]", " ", "20"}]}]], "Input",
 CellChangeTimes->{{3.63039521497709*^9, 3.630395224826025*^9}, 
   3.6304092505882893`*^9, {3.630410093108015*^9, 3.630410100101069*^9}}],

Cell[BoxData[
 RowBox[{"40", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{
  3.630395227638023*^9, 3.630395307440235*^9, 3.630395720968466*^9, 
   3.630397847078607*^9, 3.63040920612573*^9, {3.6304093422302847`*^9, 
   3.630409359745715*^9}, {3.6304100968619833`*^9, 3.6304101027655277`*^9}}]
}, Open  ]],

Cell["This is much smaller than the quadrupolar splitting", "Text",
 CellChangeTimes->{{3.630395246314694*^9, 3.6303952694452133`*^9}, {
  3.6304101050169697`*^9, 3.630410111530459*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["weak pulse durations", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.630409286566934*^9}, {
   3.6304101144352713`*^9, 3.6304101147705917`*^9}}],

Cell["duration of a 360\[Degree] weak pulse:", "Text",
 CellChangeTimes->{{3.630395311174177*^9, 3.630395319578122*^9}, {
  3.630410123996252*^9, 3.63041012440105*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]360W", "=", 
  RowBox[{"2", 
   RowBox[{"\[Pi]", "/", "\[Omega]nutW"}]}]}]], "Input",
 CellChangeTimes->{{3.630395232771331*^9, 3.630395242221376*^9}, 
   3.630395275252533*^9, 3.630395717091453*^9, {3.63040925466089*^9, 
   3.6304092567420063`*^9}, {3.6304101279798717`*^9, 3.630410130882195*^9}}],

Cell[BoxData[
 FractionBox["1", "20"]], "Output",
 CellChangeTimes->{
  3.630395242882451*^9, 3.63039530756124*^9, 3.630395721142517*^9, 
   3.630397861680743*^9, 3.630409206322336*^9, {3.630409347224757*^9, 
   3.630409359930263*^9}, {3.630410132232523*^9, 3.630410145489601*^9}}]
}, Open  ]],

Cell["duration of a 180\[Degree] hard pulse:", "Text",
 CellChangeTimes->{{3.630395311174177*^9, 3.630395319578122*^9}, {
  3.630397904837789*^9, 3.630397904982959*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]180W", "=", 
  RowBox[{"\[Tau]360W", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.630395232771331*^9, 3.630395242221376*^9}, 
   3.630395275252533*^9, 3.630395717091453*^9, {3.630397910907054*^9, 
   3.6303979175505257`*^9}, {3.630409260882577*^9, 3.630409263301152*^9}, {
   3.630410137520422*^9, 3.630410139083864*^9}}],

Cell[BoxData[
 FractionBox["1", "40"]], "Output",
 CellChangeTimes->{
  3.630395242882451*^9, 3.63039530756124*^9, 3.630395721142517*^9, 
   3.630397861680743*^9, 3.630397917956274*^9, 3.630409206352903*^9, {
   3.6304093474040194`*^9, 3.630409359944181*^9}, 3.630410145671524*^9}]
}, Open  ]],

Cell["duration of a 90\[Degree] hard pulse:", "Text",
 CellChangeTimes->{{3.630395311174177*^9, 3.630395319578122*^9}, 
   3.630397921116646*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]90W", "=", 
  RowBox[{"\[Tau]360W", "/", "4"}]}]], "Input",
 CellChangeTimes->{{3.630395232771331*^9, 3.630395242221376*^9}, 
   3.630395275252533*^9, 3.630395717091453*^9, {3.630397926446413*^9, 
   3.630397931613872*^9}, {3.630409266215269*^9, 3.6304092684875727`*^9}, {
   3.630410141300589*^9, 3.630410143032814*^9}}],

Cell[BoxData[
 FractionBox["1", "80"]], "Output",
 CellChangeTimes->{
  3.630395242882451*^9, 3.63039530756124*^9, 3.630395721142517*^9, 
   3.630397861680743*^9, 3.630397932061482*^9, 3.630409206368334*^9, {
   3.6304093474365597`*^9, 3.630409359976338*^9}, 3.630410145686047*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["weak pulse sequences", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.6304092994486933`*^9}, {
   3.63041014934405*^9, 3.6304101497599*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Weak360", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Omega]nutW", " ", 
     RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]360W"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.630409229985642*^9, 3.630409234094507*^9}, {
  3.630409302467342*^9, 3.630409315605977*^9}, {3.6304101531621532`*^9, 
  3.630410169709154*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"40", " ", "\[Pi]", " ", 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "x"}]],
     DisplayForm]}], ",", 
   FractionBox["1", "20"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.630409359995097*^9, {3.630410165265882*^9, 3.6304101703892307`*^9}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["observable trajectories during weak pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630409368213925*^9, 3.630409373331704*^9}, {3.630409457544689*^9, 
  3.630409458172489*^9}, {3.630410179124215*^9, 3.6304101795291233`*^9}}],

Cell[CellGroupData[{

Cell["set initial density operator", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304093850105877`*^9, 3.630409388914083*^9}, {
   3.630409450636348*^9, 3.6304094511635103`*^9}}],

Cell["\<\
assume thermal high-temperature Boltzmann distribution, and omit the inactive \
unity operator part\
\>", "Text",
 CellChangeTimes->{{3.6304094035733433`*^9, 3.630409424904491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]ini", "=", 
  RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.630409390964274*^9, 3.630409394832224*^9}}],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6304094014855957`*^9, 3.630409428015237*^9}, 
   3.6304101824477577`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", "\[Rho]ini", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630409433790999*^9, 3.630409442219749*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["3", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["3", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{1}, {2}, {3}, {4}}}, {
      Rational[3, 2], Rational[1, 2], Rational[-1, 2], 
       Rational[-3, 2]}}]]]]], "Output",
 CellChangeTimes->{3.6304094427443953`*^9, 3.630410182632455*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
track the trajectory of z-magnetization during the weak pulse\
\>", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630410189273068*^9, 3.630410189868565*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trajz", "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ",", "Weak360", ",", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
  3.6303956858216133`*^9, 3.630395724549844*^9}, {3.6304094761119833`*^9, 
  3.6304094984532213`*^9}, {3.630410194789727*^9, 3.63041019521319*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"TrajectoryFunction", "["}], 
   TagBox[
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"0\"\>",
        0,
        Editable->False], ",", 
       InterpretationBox[
        RowBox[{"\<\"50.\"\>", "\[Times]", 
         SuperscriptBox["10", "\<\"-3\"\>"]}],
        0.05,
        AutoDelete->True]}], "}"}], "}"}],
    EngineeringForm], "\<\", <>]\"\>"}],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, {
   3.630395712241858*^9, 3.630395726102973*^9}, 3.630398100508581*^9, 
   3.6304095009290047`*^9, 3.6304101968030577`*^9, 3.630410289014357*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"trajz", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "Weak360", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, 
   3.630395752643961*^9, {3.630410277505549*^9, 3.630410283801496*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV2nk8Vc8bB3CRVoqyRGRtky0hSX0klZRIypKiIqVEEVIkUbbiS9YrdO+1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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.78},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->NCache[{{0, 
      Rational[1, 20]}, {0.7866093841112384, 0.9999999999999922}}, {{
     0, 0.05}, {0.7866093841112384, 0.9999999999999922}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, {3.630395728971292*^9, 3.630395753143238*^9}, 
   3.6303981054413433`*^9, 3.630409504468165*^9, 3.630410200303729*^9, {
   3.630410284327861*^9, 3.630410289259185*^9}}]
}, Open  ]],

Cell[TextData[{
 "Two things to note here: (1) The amplitude of the oscillation is much \
smaller and (2) The frequency is ",
 StyleBox["double",
  FontSlant->"Italic"],
 " that expected on the basis of \[Omega]nutW."
}], "Text",
 CellChangeTimes->{{3.630409507654352*^9, 3.63040951897099*^9}, {
  3.630410296739439*^9, 3.630410336284318*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["track the state populations during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trajp1", ",", "trajp2", ",", "trajp3", ",", "trajp4"}], "}"}], 
  "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PopulationOperator", "[", 
        RowBox[{"3", "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{"1", "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{
         RowBox[{"-", "3"}], "/", "2"}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", "Weak360", ",", "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.630395432866467*^9, 3.63039547736121*^9}, 3.630395744054966*^9, {
   3.630398163355588*^9, 3.630398164199418*^9}, {3.6304095400696163`*^9, 
   3.630409550163752*^9}, 3.630410356978043*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, 
   3.630395478421029*^9, {3.6303957341222*^9, 3.6303957480936413`*^9}, 
   3.6303982188138123`*^9, 3.6304095554560413`*^9, 3.6304103596393623`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"trajp1", "[", "t", "]"}], ",", 
     RowBox[{"trajp2", "[", "t", "]"}], ",", 
     RowBox[{"trajp3", "[", "t", "]"}], ",", 
     RowBox[{"trajp4", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "Weak360", "]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Purple"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, {
   3.630395486202817*^9, 3.630395495394308*^9}, 3.630395738636546*^9, {
   3.630398235967197*^9, 3.630398320687645*^9}, {3.630410367911769*^9, 
   3.630410374706914*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwU3Hc81A0cB3DJJiKEZFakjIdSpL6iZCWj7CLZpezsPbL3OMc5R5IKRVJZ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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwVl3k4lN8bxu3bN0WhLBEJCWVJafEIyU4qayGFFkJEJCTr2HdjzczIVkqW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     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwVl3c8le8bx+31TVFGRkRCojJSGi4h2aQyCyk0CBGR7Hns7VjlnCOrlIyG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     "]]}, 
   {RGBColor[0.5, 0, 0.5], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwU3Hc81A0cB3DJJiKEZFakjIdSpL6iZCWj7CLZpezsPcrenOOcI0mFIqlw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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->NCache[{{0, 
      Rational[1, 20]}, {-1.4999999999999882`, 1.4999999999999882`}}, {{
     0, 0.05}, {-1.4999999999999882`, 1.4999999999999882`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, 3.630395496235725*^9, {3.630395734190292*^9, 
   3.630395748162326*^9}, {3.630398227045518*^9, 3.630398290611651*^9}, 
   3.630398321328656*^9, 3.6304095607102737`*^9, 3.63041037551691*^9}]
}, Open  ]],

Cell["\<\
This shows that (1) the weak pulse only couples to the central transition, \
and (2) the nutation frequency for the central transition is twice the weak \
pulse nutation frequency \[Omega]nutW. \
\>", "Text",
 CellChangeTimes->{{3.630409585125308*^9, 3.630409600819336*^9}, {
  3.6304103810516243`*^9, 3.63041041924647*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["track the single-transition operators during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}, {3.630409623164311*^9, 
  3.6304096243668633`*^9}, {3.6304098777997227`*^9, 3.630409882017585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trajCs1", ",", "trajCc", ",", "trajCs2"}], "}"}], "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], "]"}], ",", 
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], 
        "]"}], ",", 
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "3"}], "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], 
        "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", "Weak360", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.630395432866467*^9, 3.63039547736121*^9}, 3.630395744054966*^9, {
   3.630398163355588*^9, 3.630398164199418*^9}, {3.6304095400696163`*^9, 
   3.630409550163752*^9}, {3.630409629830656*^9, 3.630409691897702*^9}, {
   3.630409824146407*^9, 3.630409867617508*^9}, 3.6304104297593937`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"50.\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, 
   3.630395478421029*^9, {3.6303957341222*^9, 3.6303957480936413`*^9}, 
   3.6303982188138123`*^9, 3.6304095554560413`*^9, 3.630409695773494*^9, {
   3.63040984682828*^9, 3.630409869201507*^9}, 3.63041043283385*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"trajCs1", "[", "t", "]"}], ",", 
     RowBox[{"trajCc", "[", "t", "]"}], ",", 
     RowBox[{"trajCs2", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "Weak360", "]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Purple"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, {
   3.630395486202817*^9, 3.630395495394308*^9}, 3.630395738636546*^9, {
   3.630398235967197*^9, 3.630398320687645*^9}, {3.63040970121209*^9, 
   3.630409731329905*^9}, {3.630409776387455*^9, 3.63040980568364*^9}, {
   3.630409854197014*^9, 3.630409858314198*^9}, {3.6304104417741947`*^9, 
   3.630410451783729*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwUV3c81d8blxFly0qIFkmSSkgeqzIaErJCQvaqrGzZMq51ca9ry957nOsO
ZK8kJAotSeorofzu76/7el7nnPf7ed7POffzfsSt3fRt6eno6NT30tH9/zfv
S8vjwUhuFZfxYYLi8PPOiOM8DbW8ayon68Qd0F0nxKPsXZjASwcOJmukc0ZP
kXFPiUggLxf0uTZdmdSLRdtsZJMnvGLgyG/BO3wpCw1WDf9255UFFpzGW91P
pWjj8emuJr6zcHz9ZkpeZDkSU4qN+ccvB0ZfNSqVj1Wix5SrInEHz0PW2t2y
m6XVSPhNh3qxqAJ4Wpq/+dRdh+T3THa78qqCAfcTJnxOC+r/8OwUT6oqjMuq
NwXfbkVW3ecSG/jUoHjBl/hutxXFxCaZ7PCrg/tU9M9Bg3Y0x3djJfqgJsiq
Bz8pf9uJHm1u653O1IS2gzxdpT4IscyUNowIXQF2dqGpOyxEJJfDEiQgfBW6
r+3eqM0ionApCnehqBZkz51hv1jVhYTYH3lpEbQg8cJLtx/fu1Dld/GZr4e1
YTRHwHFDhoSm6oMK5MR1wFHgzvfeYhJySZfZN5mrA6RDHjdjF0iI3u+ti+8R
XXhF6FgNOUhG0nDpIvHodVDCySX9DiOjLvEvWQ8KroP3lMRr50YyMmLMoGM+
fgOIjyaX6T+SUfDLjZc3TtyEnWunNoLUKYivvFDmR9FNyM+90WzhQkGl8QbJ
KRK3AHv968sbaRT05aRJpQuvHvifzw+4+Z6CNuw5rCVN9eBiMv/UeRYqon9B
5vtA0AMGcY40yikq4vjo8xK/pAcLN28Lb12nooMnZAKMT92G30/4+MecqOiY
7QfZAx63IU3K5Il2FBXJFmAXBxtvg9Gm/KN7eVSk/OEGNmrnNogEnklkbaUi
rSMM1zXU9UHxvWPK7WEqMrjfvPs3Uh9s038knH5PRVY5LnXNg/og6TI7jV+n
Iud3Rx4+OnAH8MtP+XLpupG36JSQjMkdYJrwkpRn60ah954Pfcq+A03S85rm
fN0oHqcemr94B6gSmos8wt0oc+b3BQspAxBKLu81EetGRUIVnwXdDYDsgNuR
PdKNak2s8eMNBiBZRj+OFe9GnViB2/HbBiDldexjkmg36ns9wKitZghHnQOF
RQ52o1f8oc0MkYYwboXPvsTdjeYNLzp3DhiC373V+dW93WglZeWwL48RaP4L
z1bYoqLN8dzxc8ZG4CH37o3QVypiPHA3chVvBHH2SbPpb6iIS5/tUskHI7h0
9p98LZWKhJO6Vh+cvAsHbDaQcxUVSY545Ym63QWxcaOUvjQqOscpbfSm/i5U
ZOL4h59SkcrNhX0pW3dh85DHaoAFFek8T+u4qWoM8bWnWWZUqMiadc9xSr8x
FOpzM9dsUpCrTuNUILcJqC1EC5wboyC/aKc4xbsmcFTGHD0poaAk5smfle9N
wOl8G4P+bQrCXY0tdpA0haGEmjcb4hT0IlzV7JirKaA9ts2ea2REZCgjZfwx
hS+Fwu0skWQ0oG7lZQBm4EQo5pa9RUZTIXxSnOFm8Pvl7WEtPjL6vhuU9IzL
HCqknHydskhIdMfAyk3iHpz6yLl8PbELSV3azyvlcg8wD4LPvtLqQvJ+qGex
9h4Y6V1Nit8lohubJ8+YqliAhIDFg+aHROT/699fTUNLIJw//GXmWidy8Zq4
8bzLCqImBD9cLWlGvVYfzxx6bwXB9P/52W00oWO6W9wl9PfBWq5pwk+tCc0e
FpukaNyHa+IuxIHRBnT9pZPFDvU+UPJZOk69rUVSwgxuTn3WYH8wUoTZqgQt
d51N1B63Aateac9DrVdAvVzT8/VPG4jo+ZbmctwNstPuGtjy2kKNvKKJi50/
GDoFCIYY2sLR/fkPujdjgML7Mqf5tS04Hb9xeVQ4E/IeWtVIzNpBmdio2T71
Evh3+1Fyw44d7DW9cO9eWymYKkc80RB5CJMLsck6Z8uBm7tc0dLiIcgw/NW0
4qmC4NbfXWnzD4HpDZF3WL8WLNkTxpiW7KF0wmYxzrcJVMTvKq0xOsA7suY7
Fq5mEL1wOG/6mAO85Zlp+ZjfDHPmVR5VNg7A9W/bO4PcAhblw1wmiw6wFw3t
OC+0gQox3UeD0RGSBn79wN9vB9EJy/nTxxwhK/31yZG5dpjb/l5Fb+MIjD96
9NhHOsBCl+tW+QdHuLF78tVQHAIVy6nGNAYnKD6kxLPyE4HooxzRkKNOcEa7
+uHcKSLMZcquGj5wAoGbSoLlMUTorNw0VA1zAk3B6eroJiJkk4gdUvlO0Pfc
O73mPRHufdF7vvveCQz6dElj57pA+Z/gf5/pnaH3nnI11aQLhHkWzCeOOENn
xEHVjYAumFX0kC6xdobUUa8Ypq4uaL+hmJIc6gxdH5+YvHvXBbj7e3YC8pzB
nKPh58pOF5hHJ/Xrv3eGA+uK5VlnSaCMNzl3md4FhqOFbylqk0C4RjxL4ogL
8Nm/6GawJMEO5TM9j7oLFJxiefnHkwSzUzWOO/ddgJI2pSQUToL2Fd+x5RAX
8COcOWOTSgIcnbrSaK4LLLVnf5zMJ4E/7/68ti7a+iPZCY9qEphLju0rWnCB
a0fuJ59vo/ErZ3ok7nEFNt4D66IUGr+e9Rs/cVcweR3wVbafxv9ASs1WzRXs
FwRLHEdo/N7rL27dd4W3QSGhA+M0/thWLqUQV1ATNf9r9IrGTwj1OZZLixdl
B/fTYv86nXmOLlcIrNUY/zRGArMeHq0/866w59lD0fUhEijNTFd9oHODvZcG
v0i8JIHQ9zyBITE3kJ8fzI3tIsEWvVNQs6obfDarfiPaTIJp/nMf86zcIKDG
0fBDOQlapbZvPg92Ay2qBeMMgQSZKuRG7xw3ONrIQ8+SRAI//VhRa6Ib7J9Y
THUOJoGp3Z2I6/NugLncJsfqSgKRDnbvQ3TuQJSp8lo2IQF7z49SLi53mGOt
l9qjSYK/I6/mmMTcIf2ckrqFNAm+TbfwbJ9xB+aCwWm6AyR4u4i/ugbu0BlY
fWnldxcMrob4Ld1yh5s+Hq+OznRBBb3O+2E3d6hZrVGLwHUBR3C40eEQd6A8
4PzS490Frn+Jfa4Yd4DxIbVDt7tAZvNiHXuDO5CNEt+w/SNC/JNHEve63UGg
dDSmcZQI39crs8pfu0PxlPlAVD4Rqr8df6a75Q6bhP0CRDUicDnd38xk9YCa
S74SchxEcP+Ec/4i7AEmUaylgzUIzn44YBgNHpCVf1zLfqwTaqf2nOh55gGx
15hjTVfagcfociZ/mgccbmhWZXBqB89xHw67Yg+4i8fiS5fb4NzQ9w3GPg+Y
cvY7pfCqFerJb3vUOT1BMYNpSS6pGRorWxw6Mzxh6ERbbUFKHfBL//eWvcwT
rM7R/cj6WgteJbL699o9IfBe7kqrai1cLChW2pnzhMgPwqldS9XQnJHKqnTs
EWg46xc9VCqHtmceFQ2Vj6D8uJmZ7IscIJqe/FFOfgz1A4soTT0Oxf4NLpkY
fwxiNxNShWcTkVHO1P2dD49h5f4VE5mUZPRtKXJMl/EJBNXLsLJvY5GQx3Ld
F80nUNv85OydoVz0ODLfS7L7CZiH8HOb7pQhkNqW0Zt8AtwMihZ/z1eg/YP6
H72Xn0D3WQb2u46VKJeH3rhnrxdUTX1ZtrStRkN4K0W7a14ge7TVC1XVIsl6
kZ38Xi94oxAuFrDQiH4aPanvn/ICjaTjWXH3mlDnnwHnn5+8gLvpxG/5103I
EPzfqu/zhuu2Jy5eIDej0L7pzgVtb/jvUnPXK/9WdMNFznufqTfUWlzQbV5s
RYJcMWfOOnpDvKjvzKp2G6oyVMwJjvGGW/yMEkps7Wh2Pj3kcL837X+PcSTK
rQMVh31XvDbjDaIMWstaXR3I88S1ddev3uB4UpTlJFcn2ue8Yd3J6gPmnFKq
Fwo70QTHzUPLh3zgancLk/HXTpRTUzjOLu0DLyd2L0TJICT/20Dz3nUfcNtQ
yN9TjtCezPKdZ+Y+EH+hjENzGaEBZcaGcmcfMP35V4zMQUTYd2YuE/4+IEv2
HXovSUQPQuuO78T5QKbywMcgNSKSOc46dxTvAy1UHpcMYyLa6rFO063wgdFP
TyNkXImI6th681GHD3j+UXymEkpEiew8zFmDPnDmkcdcbwoRDRzt2hV+5wP/
ybkqSRYTEbOS+2b2mg/4Wu/T7GgiInW9wz/E6H1BrerxSmQ3EQXaDX3OO+AL
EQNGZlHjRNTqH/D+2HFfuGmeuNo5R0T/YaRniuR94YX0lqL0JyKSLZkZl9Ty
BYbXwsyj34nIGcUMlJr4wtrIgkHlf0T04pUiVdrJF17+vXyX+oeIPnz91FHp
7wtKY6+8BHaISJQe2ygb7wt/hLL0imixqeC1qlqCL2z62DQ82iaiNJmN4vM1
vsBXFFgSsklEY5qFOY0kX1BIu2gz9pOIOMwMMhQmfEE5+sEt+29EpO3BgGld
8oVLR2f3Xl0iomeRtTHKv31hK+fPXdcZIiLi74d1svhBNuxVWxwmop06Ln9V
IT9Aq2VrpSQiUuhDj0mn/EDb1pxKrSOix/OuLpqX/WCnpu66Qj4RVW2I2HXf
9INvVq/U9yYR0Ymj/nf7PPzA51aDHoXmh6wVT+ldD/OD3jxzcrseEeFvTWsN
pfjBYLS8ibgCEfH6KyiNNfnB6L6VUDV6ItLDfJQzeOkHS2Lvk9n7EIp9kXZq
ctoPxt9Mnk2PQ4j+1S/h6b9+0IHJ/DDKgpDK13w+c86nkB2mMYsldSLfPXc4
5sSegrnEibIY3060drpmd0HjKZTmMFJF3nWgdxEu7z9HPwWjUI1vJjHtSAgv
POOU9RQCVhbjB2XakVFd//i38qegJykzMjLShobenaT+GKatj9hf6GBvQ+0K
y8V/+PxBrPZYQKtzC9q8mZrzVMIfTNRPOsjvNqNztpoZfxX8gW4wEhoSmlFp
Ul7MHnN/6BUqI26WNiHsFwuXfXn+UHygd0lnoAE9wb2WOygTAFdPcFkd7q1B
ntfuu2pDACQsHBIp0axB7utfSnz1AgD++6asSqxGzlr/xKY9A2BR6ctUmUMV
sv51jDOrKQC4A+5ZN0iVIb3rnl+F1QIhNnTORiksD938vX3ihn4g3BwbJPc6
5yLdvHDrgAeBIPaVxcbeKAdd3cS+eRseCJX9bEalBjh0uQD1ZPcFgggbq5JZ
dTKS2mErEDMIAmWt6QpmQzskWZz2Ts82CEYyxxsDXK+h4/pih0K8giB4ZDBB
kc4QxF6cwyxgg2C6LG2Fw/kJCBiYBue9DYKLfV0PCN4xwLv7oW1sNQh4wPN9
4a142Peq8ekeumCgd/70B8uRBMzBqk1nuYPh7G77l5b+FKCfvCODORcMEvHC
wlm7WRBSJnhdSjkYTmflqG+144Eu5K0DSTMYtO2Wvg4+IsDfUw8L1w2DYf3C
3HmCXS5shvgJ3/EJBtxFzY9NqQXgfReUvgYHQ+uxhBld40LYkGY0DosOhiNq
ug8OCBTBr9fPk+sygyFoOoCXMboYvp/O3c/bEQzVznUu28qlcIz/sY4gNRhc
7C9LfZ4oBeN/V2OEB4Ph20XrMjmHMiAOrew7/jaY5g/xLC0R5fCrEWmfXAqG
rSPvd5c5K+AkARN9+lswkPY4r+unVgDGTWGf/N9gMA55Ru5PqYTuu6zaSkwh
wOqcfX6Qowq2YC5KhT0EdKa3qf89q4IHXM9YromEwCzHvOAruWo4XzPMbHw5
BHgtvV4J71SDfUbeNfMrISArFKoVfrIGcCFPIq1uhMBZzjcvfxnUAJP+IWaH
eyGgIfmqa7mwBpSUVq+62IZAbwI5376/BlyPdEV4uIRAz5c1h7XVGphct9vr
FxACUbMpRB7ZWtg/o3g1MDwEwnP8rCtv1IIKmS0i9DmNv7Bmv75DLXiWvaNG
pIbAzz4q6V9oLRQn1zLF4kMg7D5dT0NmLcw+Db+SUBgCHle/h/tU1wKXjXF4
ckUIXBxdJmhRakHz+ilqekMISBEClyUma8Hn/D9GXEcI8NzdZy64XAvlwqOa
OdQQOO/HfE74Vy3MMxY8KxgMgVMmqYMX6OqA95sX5cWrEFC9MtH+cH8daL/S
Zqx4GwKlfLeI9Tx1ENghrFmzFALBgqbUwwfroLbwe1jDtxBwiHZdLhOpg+Xn
JHLLfyHwqyjE0VysDoS8Uhk6/4aAcPBdynnxOrhpYa9BYgoF75TRJAXaetjV
S2Hd7KGw11oxy4l2vlmGg9zHFwo62xFjo4J1sMK/QD8sEgpviPn6bjR+sd06
9fHjoaBuVmKhRcvP4GNE6OvToXCaS+T+fVr+UcMmpJkLoaCXKPG1k1ZfR5M0
/fzlUJA3fVln+7EW1gm7aotXQiF7mDXddKoWTkSNhXy6EQoOQmdS83pqwdS9
sGvFMBQydidG1RtqId7YZ8+Pe6HA2yGZrJpbCyRVXbX/bENhmJtRLTe2Fn5L
iob8cQkFzXhuG8fHtWD1h0xHHxgKlyQv919Xq4WUhTTVvRGhkF72qt3jeC30
vnQI3h8fCmplvf78LLVwNpOT7kB2KMypvqLb7K0B+ktmu0c7Q4FypJd3ULEG
VmdNLF91h8LXtbuPNDlrYCbQGEUM0/C8p3IvfKiGepJh0Of5UPgkm1nyIqIa
7HT0disZwmA0TPJqlm8V6K/ctLRiC4NjO/bTIrT3APE3EDdfGM2vn5g7nlMJ
gmM6QY9PhEFiustBno4K6DO5squoHQa79bz9j2fLoHFbw/Lr7TBwLuC8csmy
DPLx6ghnGgZ2maP+4vOl4L8AQbtOYTCptRyfNVsCMg5Ku5T4MLA8KHLRmVQM
ST5ndm9NhEEU04X0PP18CBSSsdzzNgziX3WWJBHzwLFdGtUuhYGcnyr+9ek8
UKeTCuL7HQbWB7aV6vbmwq/IY7vTB58B3Y+zEfce4sE4/eCureUz+CnKkZzH
mwJijQy7T788Aws/Htx2430gOXKFZKw/g0W6z28am++AzWERhqatZyBWdnbZ
P0sWXkTJM6/vD4f6n24yCvGmSNbMgdP+VDgceWJ073bUEzTG6ZUUfi4cWCX5
byRJ+KLHlNAD+ZfC4VUekvjX5o+aT+ME5nTDwRwTxEVdCEFAN3zYwDkcwna6
CfsKotB8/Uyux+NwWDgZvlByJQaFOnw6muAfDmnyR5YkFmJR99geyb64cCit
SJV+wpSAbhael1WtCAf3Y9eEB4IxyEInU1V6NRxIXForPXPpiG63iKS9EQ7S
8V3nbJ9iUV5dnebDf+Hgs97GlM2bgZaFB7XyOCIgtu778XfKmcj1+66e4JkI
KKWufMu3wSGuArbxCxcjQO/svkrRZRyqNT5oeAciQOHSuddKNni00SVnEn8r
AuateOetjbJRQIrtfUb3CACm1lnnfTlIVNvzg7hPBLRzbWq/V85BxL+BthAc
AR4dRNUW1xzE+BDr4JcYAS5c9z+nD+agokOFX9OxEUDW9xYp2spBWiM1Lg05
EXDT4+rbIydyUZxiv8dadQTw1z5b8vLJRTKrr3+yt0TAtRdLzEaEXDSSt/jk
VFcEyIq6Pqyj5CJetn++dqMRkJV+9fLW/jzUSNy/E/YmAmRe/uxYOZWHjJ8I
BOYuREBx4OpzN908hJuTDZ39EQEqeTn5ihF5iPC29PjonwiIefSXypibh/Jm
j72k7okEo7VXvSGteejFtCBXFXck1Pe+jS38nIfK3mDq8g9Gwt0my1Sj3TxU
OcV2FyseCSXLEZxDB/JR/SRddsjZSMiWGBw7rpiPml75qXkpRoJJqsE+bp18
1Drxa9FRLRJspAejpkzyUce4a5SldiTgXI7+CLHPR8SxT6cMbkeCio/fGo9X
PiKPWg9rmUSCn8gntaTQfNQ9Mut5+X4kmG3KltPH56OXw0b8cg6RkN78jM4F
m48GhkZaTnhEguWE0sHJ3Hw0PKhz75BvJOiNJExplOajsQEKHVdIJJzReyDR
XpOPXvWrFDBG0/AO//6p2ZyPpvqar/1JjATqgyrZxY58NPNS7us3bCS8PDkx
RiDlo7ne8vj3OZHg6GswGtCdjxZ6Tsi9fhEJo8djjz57mY8Wu3Ne9VdHwkYY
E7G5Px99pAr5EpsjQVzpepb4YD76QkkRbiBGApNBZRGFFn+jDSUlvTQ9BziG
i2nxGinqQfZIJEw01m+PDOSjn130zMlTkeCtJMp+lYa3QfQvjZyPhBMRkzNs
NL4/aOOG/6dIMF29efEULZ+dTvcf7muRcPJe22IRLd/dji8ptpuRMKS2jg/v
zEf0HTYKpnRRUCmpxzXYko+Y2udmbrJEgeoJwkxofT5iaTMO0uCKggEV+qTy
ynzE2jp2REEwCtjWF2tuvchHHC3Xu6XFouA57/dKD5q+vE2q7PyyUVDDLFJ0
DZOPBBpbq/crREH73sRje2PykVDDeYNdiILpvaPhxiH5SKxOMuvTrSjASfNy
D7rmI+kqrpNtblHQYKDJFHAlH52pjBmo8o6CWFb1j9ZK+UiugtG9IIjGJzfu
Qn8mHymUbTY+T4gCjrES3SCBfKRZPK9pVRUFDzyPf323lIfMCNVWTN+j4LWA
81G9p3mI39joWPHvKMh++oJo7pyHxrh2PmrRRYOj0dlfBvfykFboNbc47mgo
le+r44E8dN52LuDA+Wi4VrYjQE+fhzhOsWWJ+0ZDspBRyc+IXPTyQ40FOSQa
HqQ8Px/lnYue4e4esY2Jholt0ytC9rloiz2/5EVWNLhbZzKf185FH9cUm890
RoMIx9fXIqy5iNj48NVlhhhI7pWROByXg566sWe8Y42BJ51fT/Q+zUHyknXm
Ibwx8LaHs1HXKQeVZ/z7QDkeA4Oxohrj2jkowz91XVcrBtQtxq+4M+YggwuX
Gr/pxQD27Bu9jUUC4lqd900wiYElAfv9/kQCirCU3jPuGAOdgjqaVU8IyFOd
zGn6PAae/V6/Ff86G53eth/fTo2BHpMz0rsV2ehTHUc6PjsGJOUZqqPDspHF
cVPRhaoY4PpEyG0/lY10WX5I24/FwM/x94Jabni0tyttbd9MDOQe/epz4TIe
kXyV68s+xMD9BmLr9D48Uvgaeen7rxjQdBfYOkjAoWNDojpeArGApp3EGZuz
UErG2Jlnh2NB+cGZYp/ALMRkG8GHkYiFAifOPi+NLLS8/W2+4mIszK1kSS/3
ZqKSkx3eS3djIdEX2+JGzEBC/7nf+2kZC/9pytpy+mWgGOIxjT32sXDhNFfx
8tkM5Hw3jkPEJxZmn0T58uKwSCbcrNAAGwtM0/PCVibpKFuPM9Y6Jxa4SB9T
KxnSEacw2d39RSyc39RX/1yWhtZqpZTjmmNB0lMZS7eRiurm/4yRp2LhL7/8
1RG3FHSsvKJ5dD4WHN/Ly2JZUlCK9/3sd59i4fhtjVw2QjLy4njpsL0ZC2nl
qP8dBYMUaDDnDsaByp+egqCfiegF8/VlVfE4ODjWbL/lk4gOju/23zwZB/N5
kgeXfiegLYeH6Y6KcWB2WzII8+s56kiXl8kziYMp77+HblVHI5kHXw5U348D
zVnI1sREoWyZ7D8dDnEwfMFZl84tEgVTmahvfOPABFP0uUMwHKn/nDDjzoyD
LJcnTCdPB6Pazii1w3lxcH1DoEO9LwAdjVGWOF0aB2oM+sPNZ54iRvGCda3W
OLho6WF3e+YJ6r75KDp4mhbXjTe1ONsi3VLupu9Cz6HggcTU18+O8PjMj/bS
o89BqodB5sUXd8DVj5BspZ8D+b+ejlNOj2G1M2Fo5vJzkLsSVv819ilgxtmX
e6yeQ+T1ztRbR8NhamcfX07RczhfMk+qM8WAzS36R3py8VDhIBp4KzIXnk8s
+LBeioeNzQq0yZkHjSZdgd0a8bAkKD5ags0DZpvgGGXDeEjdCBtbLsmHUp9/
uZI+8fDeVrBHsK8Q1nK3Rug640FZRUNP4mcJHJSYnmzrjodfWHbB0celoF7e
Mus1HA9KdX/+e/pfKSQ3+nxamY+HsKND5fE/y0C+f2N3iiEB1g/iLjbPV0DA
r3WZGu0E4Bb+JouaqmEvBYw09BPA6ptERODXakhMjgt4ZZoAUeyjzEqiNVAg
d2Lgj1MCNLkcvvMsuAZk6B/9jH2cAFyLHhn01TXQPIqERAMSQCr4EIv5XA0M
uJs4qMcnwM5Ezdegi7VgpFqUOJGWANks928pWdPmE86fTXaEBGBzD2irovnt
n5Vxe2OrE+DN5Umj8ula8A98c1qkJQFSNX5xHqP5/703TxhWdSVAn93Ix4vH
aPPHN5Q/PpYAy58OsPHb10FBO1u/7UwCxNHfKhqNrAOZOJP13x9o54mP/rIW
0eYPs6KDMSsJcNm7Y7eDVAdqp36qCv+XAHbvTrXOv62Dvi2wr/ybAF0PO01c
fteBlG33NTGGRBg8WSF9j7Me6s8fcKtlTYTsl3P615XqwRfXErrNmQipa1E/
VW7UgwqjVZombyI4KrXbPLWoBwbnvaXPBRNBz4dUvu1SD73j5R2TwokwWnhx
q+VpPTy/dGf0sHgilDKeLqyOrAf9/D+L9scTodBUS3Y6qR4EWHM2a04mQpDY
O+2zmfUw63mVbft0IvQ8YR+szqmH3OmVw5pyNPySXtKdwnqwU08+91w+EZRO
frPme1EPp0oVr00qJcLjimt8P2jxGve86WFIhF73DM/3xfXQ4Bvhaq+RCH+1
068sFdSD34J0aM21RLjz9EPsfwRaPdrjqVu6ifCcnd6bM4NWT41viYZeIgRH
X3M5k0irR1CsI84gEaY/d+3XD6+HuODukVfGiaCMPXTksU893P7kvCh6LxF4
b/t0YBzqgV/vwObD+4lAJOkeLjOuh5mmFtYa20RgIp8kt16ph5zDVoe3HGjx
fwkWSLYebCP3ntNwTYSBphcLjQfrQep7+dU4z0SwusTsQ6Crh+9Gd0xfeSWC
WZp5tPdSHdR3/nERfZoId9uOt17urQOV+Kup1WGJYCH/ARJp94FhY+XFn8hE
kHkTduCQTR303ktuV49LhF89gkxJKnWgf3r+w0QKrT8Bfzcvf6sFgdSI3yIZ
iSCmPeP9pIs2n+9Isz7E0/bfruXISK4FuwFfuT+FiXCMfVj3xdla8HU6ECLS
lAghN6d/cxrWAHaWWCjclghDfwskvwvT3scN175DKBH0m+np2Wjz3eaZlweE
ehLBWDzfjcWxGrx+BRbxv04EWztT56buSkizle7nm0mEgIe20StKldA4+eY7
7ztaPfESD4fKKuC/5vOKBz4mQrwNR1NzWDk8DvjSz/k7EfaUaEqIsZdCymr6
Gsc2rR/DlD/VD0ugzvIKH8duIuBkiH6K6AWsq+VYsDEnAeZBoIuFbTF47DX6
wSKQBG/FFtC1hAJwTejip7+YBEvuSBzXh4N4OrdLey4lgecbefFuqSyo8BC2
ooMkENdcMsVFZMDKHe+Sf1eTYKo4RejV2TRwEjytvG2UBAs39jPn1seDfS72
/i+vJPBRatEPU78N1nVu5cuNSXBdfGKXoR6HLPacu6/clgTqN1USqlqzkemt
DT4MSgKVD07WJ6xy0O2v/kGXe5MgdpV7pf5BHlI9GqOf8iYJ5hfMrdQti5Bo
csGm2k4SFJV7bhuwVyKhhYcV6XQY4LknzfLlTyXiP3PK+hsjBpy9PtVyLlYh
9v6afiw7BkiGzFd1pqrRDj3K/i6KgX+y7Oq5ybVoUy/0zpWjGLDnYtiJ+1eL
fmZfYcmSwMD2nQsf+x7WoS9KAx5XZTFQqMJ4lfFCPXrj+UYTr4YBjvG1mKXm
BjRBxP1Zv4IBy8OSdtO8jWiEw6pSSwcDp10sT9a5NqLe0mWBX/oYkJd95jR7
qAlRNksGtO9iIFRY9+EBtyaErrqEEMxo+HuctbZRE2p8//OLjg0GXoRMb5ab
NqNa2SZCjj0GROQVflkUNKPKQD+DDWcMUG8mymK+NqNCoT2duU8wEBKhY3TL
swXl2FM8f/vSzs+u6JNrWhCuMVLiRiAGdm3NWuNWW1CKPkfSZgTtu/WkvX/D
shUl5oxeuRmLgXflpwrDUlpR3GrKVn4CBl5feaqr0t2KopSNq/4kY2B2kRor
8l8rCos5ZHMLiwFPb+tAQfE2FDg1J1iIw8Bwo1HUCZ025Hcib3ArBwMFPl3m
4N6GvB7bhuoVYiAYq/zPNLkNeZIkLxaVYEBGXZ7oUdeGXLlWvm5XYMDAXk3L
f6QNOVpU5dyuxYCs3L2ER1/akF25p2FxIwYaZM590NvTju5vXdj/txUDzwWv
f2Tna0fmWn869REGAraV0gqOtyPjtPZHL8gYOBHTqc55rh0ZLAZJ/uvBwEmv
KazW5XakJ6fx9s4ABryzprN1NdtRUTR7vuUIBjblrjN8u9aO/s6/tneawMCh
5PmwVi3aeYU8Ge8pDMwJ2a5WX21HpQnOv0JnMZA68ffuoFo7ovso3xo/jwHt
AiTCrtSO7qrsCc5cxECvsMaSy5l2VJnaf6XoEwZEl87gv4m3I8Zvqay1K7T7
gCUGxHC3I1NNq9GONQz4sMA+jX9tqCZLKv3lLww8mvBh4//Uhlh+/jJ/tYmB
VXlpAv1wG7LQQUcWdjDQtsflGAtNv/rc6E8rdMlgV7VH90RKG9r/507lJmMy
zD1tZr/n2Yaaij8pcrEnQ61d7QjfiTbEsVu7e4g7GYrar1zJ2G5FNkYBVAm+
ZOBhZgeFoVbExcRzG0SSwePe160hx1ZkZz7LryueDO1fZzP7zreijrqiWaPj
ybDrsfz083YLcrS+ZO96Ohk+Fu1w40JaELGFScbvbDKoJZlzy6u2IAHukZ/h
F5Jh47bd8u52M6IgmyD85WSwHNfdknNqRqIi8WkDN5Jh/4ELe9Mlm9Djx8bm
U7eTQbYuaPj0aCPq7z9yZNEwGQQ2SBzC3o3Ix6+pYvseLR/Tu3aCbQ1o7PU8
Rco1GYyFGLjvHKtHkmfKYuQ9k2HVkshm11yHgiKe6Kl7JcNQ8aOf+3XqkPSF
/bMmgcnAGcAlftquFkVgzv2Mik+GZGReMRFajWY//21OwSRDlcBOoxdjNTqn
1huYk5YM1aaKi9+Yq9D8d/P9zdnJcMv3trzfn3KkdCNC/GNlMrRdEnh7seIF
+sb85taV4WRQCFDJOfQmG4kptxQWjyfDpRiTTANFHNJ3z9jeN5UMlJoQHYXk
DNQ8ZVI8NJ8MTA0bEkcvpKDQkul/d9eTgf4SX/nDR6GIX3e2wpEvBejwZLLw
SgxoBbUzDB5Mod0fKW/5u4nwtA5nckY0BTx9v7V2KybD/KF7TL9OpADHt2XD
oT0ZULry1jxAIQUejuwAn04e7Xv5jjXRLAX47nq8sG2rAHcSur9umQI3iWd0
Tx2tgvwNQpOBTQr8tpXJ9NOsBhZLqwcHXVKgPBO+/iqqgbEzC615gSkQu0+E
zdC8HhhturiYwlKgspAxaZ2pAS5ic+0eRqZA0kry3U8VDYCjs+aRTkyBPq1X
w9GbjWA3+t6hITcFqJGnWBy8WgDLREYCRSmQkGxoGsfVCv2K+Xx+pSnAS9QO
tXvRCrJ5D7pU6lLAGuTV10faYMtzUbCXkgKB8S08JgydIF1McZV6mQKSJ2Tk
j0Z3guVMASVuMAU+7aez4WJDQNGwdb89mQK2F7ViIxmJkMC73DP9kVb/yW+9
y6tEWP/mXym5QuMjSz5/fKwLjHoOpHqtpcCebvxba+MuEPZTs+b5kwKYKefk
K21dEHRnSsvqbwoczvTMlv7SBe+l3c5U7kmFwmcToSYCJHjxDrejvT8VHjGB
oLMzCVhbzn1I50gF3ImJd1dSSOCK6Xu5xJMKJ96GVN1oJcH5K5tpIYdSgeTJ
XTlKR4Z00YSA4cOpYJqfFKghToat38dtRI6lQn/PXNYQkIFYeudsizQNP25U
SdSbDEeffRFgPpsKRYvZdNMJZIi4F/LP4EIqVDwdxeGLyPBZXnApT5GWn0G4
om0bGa5zVfWvXU6F4hR9hdNDZKj6fKVWRT0V0i/Nyq3PkYGHPIuNu5oKf72N
t6u/keEJ7lHQtE4qjIXw4O22yDD1ZL+d5K1UoH5aMudiosClW7nXve6kQoNG
XUsZOwWyJRXOUe6mAtuZIWd5XgrsoR8+yGOeChHRNo6VghSwmbGls7JKhddz
cwvchyjQU7+zXGGTCp1riiqWtFgqPnlw2z4VHPRMTqQepED8Q6l6bZdU+PdH
P6CWjwI/VLsy0z1SIXGpzrqRkwIGQsYhS09o9YR0yOUwU6D55+rDc36p8JsV
F+H2lwyHBsNvhgSmwnZH6vljP8gQWCR8YTg0Fcwocnqd78mwEFR3SCSS1o/N
e1IqY2TQNNGhd4pNBSf9wNsFiAzFcgufmhNo+h6ITvpRSob9bD7De1NSIQrL
RntmZHBZ4mg0wKbC2utzxCtPyTDSWYjLw6WCbjjJ75YVGc5hlcPWclLBY2Lf
8hUNMqR5jDuoFKbC6bev9pw6RoY/Oo56cSWpcA13h3UPAxnMj+25OF2RCvKY
7/5970hw5LUMo1djKsSRn9SpJ5MgvJr6hdyaClMT7/G/HUjwKdp8lBulQo3D
X6VyFRJUKsdkV/TQ7hN+0e3o+y7g5hcP3+5PhZjHxhyr1V3w+HuTk/YIbb+h
gHNvQBco5S0pLE2lAqfJnp1O7i7AP/U/fO5tKmy1fNm/NEUEOsMDe0MWUiFQ
pCZJJpsI3cxq48JfUmFDTFZe/SgR7rjgXAy2U8H8bXv7CdlO4NJTsjXeTQVF
88NOWWUdMCQ3ZW7OkAb6mEd9ksc6QGfzwHUb1jSYYOf2aWdrB/WwWKnHh9Ig
oLffVKyjBWQz/D4mX0oDkZlavsSielh9KvguHdJgU17Ir+hPHZRbNE5maaRB
zGJHWY1OHUgcW6fm66YBq4C33fJyDYhWORTUmaXB+5M2vScPVAIb1fj++NM0
GHrspsrFkQd9xRvGr4PSIH39/EhxaA5ExaTozYSlwe/bUT9KvuCBQW8EPsTS
8ntQxMxWlg5b09dEf2alwXKDx0AeXwR8XpOf4WlPA+fZj/E3V+JQtzCfof5O
GrD5sjYQ+KqR1WzvbDldOgR0XPwZs1iNtrL8bZiZ0qF3YeVYR00Nkjm0+Kid
PR3wtRvx6VfrUOrBOsyJw+mwc2q/WfrdRiTzxk4o5Gg61N9Q+HOKvwn1YoXy
ZiTSYTWaInVrrAntCITWJMqmg9Wvk6Gf1VuQDf/tkS21dBjEE/kEGNrRv1eM
xoZX06HP81tJT1k7wqY2v6vSSQfJy88pFrc70ACv2HebO+nw51ti2DqmE507
8J192CYd9FwVF0e8iGhgLC/1pEM6fEcq660dRGSHMRJ55kI7z2OyNUTfhTK5
O6UVvdJBWrpgr0FkF6Lneq6bH5kO5dVXb/z2ISHcsOr431iabiHZ9IbVJCSf
8MvUODEdEmuIzjlLJOTIYe7InpEOChEHopa1yYhxiHP9IT4d/L/uXZ7wIaPs
52RfUm46bCjP38EWktEo26lo79J0UCRdto/aJCPHgTmuscp0SD95tq5UlIIY
4zBY6bp0CMFqGD9Xp6Bs3atikU3pULmNHzhlQ0EKrFvFC23pwFFW1xMSRkFj
fRVnlInp0Jk9oRGbQ0HOMfeb0ijpYFrXFKjZRkF7dfjgR286aH3d+VMyTkE5
+1526w6mQ21m8dPmzxSk9NL/ZtFoOlBdEjlc/lLQRJTsJN1kOigpDtNTOajI
VWvxntl0OjRGCK92iFARCwt2qWEuHXqGpMoNpagor0fXhetDOlw2+G0Rc56K
lCN3fzl+TIeBFB43U2Uqmrxa50/9mg7TmvOxFDUqctv7kFFsLR00BobKejRp
eN1CcX6/0oFeOYLtwRUaXvjQgVeb6SDTwHEuTYOGdyU068zfdKhRWv1qBTQ8
RvmjMXuwEPXpsi5ZgYrcKZ9LF5mwEBDXWN5xhor2P8PLwX4slOLq6/SOUVGB
xu3WDA4sMMac0w3gpyIVBib1XzxYWHYhFmrupSK5ATTNKIAFLp//zv3+RUES
qX6P+A5hoWxR8kPqAgUJW1xgO3EYC5LvbhseGaAgLom1AvmjWAjF2lpn11MQ
01rp5WsSWBhVkhVky6KgrWbbybunsHD0tGSrSxAFfdCZYfY9h4Xb9dgZflo/
pw6k5URfxAKDmdvKAzEKGpjVU8y8RMv/USVr9Q4ZNbp2O7ZpYGHquNiMfhUZ
lV4MYRi4hgVuMxVidTgZEeiUcbO6WFDsXBUWNiWjKEzN4N87WJi4Fj9z6i8J
+Zs523EYY+GTihjrm34S8jgmsStqjoXPYjXXC7EkZNqIk1W1wcJv61ZypTQJ
nZ6OTA59jAWtgRUdIehCR/LVpZN9sPDh+5cnd3aJiN/5LyXfHwtB1l/2TdHe
D90/zw3KMyxY8t9geXuBiMbELUyYU7FAv8/5/onjnaj7i+C6QAYWyjsTHLtj
O1Bb3XiMJB4L0ylRLs7f21HBFe127UIstI5qsrNUtiFvh/OH4xqwsJM5R6ey
vwUJ1+xf4prEQr1YdXT8jTpkq9rkLiSQAQLjd9lX2DJRTKVkJv+hDDAcLIzo
pqahauFMMs/hDCio2B+i7Z+Mtjb9+VklMsC7yIf7YE80iq9Rb9+WzwBiNkel
N9NFaDoyxPzWKAOqp8hRuIFMmE2Es29MMyDJj/MM/4FsoN+tNn1lkQGiJ67N
2JflwPWZ5IpBuwywefHZyO5LPswnm9zp9MqAazVzf1lvl8I+pqVsQloGZJ7h
FLO5VQcyj4x6szIzQHpe98IoWz0YLPT8SM+m5T8aWmLSWw/ZHaWaiUUZsC5z
C/9YsRHkvNy/BDdmwAb+uc7Snha4u7hwIKA1A8z1vtSoVLaAv/6dy76dGfCf
ommFpHErdMvIJ3p0Z4DLGZKiS0EbmH3cvmA9mQEi/Ocz/wl3QrChi6XFdAaQ
yhR/idV3QhF5Lsp0LgP6U0w1jLUQrBG6ZvSXMwBw4onL54jwzDgyRGMjA+73
PdtTqtoFJd2bpbCVAbfZ34qOBHXB0HnHiUv/MsDueS/99Y4uEOS+IXF+bybs
7mUinz5HgoqXPIPH+GlmmnWdfncfGSp5MyO8hTJBr1Bo4BbN31Vbiqv2iWZC
qhdnk48nGWr/O1PnJpEJ060tt5Vp/qROtcmZdCoTvncL6A/8I0N9rMoJPtlM
4HJ8yX/4JAUaxW9ktCpkwoRYhOWWFwWanCf02S9ngjwy1/DLpPmjJjM2K7VM
QAZ85WVtFGil/0CtvZIJFy7rrcdMU6DthmMQk04mrAus1vL+pkA79oeC8c1M
KJN2G77CTYXODz7rpfqZwJCv43roJBWQDF35X6NMyAm9vI1RoQLRN9JWzywT
Ih8lSZTepkIXheNwvmUmXJE3+2JhTQUSZ9rUfw8ywWiwOrjKnQoUUxGMlj0N
T/+1S6Y/FaiFBbpZzplQ72b/VDSCCt1rp5hW3Wn6hLq1KD2nQu+luk7VJ5ng
ahAYuJpEhZcRSj7JvpnA4t/yUDGFCn2jXWeXA2j6GswaH6LF/cLaXxVCM4Ev
47x/Cm3/wMORgtiITIjGpqoXxlFhqPauxVxMJvzl0XhwM5wKw3/nBM4mZAK1
cXwm8SkVRrTsRsOSM8FOm3XNxY0KY8nfYibTM+FRUPnJj1ZUGJ97rHkSlwlC
MerG/25RYeLkzt+nOZlAvv8+sUGZCq8ehzUNFWRC8uSH05wSVJhE+z3ESzLh
pDtmiJ2TClP7MVKPKzKBW2LSqP4XBd4YHlzsrqHxM0ysMk1RYDonB3+wMRPO
VEXQ722hwOxXibvOrZkwRX9LrTmdAnMh8n3c5Ew4Pjikq3GTAu8GOsJsejKB
Vegb6dgJCswLXLnc1J8JrQNTrS+3yfCh4k61+QSNP++mnmcOGRY3px2qpmj6
YqUIwW5kWNawPkr/NhPcJo+NPFQmw6c37mnFS5mgunLx69QwCT4f27y19TkT
7EttvN3SSPDFLWjfjdVMSEnRkdw0JcE3pnj/9Y1MkK1S6N9+2wXrZ8usL7Nk
gYIW3jprgAg//eWEE9myoPw/747EMCL86ml59Z4rCzjoN7ENCkTYuNerFXUw
C66ka/62uoRgO3pJZlwqCx7wa/eOFLWD0dyjPzMytPP9nBcMmdqhVo6esiiX
BeHseo2y99vAcUbUZEMpCyK0bLEy3K0wLW0cdlA3Cww7XtaKGjRB63Dfa0un
LMi+JKl/40kN+PFVB6+UZcHI5YapE8UYmHRQ0f2vKgvOHZY/sVkfD3KdA3z/
6rKAJUmZ78HBKPhi97mUsz0L0hZSbvK3PwHT5iOv5AayYHQqbHBCJggpmqWe
9F3JArt/+2/UbueglKqjv0LWskDL2F14OT0PrTHUdsb8yoKKM9cVjsgVoBfl
Q3dwO7T6fI6fFbAqRoL/mAMRGw4OGMvqdeIr0GaO3xjTaRw0MWlSK1E9kh0T
PW17FgfcL08kGjxrQPYM5EjKBRwY+9Fp+1xtRFO2rJfDVHAg98Tv6hKpCTVL
4Yrp9HCA/Xd+RiizFa2ZqdJbGeCgP1j6xiOtNiT5fNEcGeMgSPyhYenPNoT9
Ls0TeB8H/5TycE6qHcinvsN/2xMHihtz/EY1CFUv3X9t6o2DZ2th/feOENEn
/r1yrU9x0DIc3KTsSETGvjc/+jzDwaW+6hf3fxFRYum62lQUDj6OtcRmyHeh
3pk03MXnOHBknb674NWFFFTe3d5IxYFN8OV/ET+6kLtbWLlhJg4ASeGmTpHQ
ixwJ5oZsHMhk9JaJ25CQIIN7+6NiHExnOJo9GyIhvfO8AuNlOAiPUG1JpqN9
322bPeSqcVB6w50pQpaM/vTQSfxoxgHrw7mqPTFkJPenIESvAweF1m6ToXU0
PymlPVvVhYPQebL/5DQZ5Zl9k+fsxgG1KPT0n10ymo5LSnLtw8HhrsDGj0co
iKfzwsrgEA5uZexIEjQoSOf7m6unx3GgU7v6RtiagkLFAnPjXuOAjl7K2iKQ
glpvH9n5OoODvR+Tsu9jKWg9tNtIdx4HC42Xqo9VU5BUvWNN6SIONhejdwqp
FGS9xMG2/zMO7nWpnF6coqBM/jo7h284aB6JkJ2j+c+xa3e7en/gwA1tKSRv
UtB+3+1Dkhs46FrHdtAzUZF6KcErcgsHb9sbfaU5qchvRmN0+R8O9BU+O3MJ
UFEt26dTVxnwUDq6NF0pTEVfLsdFFDLjAUWY6rKIUdERN9kFRjY8HP/QES0i
TkWmOROXbLjwEEThL/x+mIowoz5pZF48mK+1fQ+ine+jF/lx5CAe6CJZd4dp
fpH+fJduqAgerlsJlS3Q/LCSrW3Rgjge8i3NOJoYqcgzbd8etRN4iBhUCden
5V/aU2GWI4UHQvfLikZafe83bzfuyuAhdeT4w2Va/UJSG1yW5/DwplBydJGm
j75ZplPnRTwE6k7oNtD0i4lT6RZRxkNH2LCXWQYFkTreiwWo4kGqdlJ2huYn
t1Yjns5q4iHj6vF0Bdo8YE1dsJPQxoPwkMoS8zUK6s9S1ve8gYdfCuUyoxIU
hNNal2QxwkNDkp+MzQfafHL4Bu8dUzysk4nlFzvJyOW/4l28BR6uPeqvF0wn
I5W8e5PnHuLB4ruo5kENMiryae4KdMKDTlktaPKTEeetAxUv3fAQ94G/PPkj
Cc1v94ZZ+uAhuXp6rfkZCYUZnj8bG42H6HK3mNclXWjlVILw5HM8JD5LYnzn
2oUM6L8wi2PwYNt58K+aXBc6UUWYa8yk6ReVekOxnoh6WVjj3pfhIZvtgT1e
FyG29oVlxSE8KM8/3JGPb0WPMcpjz8Zo/WHXJiV/bUFv7dM7hifxsD9sy5F4
tQVV8t1IsX2HBwPmgjNTG01Iz61ZLWkND1XBLTrnVBtQypEE3CeebFB9UPNF
50AVEolW1k+/mw23XV0OBdnGoXn77JtYs2zafPZMnr8/AhVo0elmWGbDA7PN
N73nQpAUC0Uj62E2yNKF6Ieq2yOFSN0LBO9smAy8MPpgPQj0w00Fi9OzAeuQ
/ueIAR74bNt5X2Rlg3PwGn/UZwJMaYpylxCyoei1d2yZci5YMr7fV1acDStP
Nb7nkfPBOcxhu7IpGw5HOIWwlr2AiBCfucbXtP3siyprH6pB+/70dNNMNlyL
ku1xcq4BNjXl183vskH0lodUxXoNJNPRjbR+zIY+IEQbbNZCTlBkV+fvbGhm
MY3b97EebCw/d6DtbJDRsWCNMG8ACdBtJe5mgzfzmMWT4Qao/MdRR2ImwP4G
XoWoikZoC0gr6BYggFBDWkuidjME3tvM6TlEgGqHjyt1Jc2gftkU33uYAHxW
bz+yMLdA745IWp8EAYxKD9w83dICcbNBmP5TBHBSpWNZY2+FW+0L8QNnCJAB
SKLfshUmnxZGDl0kwM7VSyn1W62QYcb8bPgSAUpbHQuaNdrA/JJD8AgQwH9x
IZcY3QYftqR9x64RQM7nwN1+tnYomo5/Mq5LAPtn7Hrd2u3g2LrmMXGLADbJ
Qi0NYe2w5lvvOHmXAIcxKyO2q+2QKC/9+7Q5AVScdmqFjnbAmZ/5YeFWBJAK
TdOSMeiAoapDXG9tCHDHP1IrO6QDXJ2TcecdCDBmVjdlX9YB7CdZT8a5EGDe
aOV53GgHlC+FNnzwIIAxT7sTy68OuJ63pXbJiwAcNw8vzvB0wlcLzyGMHwGO
CJ1/vVemE2IOfTH9EkgA24JpTPSVTpCauv9RLYwAeq1aYzYmnfAy5c2jjEgC
+PAkdmQ4dIL97dt0P2Jp9fgJfD7p1QksHC/jtBJp+AzMhgJBnVDcp3owJ4UA
+GvFzjbPOuFqZHPhbywBrq3VMfFGdNL8j6zcLTwBrsfnWp6krUfQvegsyiXA
j/XJIy8CO+F4x2Hdf4W0fkhMW6Y86QSKb/prw1ICfJLwiF+37wQbeU6bikoC
nIxsjOsx7gSGnxFrjHUEiD1+JFuQln9e1T9/8yYCDByJcPx6uhPUnb321bcR
4PE5ur9XDnTCguRqKiuRAEej35Fk/uuA4CXbIw8oBPDzCYopH+8Asby3la29
ND3YBEK7KzsAWRhe4hkkQEpjgPyziA6wODTY4zBKgOUbS0nfTDvg32tNg65X
BAh9Hj29X7oD8Cnt84LTBCjUNqxZ/NMOs+zlf3reEyB3iEdnPbYd/PuORhz+
SOt3StReRb12OBSZxeP9lQBm4ec0rLnbwZQu9tSJXwTYmkgdDY9pg612+uaA
TQLkjOs2p6q3QYavn+arHZo+nOtX6n63gvOfehkSfQ7sGLdNXTFphfbXa7++
MeaA+BWVN2NMrcDaKN12kDkHbtSvPsJXtUCpZ8H/KrjycCi/Ly5lKZGlCEmS
kohky3ZUkpD9K1kiWlTaLBVFIpIkW/Zl5p2d7A1jvTO2EinKkizRZt+piH7v
788zn3PvOedzzrn33OeZmeM3BQhwIXoqcPsyC0bGEtx3bCbAUyFf56O+ZaDz
5t1uC3ECKESO1+4XKINIusDE7a0EeFFca1pPKAXF82EB77YRwHl71knFBiZc
6PeJD1YgQKOAZWrAfAl8e29T36tFgCcpmVK/Fwpg8KBIwlcdAqTdLFa7t5wP
/Unvz47qEiCl5V0kdTUPul2s/v0yJIAP/xYxl9VcaBm20BU7TgCDWMkq2x80
YHKZFp44RYDWvqZNrwezIELNMKP0NgGmxX/KddR7o7CElcvVAQTYauMW0TR4
C4UsVh2qv0uAeyo5A9GO91FglV5X230C6D+S7nuyORJdMz0kOvGIAMr3vNR2
WSeiU+4akfIpBFixr3X02Iwh+7o5B6U0Apx7ttf5HR8J2e4uUTiQQYCb/f2v
mb9JyGL8QJ0hgQB3dLgrM9spyOiO6uppOgFmnVsPlp1jIMVYJb9YFgFWJ4Jq
zGcLUPWxYwJPKwiwI29i+pJjIbJddsMeVxGgbet1rllmIQq68Px9KBu3Rwy/
+/JKEWrX51Lxf42vzx+748wpRl6zUvU33xDgvUdOmrhoCVqhaTpfayGAe9Ss
0LB7CVIUu/L44nsC8K9+1qn8XYKCRjq+n+4mwDdt/5lcYSYSzZ6+59BDANZ2
z2CiDRPR7QU22/USQFarvehpLBO1I6MjFl8IUPJW7Lohfyny8nf+ZDpEgKs2
X1krRqVoRenWjWPfCPA1Q3ov43YpUkzKzTIcxv19P36tqr8UVZs3auqNEmB4
h0/zjk1lyHbNYIv2OAGi6+edLxuUoSBv8WW1aQJ4nnyVQE8oQ6I7D8SrzBIg
4Vjhw/TKMkTvMt+rNE8AtQk7/RuDZaj9yINT8r8JEPg7dbF6Nwt5/U6flF0i
wPq72qtaJiy0klcavu0vAZ4dHuqI82SheM+2bZKrBHjkfYD/XTALKUqOl2zh
IgIrIfy/qWQWqm7lNRflJoKdIalkLp+FbB/KDQmtI4LRl+Mn++pYaPiQfoAA
LxGuXCt/kNfJQkFTDsL8/EQIxqy/nf/JQqKUm7R1G4jAtbSix7/IQnSnaMM1
G4ngGd0UmsRdjgyEaR0rgkR48urkd1HBctTewPFe2kQEjb0qtfe3lCOvu71r
f4kQIVMwjDEgXY5W1H6lzYkRQZ9q5aK5oxzF/xBRn95CBLbqQHPYznKkmKHc
NC5BBPoDZclWXK62Oe4+IkmE6wKQKCFXjmz5PH59lybCyqmHlZ4y5Wi46l7M
kAwR9h5U0CuVKEdBPskKA7JEyAl3GBcVLkeiisVVn+WIYLGO+jGItxzR+1rs
uuWJYNB8RGF5iYUMEn6OflQgwqOVw7rPJlio3ZQ7tG0PEfgjB1IN+3H+V7dJ
tu4lwrXtlXOCb3H+S7QL3+wjAneMyA7uCpz/S7bHX6kQQT5idvsOCs6/7NX+
OlUifB/zkbgag/P/8ZE/+wAR/nz67DDpj/MfhW2sPkiELq9OK4YzzvdCl26p
NhHGqxcmh+RYKCR1RbL/EBFGhUdbc/+VoYcG8n948LlEryORGfC5DEWFXyv7
z4gIPzff22v8tAzF7E1MCjpChITy0AlrzzIU97bcn2JMBHV9cfkw7TKUsoVH
Y8GUCMN6HzcH9pSi9HIlMRlzImjyk09YM0pRlqv1rPFJIiSBb/+1W6WIQkkv
TLTB/eW+n80QKEXFmuoqGk5EaG8kF0jLM1Hpp1MbXVyI0HrfZ6vu95eoPCho
LOwMEbx3/uwZp7xE7IbXjA8eRFhraX5KW/4levuf227fK0Q49Mdh/K5QCRr2
j5YtvkeEU58aatsLC9G4ZPHqp2AiVOr2lvOcLURT1V19ax4Qwel0k4SvcCFa
5JHPsAkngsQ5wSbLnny0Nql868xTIsipNs7rGb5A20t/iKhlE+HGkHFxSy8V
2S8arcvnEOH1088udVwpiEd2dKywjgjLt6wFpuuSUOnxhA8lDfh+5nx7CJHP
kUTqd6y8CecrhPvvtHgC6tGLOtzQhtcTIV9tU2I0cn/wIbh3kAgm+2pGRO/4
IZGcexcGvhKBMlb6mSByA9W2K1gOfcf527HHLfjqRSS/647M8AgRQgy0Yffu
E+hH47aquRkiRN7rvVnbdhm8N174s4EbA57Qkp13/oaDjOamQcF1GKQ/jAqW
aHgEra6s18K8GCjK8zQZRTwG1YINKeIbMIg5XaUxMRMNszYFWjtFMSicCDON
LI0DUqDjdoXNGPx4U22hci8e7ElreBXFMdhmdLBn0CABmPN2HSpSGMj6RPx3
iZkId5J/+x7aiYEyc8Ysyy8Z9rKJzvq7MFgQdtbzkkqBnmGzo7Abg4elchKq
VSmgp5spekwJgxb+LLmXc6kw7mGydFwZg7frZD75Pk6DjCdTg2b7MTix72rU
Qel0WO09XGStjkHagK15pXoG5POMpdhpYMDHPlwXib+T3fYnhjhoYRA2tp37
rG4msO//sHLRxSC4+nTZYfUsCNv5ZPLiEQwMzr/+Zj6XDdgh2J5kjMHTxKN3
NQ4QgG09d7LeBAO2i/2xxxfweyLYOW+HOQa1G7kvpuD3hEzSpj7Lkxj4Df9s
cvmD33t5dRuDrDD4ZcPzYBnv88DP+7w/2WEgdTy2rP8OEVJnB9L5HDCwzFxW
U8XriLU+sVnTEYPNBR8nb+J107nDdNnTCQPuY1UBeXieF7T/KsW7YLBftyRm
mAfXsyp0Yp/BwMxQXkYJ51H9wrmoSXcMzkcPGQcYYXAjsWXE7DzOx+eqBldf
DJ7lhkgGXMQ/zwk35I7CIL9W4wTtEr4u6euT9iyc50/Ddzqu4PlNvkrsLMJg
bDqDvvYaBkUDw0nidRhs4LfpPnADgz3dB6lp7XidyPLwu/tgcFVOde+VLxgc
1yrXjvHDIHmcnBw7jsGFk1cvVt3CIEhINVzsFwbh5+SSR+9gcEZjW/bffxiQ
73Y0br2LQWSSfY49Hwlq4x8vmgRhoPXI8MEuQRIMMgx2+9/HoOYIScRfhARc
nJn/SA9wv90Tnaw2k2B7NyW8LQyDBkPby1VbSGAwdZr5LxyDv28PujTgsguv
0HeVSAzKJGMdfHH9uzK1m13wuB+OMCLf4fuladwyjorGAPVkKn7F7bHMlfxY
MRi8OGl3s4yfBF0e/aQfsRjEP7xB+I+bBIsB8R82J2CQaGY737iE8x9nsvbo
cwxMwvhyNs9icJC+pH4zGcd/WS8fH8bAFuV7ZKfi8ZVTtl3uw+Bmp0f823QM
mLf09R62YRA7IV67nImBo7DU3ex6vK6l78s5Yhjs8j7KXKFhMK5+0CaCjK/L
9GXZpuD8m/0MeUnFeetaGm15hIHpHasvwrkY3Il4qmZ/DoOLz9YKQx4GQ3ma
LB8bDCKoZXC1AAOC0JT9JwMM6j7KZjeVYDDb+IZBwPvW8MC0a2gVzl/+4O3V
CvzeHI39PPcWg9DYjOTqGQJwRbwWW3mHgQDtiGw3Pte0yHFZ8OJ5b9EK86hA
+Bxy+nrV1k4M+g/tGx2JJsDz1yczDfoxiNKmXrqNz6WL1A1ujyYxkPumkFZJ
wd+dng+HpDaRQHpt5YvA8+nw8F+l1C48D5qNvi9b1NPBOn3OVkWMBLuGeuos
uNJhuN2jDiRIsGp0av3H9DSQPHKYfE6WBL9jXLW6P6ZC4I7V8/mqJJiXsjTx
t0gBg77bI4etSaDt59E5pfYcsOYNo0a2JGjn6JUsrCQCb0XmKH5IgazUEa/o
N4nQmlQ3ZuBIAsGeA3XmHongbr1p8pA7CTJLSOsVnyRAvSE2qeNBAhiIP9ds
lwB7VTSntM+RwIpvpqdSOgFm1ztPa3qRYODRwDt3Rjw8rKPOHrhBgkjQLONU
xMFw0aE5NR8SmCn/Mey4FwcnCS1zqn54nYsYp04axIF40Oy8yh0S7Myw27Kp
OhZoWoa/9oaQYMU0un67yzN4w+hYlovFZWVhNUFaFOxP8fq7I54EGR/Xt777
/+9YIpb/yiaSwONoiVGc62Nw8ZRblUkhQUSi0mQHXyRMbLvKJUUggcJBr6kB
zXCwFeBaI4mRoPd0V7hwwEMo/RO/ZiuZBM0jtU8/ssIguJPFLU4nwXJTou+I
SigIx67jES0kgVqLuK5pTxD4BSfziBSTIH93k/rzPffgk7cSr/BLEgRf3rpy
9WogYCes+YRYJIj3si6KGroFGmsz1m9gkyDRvqvKYeganLp1UIj7Pd7H45lP
RsuVkZJdm4NyOwlGd+RSzkmZob+q17MdPpIgPe1iZSTNARFGctRyu0lQtJ0p
dmrXeTTqstPOfpAEjXysgdi3fij4qEgKdZYEX1K+mSZcDUcU4Sk58y1kGFaR
WboimIzuTERf9pcggw/v6VucvmRk9kapJFuSDGoZmYHz+SloMuyC8bwMGRL4
DaYIdmlI51ffhczdZLjmae7DImWilr6W3CltMmR4FmKggKGsisvzkrpkmHt6
U4z/GYZuJvMbGOuToSLGWDXkN4bEbYxbU4zIkEpVTzB9Q0Lu9ZXTh0+QoZgc
7Vh0kYLmcnI0E53w9fpJPMpBdOSzsSUi1YUMGr/fNy1/pKPZqxNdWWfIENl9
zaliHwPNqqkFMjzIIJ7L9b6tA5dLmTU1l8mw1TzQdYN0LvLZ2rWp3psMb9vE
d8x45aLZgN/uTdfIsMPWfb8HMxfN6Out/ehDhhsNHauFJ16g6Vr28ZFAMtyL
HB8lnclDN3YNpUzeI4PA9KjP/ew8NB2+dnQumAyVvBNTD/rz0JSpSfRqKBmM
RVd1mh3y0bWci31rw8nQ/Flv9s+zfDQp8Hj/+kdkmP3pEyz7Cpdbm9+LPSHD
/qDfS7KqBeia2oSc5FM8fvG19K9uBWgyTsh3+zMy9JduoVyPwfE51Xr5ODIU
7mvMZlXguL3Nlr0JZFBqjvMq+YbjpT4X9j8nw0iIbaASbyGalEgsO5hMhjzi
e9WmrYVooqfztGE6zt9sL4+zbiHy1v+dczQTt9cpk3P0BD7fZUr+Nc0mw8b+
RZPvDjj+T/ekJZEMWWcedul64ri7S5YdiQyerQ7X4RqO1wZNOVLIwAyz0Ju8
jePy2UZnaGRop14KPRKC4+HsOE8GGZY186naj3D8x+CQVy4Z3v8ZUWiK/v//
N6zVuJZHhnGrmLTZWBxn7Ar3LcD9pwdVFSTguIBJ550iMnCld5/9m1iIxrwv
7gkuIUPftdf3P+Ly5dbIO2FMMjitO75PA9cfVc1piiwjw4eZr6kS+H6X45ql
Ysrx/NVG7Lz7BMdnx68kVOL+auw3dA7HcXuh6pRqMmiefhH5MgjHmapCWQjP
T6AbJ8wPxyVs3EgcMpgU/GxuuFSIRu74FNLryPBwprvwtmsh8upJWJPfQAar
4ktZSVaFaFiPaVvyigyXKmVGZI1wPLOTxGoiw6jF1Y0iqji++mu+upkMus5e
uRe34bi7pEndWzL0tP0XJ8eP4xzd5NfvyGD7IPNcAJ5PL3mX4bdtZHhWmnPq
GrMADT8MOvThAxmenH0XtT0Mx39kRXV3kOHRum1DESdx/Dj7c18XGe4fa0om
by5APzesDR7+jPen3p6qxZR89NFJVUKyH+dr6lHPJet8VJvjXHjiCxms13x3
Wlybj7LMXg7lfCPj91HMkoNbHopO+3L38w8yvHifu1mJLw8Fjm7csnGEDFUI
RW7OfYEcos4fvzpBhqOuGTwHf+Yi4564L5lTZNgw8EPq8v1cpK5UE9A6Q4Yl
+E2uEctFgm/EX6gukoGdJT/WrJaD6te/Fp5dxeuXWZ/xU5+Oik/PM3auoUD+
ritCt0tpiMDYcdRuLQV0xnounFCmoXsnAvxf8lEgM+dQ/oeNVHTwsVLPLWEK
LGVH/7yAkRDG/5S0LEeBwfw9HEmbDBTrWK6vvIsC4g9M+uI70lAw/XuHy24K
XA5tfDVvl4qcTA35a5Qo0Pp+4sq0YRISiZzyDjlIgdRC6SOfsGcohM9Wi+cY
BfyG0sKCTdyRK69Ek5AXBRYXA6QEhTLgGz1LSfMyBUwcnW97L2TCZfPd0c7e
FLhlxGk278uGW7GaVvQbFIh4ZOj0uZMIMVL2HYcDKJCg0xlUQKFAzf64Qb8o
Cozq8qjzKuSBcdvWo+nRFDiweCpkeVM+vPElkDkxFAjx/GcW8CcfOlkFF4US
KNDi+H6l1bMQpo60TtDSKRDlpmdUvbsYdpwSWOp5QYEBOdGTSb5MoP6Jd15T
QIGwbEOR1k4mKGdIVe8pogDvr6EXV3VKQWdwb4gfE/e3Um+8YLEUbK6Y8grV
UCBoo+pUlysLugXfX9Rg4/7p7JP5XsyCM4WnmpxqKUC+cCtynqccLi9ciKY1
UoBxI27bKKUcQu+Hix5+h/PRlWU82lwB/DsF/S62UWBCM/9k7aZKiKlP7Hj6
gQIcP02vwzaVkLaenNLTRQEbtT9CAm8rYceLfUtcPRTQ2PvH9DBfFVAtS5z3
9FKgy2bT3IJhFZQk1G73+0IB9WOfHr+kVoGulllI2hAF4iaXBF90VgG7u22Q
/Y0CgesXD66srQaTu6eP/vxBAT078M7eXw0tMoNkwREKbP9XeiXKoRps2V68
GmMU0K5Zp1J6txq6PaYvOk1QYF/4+IxUVjWc4bnTFDJFAcu+dOOi6mr4Rvun
RJuhwJ/oqd83e6ph67sNz+lzOD8b3EULZ6vBfHHLP8YCBZrvel+6wl8DwTJy
l3J/UaAwkNCfJV0DxcbKH178oUDuiQ9PjynXwI8r2gb5yxTA3s20OunWgGTC
EVrBCgX622u1eo7VgEXFSZGifzifDpRkZFkDIYOOd4vXUEFr2ZSb778aeMl/
7nvJWiqct3FvfOFYAz9Vr1sxeajQ+cvCN+90DUidCiwv5aPCutsN3Tw4bhkc
Ls9aT4Xuaj++ErsaCKXEPi0XoELhrgSbYosaYLak/6oQpALt2x3zNUdrYHiO
erZqExWsRve2ZGrVwDbp4uZqESpMjfVMhO+pAesj1ZpIjAo8JdeFWFtqIOzS
62z2Fioshsy+U19TA6WxH9bXSlDB+N46yYWRahgt6/etk6TCoNjxLavvqmH7
wEhfvTQVRE1qNE+WVIMN78LxRhkqhFTsOzCUUA0se4FtTXJUyNmTONtnUQ3j
d8Uj3shTYbU7MfyYQjXIkuSmmxWoEKQuFTO/VAURM9r1rXtx+/rKVJWsKqjY
enT/+31U+G+DRWXFlSqYAMuUNhUqKEe42jzXqgL7mHPeHw9Qocymfbt+fSVE
Mq93dhykwj0zTorgo0qo7A006tKkQnpS7Vbt45Wwc1/c5p5DVNCpE2rIRhXg
YJsR/FmPCtwzN2/+uF0BjwNow70GVHDh+iqfqFIB06+qqwYOUyHtwIUXWnHl
sGvq9e7Bo1R4NdGsrwnlcEr8Y+zQMdz/Xp/j+aMsqDk3eu77CSo0zjqa7tZl
QfQaCcExGyqoB/CQeypLga248/a4HRWkdzVwTjmUwpyVyuDEf1SQmuFzDZtk
glPWUeb0aSrcpClu49nKBEW9G66LZ6nwxU4qI826BOr8mvLW+FAh1PaArz47
H85FDbjt96PCkmfFhvCMPOAlLIg436JCvNWmhTq/F2DWLHfrZSAVHCyuKadL
5sB7uUDDi2F4fq5afRbQoUBvq9K7lkQqWJ8S9VJueg7zitHTyWVUkFS39w3Z
lISSDDGsvpwKSZt67yd+TEHa9iz7mUoqBI9a0nNT0lHg/W8sMzYVn2/v/bGM
ISCuTv0HK6+pMNr//acdDxVtDJsQ8eyhwnPSshePZSHKT1lb/6yXCvKuwpOt
M4XIKl/yVlU/Fcbmt9/bkliE4j8d69nylQopfgLCzR+K0Va1LOz1GF7f7a+4
yw2YaFef5cH9K1Q4mDBYpppbjnxvD09o/qNCvU/ra3OFClQrEko3WEMD351j
TuKZFcjdhClzkocGd3gXRR6EV6L0Aml+b0EaLNoWzRvqVKPRE8xa3000mPsU
9sUtqxrpfLMMuitCA4tsTcGmNTWoc2vobNQWGvxJHLp5jF2DREOHexkyNPj+
Mr7LQZCNzm4LTS6SpcFOTqvMmAYbFZZK25bL0UC/3Er9txMbWY5ZvnqtQIOz
BJvySxgbZYYPP3i/hwa5j7u5G+rYaFw2VL97Lw3qJrqaIr6y0WN7ZtFPFRow
LAsUVLZzUPekpfeUKg3SiQav1x/ioN2Ph3f/OkCD9r0V6wxsOchfPnRw9SAN
bHQsjtdd4qD6aukMXi0anPcLUUi9z0FijkwHIR0avFZCZyoTOMhj1lJEXJcG
5y7W9O6mclBR9HCzjD4NPN9OlXSXchDXntAIBUMaeMiMyrc2cJAVR/qwihEN
uFxak9d94KAsZ+ayxhEaRETTqQH9HDSxYFmqb0yDzulmsX3DHKQfO3zD2IQG
/nVK78SnOeiJUug+C1MapJ1hLOguclBPvfQPOzMaxDd4tz1f4iBFNybB2YIG
+Q939SiscNDtP5bOnpY06Oq1Yo7gcmPC8JYr1jQYOxCs9eUvB23eH/rex5YG
ikVRbvz4es/X0k8C7Wlgu/uD+9kFDir2YB4LdaBB+O9LqaOTHLRmxZIrypEG
C8ZHk0k/OMg6ebgizokGUiKuEtG9HJR9INQ/1QW3Fz3EQ37PQZPN0mrEMzRQ
O2MWPFbLQQYXmKN0dxq4zFxv9ijhoGguK0qhBw02N9IubsA46HPasBvrHB5v
WevfoRgOUtIMlWJfoAGmY39uIoCDAt5Jd7zyosFgKNCUPDno9SXms3eX8Xoq
Ul1NN+OgC1nD6wau4fVUep21YzMHMXVC0Y8beD42FARqL7LRug/SgZM+NIj7
lC/0uJONMD6rqZVbNPhyttTnexwbzRCHGTwBNPjIPS294M1GRvqh5wTv0iCw
Yc2JEyZs1HeD+WnbfRp0OPx+9fwnQvWuOS5SD2jgoLDoXROH0Auz7AGJMLxe
Yt9W5+ggFLjr8XfRRzRI8V/4OHKvBol3u8zwP6PBQUzV4ONAFVqpt/HjjaPB
BrvPVqM3qtC3IpNfaxNoYNh83mXtv0pU8kRtZTUJ9/ev2aZzopXIGtatX8ii
gcifadJv8XKkrfznySwBt5e5uNUgjoW2S04KTWN4fR0/UtLFz0Ljs12bx6g0
2PMv/ZbhdCl6TM3dMZhPA+HiuoB9xJeoVtBO520NDVLb1nja7C9AjKXjlW/Y
NAgSEj9R+ykPxf7UN3xdSwPX7y2aiQ9eoDOc3cZ1jTQop3540N3IQMt+S1bl
rXh/cvz1LuwjI41e4kVKPw34OnXT8uZiETVnOilolQYSh/Xu3SvLhuXw6bNU
Ljp4h32pKQ8lgvXZaeV33HSIq/fXrVIkwbLEdO0OPjo4Kp/eKX4TP0fDpybr
NtGhRmW1bHDiBfxxmzTZIEeH6K3S2dplL8FSb1LkoDwdkn5ddmy9zQSy+GSv
swK+v1Fjwk2tUrB8O+GTt5cOE24P4h/mlQGmO5FlrU4H4aShSwEhFWCxZXwx
6SgdtHadr7SkISBOj3HQMTrMTEfkuMqyYbF5LHr4OB3MV7Sf3rrEBmLo2E5d
Czq0f3ng8eL3/7+PNzbhYUkH+cCFiTIDDlgcGmM9saZDW4L80bUPOLA4NWrZ
Z08HrjnWIx3uWjBvHpXkPUWHGM/OOFGjWiBQR7/tP02H8EqJzI33asHMdTQw
xJUOOanbdx2drIXsNyNU+Qt0SC3yq1usqIN5yshNCy86fLL4ZrBxpA7MHozo
+1+mA+mO/b6NW+phXnukvfEaHWRSp7tfXqiHE2IjmVM36LDWW3bcNroesiaH
vbb60sHlG0uysaAeTCnDq5du08HjVpyg5HQ9ZIYMN8UH0KE8X2/L9MYGmHUe
Tqy8SweRNpvKqD0NYKo97PYtiA5h6R3wHRogU3RYSTCEDp83+cn//Q/Xn/i5
oBlKh+5eLsWWS7h+00/2mYd0sFActba9i+uTfz55FEEHlEv++iQK17//06Ew
kg51YsJet5IbYH7gstLLKHw/1Qf13sQG+AWTK2XRdLgZG/zLhdGAv2tutlXG
0EE1MjDzWEED/P03T0axdEgZUItQKGmAVbc7d+ri8fwOtr9cftkAa9jL5q8S
6SC0bb/7K1xet+O+bHMSHVif3s4+Km4A3hDuudYUHDeUEDDIbwD+L+GN7Wl0
+CjifvcHrQEEjNandWbQIeQAl9nD7AYQIkRf7cmiw5tM1yLx5w0gzCV8uJ9A
BwflOdmsyAYQc0/YPITRQb/DRkc6sAHE2eLD38l4fjO3tcXgfGzdkVY5QqUD
t8y/+T8ODSAdIvNsgk6Hx9lZQ65HGmD7F4LHTA4dDg6Fb6za1wA7jHZpLbyg
w7WrApLiYg0gT6Ct/5NPB8+n6kNXf9fDbq59fX8L8f4Zi/Bv+FwPiu75hVwl
dPj3ZlZMtroe9rEPPFzHpEPQ2LMDQRn1oBais29jOR3OePiU2/xXD+pfKlc3
VdIBxH+sb91fD5pG0C5WTQf22XMUJ9560OUyCZDm0MFAzbqouKAOjEPsXik1
0UF69UPsm7FaMPnSmba/mQ7ZZn0WGqW1cMLI6Zr6WzpEyCWrvwuuBUuus1t0
2+ggFnDg9osNteAYcs3zxCc8vke9XWmCHHD6MqN18jMdOm+XPNr5hg2uRv4b
bPro4K7xa54vnA0eXPeKHAdxvk8/2CMwjuBqyON/F0fo0PCz68mmJ9Vw48vG
D1fG6MAIWdx7Y6wKfIxiqdcn8HhuizGXTKvgDlfyydsz+Pmh4RrzZrkCQkPI
6RF/6MAz5PZp0xEWJIUgbcp6BqgiG8MBt2Jw+yS//rsAA46OOC7dDysCRfXI
nl1CDNjYu/RoilwIFV+tg8iiDDj5du8Bs7o8GDAZqiVJMwAlF9pXR1FBUZDH
ElNhwCV+T0U93xiYOX9JdkiVAeuLZCrf90dARc3baTl1BkSLosTqp8Fw8kZS
AlGLAez2qaQXG7jA58OeTwRgwNc1PZoctxhUmWp2LtuGAf52hU9asqjo4Wy+
5oAdA3qLWp5gt+jI0lyMT9aBActc/BtY5jnoy9/PjCwnBqTodfij8Ty0zv3q
VKYnA8g6zRFiocXoLauN3XeeAadVWQuTbiUoSUQrXsaLATfrMv2e6r1Ee+tW
NTK9GeDs3/qDMcZElrtjAzP8GbBytn33U+VyJHF/3rz3NgO+1dW35i6Uoy9d
jjLbAhmwmMG7v7ayAvk8lmOnBzOA+9zkr1uGVSh5vJgn/REDqki2u4OkEXI/
JtHV85gBKq/qrn5oQkgp6y5dKpoBpj7mY1q6bFRlZWyeFssApciPTUIDbBRO
p2/riWeAk29rXvh+DrJcIzgp+ZwBpNm8rb/ucpCE0010OpkBjYVL9adfcdCX
4o7Y1FQGFD2+nE8WrkX/AxpKKXo=
     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwVl3k8VG8bxhFJUtl3IkkK/ZKK5K5QlpK9LEmilDVJ9q2QfRlrlhkyM6hU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     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwUV3c81d8blxHZyg6lFCFECckjVEYiISQrSkZGZWXLln2N615bZe89znUH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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, 3.630395496235725*^9, {3.630395734190292*^9, 
   3.630395748162326*^9}, {3.630398227045518*^9, 3.630398290611651*^9}, 
   3.630398321328656*^9, 3.6304095607102737`*^9, {3.6304097133960733`*^9, 
   3.630409732179648*^9}, {3.630409783077269*^9, 3.6304098062452927`*^9}, {
   3.6304098500129347`*^9, 3.630409871111631*^9}, {3.6304104427267942`*^9, 
   3.630410452422469*^9}}]
}, Open  ]],

Cell["\<\
Only the central transition coherence is excited by the pulse.\
\>", "Text",
 CellChangeTimes->{{3.630409585125308*^9, 3.630409600819336*^9}, {
  3.630409891121662*^9, 3.63040992008985*^9}, {3.6304104587709846`*^9, 
  3.630410472945498*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["central-transition-selective pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
   3.630409368213925*^9, 3.630409373331704*^9}, {3.630409457544689*^9, 
   3.630409458172489*^9}, {3.630410179124215*^9, 3.6304101795291233`*^9}, {
   3.630410486380157*^9, 3.630410492150288*^9}, 3.6304106338203897`*^9, {
   3.6304107753641653`*^9, 3.630410779142592*^9}, {3.6304110037183113`*^9, 
   3.630411005347767*^9}}],

Cell[CellGroupData[{

Cell["central-transition-selective nutation frequency", "Subsection",
 CellChangeTimes->{{3.630410781562168*^9, 3.630410789988331*^9}}],

Cell["\<\
The central-transition nutation frequency is twice that of the weak pulse, \
i.e. \
\>", "Text",
 CellChangeTimes->{{3.630410502692959*^9, 3.63041051470778*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]nutC", "=", 
  RowBox[{"2", "\[Omega]nutW"}]}]], "Input",
 CellChangeTimes->{{3.630410518491323*^9, 3.630410525531611*^9}}],

Cell[BoxData[
 RowBox[{"80", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.630410526962617*^9}]
}, Open  ]],

Cell["\<\
This is expected theoretically (see Levitt, Spin Dynamics, 2nd edition, page \
344). The factor of 2 may be tracked back to the matrix element of the shift \
operator:\
\>", "Text",
 CellChangeTimes->{{3.630410531201345*^9, 3.6304105983791237`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", 
   RowBox[{"opI", "[", "\"\<+\>\"", "]"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630410604277255*^9, 3.630410613668952*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      SqrtBox["3"], "0", "0"},
     {"0", "0", "2", "0"},
     {"0", "0", "0", 
      SqrtBox["3"]},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 3}, {{2}, {3}, {4}}}, {
      3^Rational[1, 2], 2, 3^Rational[1, 2]}}]]]]], "Output",
 CellChangeTimes->{3.630410614229624*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["central-transition-selective pulse durations", "Subsection",
 CellChangeTimes->{{3.630410781562168*^9, 3.630410799213793*^9}}],

Cell["\<\
The duration of central-transition selective pulses are therefore given as \
follows:\
\>", "Text",
 CellChangeTimes->{{3.6304106382515697`*^9, 3.63041068652743*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Tau]360C", "=", 
  RowBox[{"2", 
   RowBox[{"\[Pi]", "/", "\[Omega]nutC"}]}]}]], "Input",
 CellChangeTimes->{{3.630410658854363*^9, 3.6304106979248123`*^9}}],

Cell[BoxData[
 FractionBox["1", "40"]], "Output",
 CellChangeTimes->{3.630410698453965*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Tau]180C", "=", 
   RowBox[{"\[Tau]360C", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Tau]90C", "=", 
   RowBox[{"\[Tau]360C", "/", "4"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.630410704858992*^9, 3.630410722226533*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["central-transition-selective pulse", "Subsection",
 CellChangeTimes->{{3.630410781562168*^9, 3.6304108066731663`*^9}}],

Cell["\<\
A central-transition-selective 90\[Degree] pulse is therefore defined as \
follows:\
\>", "Text",
 CellChangeTimes->{{3.6304106382515697`*^9, 3.63041068652743*^9}, {
  3.6304108102186832`*^9, 3.6304108233015137`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CentralTransitionSelective90", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\[Omega]nutW", " ", 
     RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}], ",", "\[Tau]90C"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.630410832293478*^9, 3.630410853927019*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"40", " ", "\[Pi]", " ", 
    TagBox[
     SubscriptBox["I", 
      RowBox[{"1", "x"}]],
     DisplayForm]}], ",", 
   FractionBox["1", "160"]}], "}"}]], "Output",
 CellChangeTimes->{3.63041085449189*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["spectrum after a central-transition selective pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
   3.630395414602334*^9, 3.630395417930991*^9}, {3.630409933570064*^9, 
   3.630409938023226*^9}, {3.630410731329482*^9, 3.63041073661524*^9}, 
   3.630410999229494*^9}],

Cell["\<\
The weak pulse only excites the central transition, giving a single peak (to \
a reasonable approximation)\
\>", "Text",
 CellChangeTimes->{{3.6303985624702578`*^9, 3.6303985786813927`*^9}, {
  3.630398808185258*^9, 3.630398819085018*^9}, {3.630409942502898*^9, 
  3.63040996096321*^9}, {3.63041074000377*^9, 3.6304107593865633`*^9}, {
  3.630410892471232*^9, 3.630410903439592*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "@", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"InitialDensityOperator", "\[Rule]", "\[Rho]ini"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Preparation", "\[Rule]", "CentralTransitionSelective90"}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
   3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
   3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
   3.630396027075295*^9, 3.6303960409823837`*^9}, {3.6303986168297997`*^9, 
   3.630398660220437*^9}, {3.630398702294038*^9, 3.630398710640931*^9}, {
   3.630409971284046*^9, 3.630409996325594*^9}, 3.6304108846890182`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.6304108873747053`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxUvXdcU9nzPn7tXaOCYo+9oUZFRUUYFREVIQICAsKldwgkhBAIxo5lNbpW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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-0.0027285238838917853`, 
   0.04339873108013392}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630396042375787*^9, 3.6303960716595783`*^9}, 3.6303986852682743`*^9, 
   3.630398737135955*^9, {3.630409988583632*^9, 3.630409997325322*^9}, 
   3.630410887513607*^9}]
}, Open  ]],

Cell["\<\
The excitation is not perfectly selective, due to the finite value of \
\[Omega]nut, relative to the quadrupole splitting. \
\>", "Text",
 CellChangeTimes->{{3.630398780957326*^9, 3.6303987931408978`*^9}, {
  3.630410004290997*^9, 3.630410009228343*^9}, {3.63041090751451*^9, 
  3.630410924714551*^9}}],

Cell["\<\
Note the small amplitude of the spectrum, relative to the hard pulse. This \
loss in amplitude is due to the fact that the population difference across \
the central transition is small, relative to the population difference \
between the outer Zeeman levels. \
\>", "Text",
 CellChangeTimes->{{3.630410928472756*^9, 3.630410993331963*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cosine-modulated pulse", "Chapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}, {
   3.6304100520609903`*^9, 3.630410052509768*^9}, 3.630411074497102*^9}],

Cell["\<\
A weak but cosine-modulated rf field may be used to couple into the two \
satellite transitions simultaneously\
\>", "Text",
 CellChangeTimes->{{3.630409145372348*^9, 3.630409176378265*^9}, {
  3.630410054917211*^9, 3.630410072434702*^9}, {3.630411079007547*^9, 
  3.630411098592814*^9}}],

Cell[CellGroupData[{

Cell["set rf fields and pulse sequences", "Subchapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}, {
  3.630409216531904*^9, 3.6304092216056004`*^9}, {3.6304094827899113`*^9, 
  3.6304094837227907`*^9}}],

Cell[CellGroupData[{

Cell["modulated rf amplitude", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.630409276272395*^9}, {
   3.630411328117082*^9, 3.6304113294331408`*^9}}],

Cell["\<\
The \[OpenCurlyDoubleQuote]weak\[CloseCurlyDoubleQuote] rf amplitude is used \
in this case, but cosine-modulated at the modulation frequency \[Omega]mod\
\>", "Text",
 CellChangeTimes->{{3.630395292959406*^9, 3.630395300834734*^9}, {
  3.630409246076763*^9, 3.6304092476958227`*^9}, {3.630411110937302*^9, 
  3.630411142854623*^9}, {3.6304112273685904`*^9, 3.6304112419035387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]nutmod", "[", "t_", "]"}], ":=", 
   RowBox[{"\[Omega]nutW", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Omega]mod", " ", "t"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.63039521497709*^9, 3.630395224826025*^9}, 
   3.6304092505882893`*^9, {3.630410093108015*^9, 3.630410100101069*^9}, {
   3.630411246989772*^9, 3.6304112626279917`*^9}}],

Cell["\<\
A modulation frequency of 200\[NonBreakingSpace]Hz is used, so as to put the \
two modulation sidebands exactly on the satellite transitions:\
\>", "Text",
 CellChangeTimes->{{3.630395246314694*^9, 3.6303952694452133`*^9}, {
  3.6304101050169697`*^9, 3.630410111530459*^9}, {3.630411267263534*^9, 
  3.630411299518032*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]mod", "=", 
  RowBox[{"2", "\[Pi]", " ", "200"}]}]], "Input",
 CellChangeTimes->{{3.630411301944716*^9, 3.630411305537527*^9}}],

Cell[BoxData[
 RowBox[{"400", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.630411306371611*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["satellite nutation frequency", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.630409276272395*^9}, {
   3.630411328117082*^9, 3.6304113294331408`*^9}, {3.630411396836657*^9, 
   3.6304114005935*^9}}],

Cell[TextData[{
 "The nutation frequency on the satellite transitions is given by the \
amplitude of the irradiation on each satellite transition, multiplied by the ",
 Cell[BoxData[
  FormBox[
   SqrtBox["3"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "factor in the shift operator matrix element (just like the factor of 2 for \
the central transition)"
}], "Text",
 CellChangeTimes->{{3.630411403068632*^9, 3.630411470876405*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]nutS", " ", "=", " ", 
  RowBox[{
   RowBox[{"Sqrt", "[", "3", "]"}], " ", 
   RowBox[{"\[Omega]nutW", "/", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.630411474248413*^9, 3.630411491937985*^9}}],

Cell[BoxData[
 RowBox[{"20", " ", 
  SqrtBox["3"], " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.6304115141324873`*^9}]
}, Open  ]],

Cell["\<\
The factor of 1/2 above comes from the fact that the modulation splits the rf \
power into two sidebands. \
\>", "Text",
 CellChangeTimes->{{3.630411493805015*^9, 3.630411509353194*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["modulated pulse durations", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.6304092994486933`*^9}, {
   3.63041014934405*^9, 3.6304101497599*^9}, {3.6304113427101097`*^9, 
   3.630411345859275*^9}, {3.6304115390446444`*^9, 3.630411540067713*^9}}],

Cell["\<\
Durations for satellite nutations are therefore defined as follows:\
\>", "Text",
 CellChangeTimes->{{3.630411543994035*^9, 3.6304115689255238`*^9}, {
  3.630411658267728*^9, 3.6304116692472057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Tau]360S", "=", 
  RowBox[{"2", 
   RowBox[{"\[Pi]", "/", "\[Omega]nutS"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Tau]180S", "=", 
  RowBox[{"\[Tau]360S", "/", "2"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Tau]90S", "=", 
  RowBox[{"\[Tau]360S", "/", "4"}]}]}], "Input",
 CellChangeTimes->{{3.630411602108083*^9, 3.6304117130801163`*^9}}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"10", " ", 
   SqrtBox["3"]}]]], "Output",
 CellChangeTimes->{3.630411713587183*^9}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"20", " ", 
   SqrtBox["3"]}]]], "Output",
 CellChangeTimes->{3.6304117135915947`*^9}],

Cell[BoxData[
 FractionBox["1", 
  RowBox[{"40", " ", 
   SqrtBox["3"]}]]], "Output",
 CellChangeTimes->{3.630411713596005*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["modulated pulse sequence", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304092731559877`*^9, 3.6304092994486933`*^9}, {
   3.63041014934405*^9, 3.6304101497599*^9}, {3.6304113427101097`*^9, 
   3.630411345859275*^9}}],

Cell["\<\
A set of satellite-selective modulated pulses are therefore defined as \
follows:\
\>", "Text",
 CellChangeTimes->{{3.630411543994035*^9, 3.6304115689255238`*^9}, {
  3.630411721888804*^9, 3.630411734095944*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatelliteSelective360", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{"\[Omega]nutmod", "[", "t", "]"}], 
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}]}], "]"}], ",", "\[Tau]360S"}],
    "}"}]}]], "Input",
 CellChangeTimes->{{3.630411602108083*^9, 3.630411646521681*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{"\[Omega]nutmod", "[", "t", "]"}], " ", 
      RowBox[{"opI", "[", "\<\"x\"\>", "]"}]}]}], "]"}], ",", 
   FractionBox["1", 
    RowBox[{"10", " ", 
     SqrtBox["3"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6304117460129538`*^9, 3.630411787186872*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatelliteSelective180", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{"\[Omega]nutmod", "[", "t", "]"}], 
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}]}], "]"}], ",", "\[Tau]180S"}],
    "}"}]}]], "Input",
 CellChangeTimes->{{3.630411602108083*^9, 3.630411646521681*^9}, {
  3.630411766672278*^9, 3.630411772179843*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{"\[Omega]nutmod", "[", "t", "]"}], " ", 
      RowBox[{"opI", "[", "\<\"x\"\>", "]"}]}]}], "]"}], ",", 
   FractionBox["1", 
    RowBox[{"20", " ", 
     SqrtBox["3"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6304117460129538`*^9, 3.6304117874003773`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SatelliteSelective90", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{"t", ",", 
      RowBox[{
       RowBox[{"\[Omega]nutmod", "[", "t", "]"}], 
       RowBox[{"opI", "[", "\"\<x\>\"", "]"}]}]}], "]"}], ",", "\[Tau]90S"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.630411602108083*^9, 3.630411646521681*^9}, {
  3.630411776390492*^9, 3.630411783332769*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Function", "[", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{"\[Omega]nutmod", "[", "t", "]"}], " ", 
      RowBox[{"opI", "[", "\<\"x\"\>", "]"}]}]}], "]"}], ",", 
   FractionBox["1", 
    RowBox[{"40", " ", 
     SqrtBox["3"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.6304117460129538`*^9, 3.63041178742975*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["observable trajectories during modulated pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630409368213925*^9, 3.630409373331704*^9}, {3.630409457544689*^9, 
  3.630409458172489*^9}, {3.630410179124215*^9, 3.6304101795291233`*^9}, {
  3.6304118018929043`*^9, 3.630411803152272*^9}}],

Cell[CellGroupData[{

Cell["set initial density operator", "Section",
 CellChangeTimes->{
  3.605545643975979*^9, {3.6304093850105877`*^9, 3.630409388914083*^9}, {
   3.630409450636348*^9, 3.6304094511635103`*^9}}],

Cell["\<\
assume thermal high-temperature Boltzmann distribution, and omit the inactive \
unity operator part\
\>", "Text",
 CellChangeTimes->{{3.6304094035733433`*^9, 3.630409424904491*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Rho]ini", "=", 
  RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.630409390964274*^9, 3.630409394832224*^9}}],

Cell[BoxData[
 TagBox[
  SubscriptBox["I", 
   RowBox[{"1", "z"}]],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6304094014855957`*^9, 3.630409428015237*^9}, 
   3.6304101824477577`*^9, 3.6304118066225443`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixRepresentation", "[", "\[Rho]ini", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.630409433790999*^9, 3.630409442219749*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["3", "2"], "0", "0", "0"},
     {"0", 
      FractionBox["1", "2"], "0", "0"},
     {"0", "0", 
      RowBox[{"-", 
       FractionBox["1", "2"]}], "0"},
     {"0", "0", "0", 
      RowBox[{"-", 
       FractionBox["3", "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 1, 2, 3, 4}, {{1}, {2}, {3}, {4}}}, {
      Rational[3, 2], Rational[1, 2], Rational[-1, 2], 
       Rational[-3, 2]}}]]]]], "Output",
 CellChangeTimes->{3.6304094427443953`*^9, 3.630410182632455*^9, 
  3.6304118068233843`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
track the trajectory of z-magnetization during the modulated pulse\
\>", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630410189273068*^9, 3.630410189868565*^9}, {3.630411811939809*^9, 
  3.630411813187788*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trajz", "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"opI", "[", "\"\<z\>\"", "]"}]}], ",", "SatelliteSelective360", 
    ",", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.6303956858216133`*^9, 3.630395724549844*^9}, {3.6304094761119833`*^9, 
   3.6304094984532213`*^9}, {3.630410194789727*^9, 3.63041019521319*^9}, 
   3.63041182210264*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{
   RowBox[{"TrajectoryFunction", "["}], 
   TagBox[
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox["\<\"0\"\>",
        0,
        Editable->False], ",", 
       InterpretationBox[
        RowBox[{"\<\"57.735\"\>", "\[Times]", 
         SuperscriptBox["10", "\<\"-3\"\>"]}],
        0.05773502691896259,
        AutoDelete->True]}], "}"}], "}"}],
    EngineeringForm], "\<\", <>]\"\>"}],
  DisplayForm]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, {
   3.630395712241858*^9, 3.630395726102973*^9}, 3.630398100508581*^9, 
   3.6304095009290047`*^9, 3.6304101968030577`*^9, 3.630410289014357*^9, 
   3.6304118261087923`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"trajz", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "SatelliteSelective360", "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, 
   3.630395752643961*^9, {3.630410277505549*^9, 3.630410283801496*^9}, 
   3.6304118315639133`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwU13c81d8fB3AZJUlSShkhVFYJJckLJZLMyEwZJUXIHtl7XZtLURFJigYp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.58},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, Rational[1, 10] 3^Rational[-1, 2]}, {0.5941820312552022, 
     0.9999999999999569}}, {{0, 0.05773502691896259}, {0.5941820312552022, 
     0.9999999999999569}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, {3.630395728971292*^9, 3.630395753143238*^9}, 
   3.6303981054413433`*^9, 3.630409504468165*^9, 3.630410200303729*^9, {
   3.630410284327861*^9, 3.630410289259185*^9}, 3.6304118326123333`*^9}]
}, Open  ]],

Cell["Note that the timing of the 360\[Degree] nutation is correct", "Text",
 CellChangeTimes->{{3.630409507654352*^9, 3.63040951897099*^9}, {
  3.630410296739439*^9, 3.630410336284318*^9}, {3.6304118396729317`*^9, 
  3.630411851158684*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["track the state populations during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trajp1", ",", "trajp2", ",", "trajp3", ",", "trajp4"}], "}"}], 
  "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PopulationOperator", "[", 
        RowBox[{"3", "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{"1", "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "2"}], "]"}], ",", 
       RowBox[{"PopulationOperator", "[", 
        RowBox[{
         RowBox[{"-", "3"}], "/", "2"}], "]"}]}], "}"}]}], ",", 
    "\[IndentingNewLine]", "SatelliteSelective360", ",", 
    "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.630395432866467*^9, 3.63039547736121*^9}, 3.630395744054966*^9, {
   3.630398163355588*^9, 3.630398164199418*^9}, {3.6304095400696163`*^9, 
   3.630409550163752*^9}, 3.630410356978043*^9, 3.630411860849905*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, 
   3.630395478421029*^9, {3.6303957341222*^9, 3.6303957480936413`*^9}, 
   3.6303982188138123`*^9, 3.6304095554560413`*^9, 3.6304103596393623`*^9, 
   3.630411871346365*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"trajp1", "[", "t", "]"}], ",", 
     RowBox[{"trajp2", "[", "t", "]"}], ",", 
     RowBox[{"trajp3", "[", "t", "]"}], ",", 
     RowBox[{"trajp4", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "SatelliteSelective360", "]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Purple"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, {
   3.630395486202817*^9, 3.630395495394308*^9}, 3.630395738636546*^9, {
   3.630398235967197*^9, 3.630398320687645*^9}, {3.630410367911769*^9, 
   3.630410374706914*^9}, 3.630411869535996*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwU13c8lV8cB/CSVJKmEiqjVEJRIslHVFJSFFkRkr1l7z1zjWvPskKKCiFJ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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwU13c8le8bB3AJSZJkNZRRypaRkXxQViQ7W1YiK9kjIyt7b0URja/SENql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     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwU13c81f8XB3AJSQhZDWWUsndGOChbsrO3RFayV8jKvPa6iiKSr9IQGu+G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     "]]}, 
   {RGBColor[0.5, 0, 0.5], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwU13c8lV8cB3BJKqGpZJSVSigiI/mKJCUZkZWZ7C177+0a155lhRQVQo4k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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{0, Rational[1, 10] 3^Rational[-1, 2]}, {-1.4999999999999352`, 
     1.4999999999999352`}}, {{0, 0.05773502691896259}, {-1.4999999999999352`, 
     1.4999999999999352`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, 3.630395496235725*^9, {3.630395734190292*^9, 
   3.630395748162326*^9}, {3.630398227045518*^9, 3.630398290611651*^9}, 
   3.630398321328656*^9, 3.6304095607102737`*^9, 3.63041037551691*^9, 
   3.630411873245603*^9}]
}, Open  ]],

Cell["\<\
This shows that the modulated pulse only couples into the two satellite \
transitions\
\>", "Text",
 CellChangeTimes->{{3.630409585125308*^9, 3.630409600819336*^9}, {
  3.6304103810516243`*^9, 3.63041041924647*^9}, {3.630411880973818*^9, 
  3.630411891616262*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["track the single-transition operators during the pulse", "Section",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
  3.630395414602334*^9, 3.630395417930991*^9}, {3.630409623164311*^9, 
  3.6304096243668633`*^9}, {3.6304098777997227`*^9, 3.630409882017585*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"trajCs1", ",", "trajCc", ",", "trajCs2"}], "}"}], "=", 
  RowBox[{"Trajectory", "[", 
   RowBox[{
    RowBox[{"\[Rho]ini", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"3", "/", "2"}], ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], "]"}], ",", 
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "/", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], 
        "]"}], ",", 
       RowBox[{"SingleTransitionOperator", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"-", "3"}], "/", "2"}]}], "}"}], ",", "\"\<y\>\""}], 
        "]"}]}], "}"}]}], ",", "\[IndentingNewLine]", "SatelliteSelective360",
     ",", "\[IndentingNewLine]", 
    RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 CellChangeTimes->{{3.630395334250416*^9, 3.630395397953382*^9}, {
   3.630395432866467*^9, 3.63039547736121*^9}, 3.630395744054966*^9, {
   3.630398163355588*^9, 3.630398164199418*^9}, {3.6304095400696163`*^9, 
   3.630409550163752*^9}, {3.630409629830656*^9, 3.630409691897702*^9}, {
   3.630409824146407*^9, 3.630409867617508*^9}, 3.6304104297593937`*^9, 
   3.63041190270233*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm], ",", 
   TagBox[
    RowBox[{
     RowBox[{"TrajectoryFunction", "["}], 
     TagBox[
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox["\<\"0\"\>",
          0,
          Editable->False], ",", 
         InterpretationBox[
          RowBox[{"\<\"57.735\"\>", "\[Times]", 
           SuperscriptBox["10", "\<\"-3\"\>"]}],
          0.05773502691896259,
          AutoDelete->True]}], "}"}], "}"}],
      EngineeringForm], "\<\", <>]\"\>"}],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{{3.6303953633828297`*^9, 3.6303953990673943`*^9}, 
   3.630395478421029*^9, {3.6303957341222*^9, 3.6303957480936413`*^9}, 
   3.6303982188138123`*^9, 3.6304095554560413`*^9, 3.630409695773494*^9, {
   3.63040984682828*^9, 3.630409869201507*^9}, 3.63041043283385*^9, 
   3.630411911752211*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"trajCs1", "[", "t", "]"}], ",", 
     RowBox[{"trajCc", "[", "t", "]"}], ",", 
     RowBox[{"trajCs2", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"Duration", "[", "SatelliteSelective360", "]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Red"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Blue"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Darker", "[", "Green", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Purple"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.630395378080489*^9, 3.630395394429152*^9}, {
   3.630395486202817*^9, 3.630395495394308*^9}, 3.630395738636546*^9, {
   3.630398235967197*^9, 3.630398320687645*^9}, {3.63040970121209*^9, 
   3.630409731329905*^9}, {3.630409776387455*^9, 3.63040980568364*^9}, {
   3.630409854197014*^9, 3.630409858314198*^9}, {3.6304104417741947`*^9, 
   3.630410451783729*^9}, 3.6304119083603086`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwUV3c4kG8XliRJ0h5GQipJJS3hliIrISsJESGEjMxk7703WT9KZCY8QjYZ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     "]]}, 
   {RGBColor[0, 0, 1], Thickness[Large], Opacity[1.], LineBox[CompressedData["

1:eJwUl3c8Fe4XxyUkoUhlVUhLqEQhfKSlUl87WxEhM7KSbLL3niWERCQRj+y9
97yuoiQa2qrf/f11X+d1nue5nzPuPe8jaGKnbkZPR0f3hYmO7v+fIatVVhwK
XAoCuSPk9nRMTZmUYElY1GcFcROpcnPZm0Tuyl9Jsyh6VNxdOMsl40O8vi5+
U43iRLuVnIi2ZDQRUnw9fCZKCLZXjzzMF7xPHN8Yt5yIkgC/8j212OESIpD+
IUar8ggcorYnJM8/JR3at40tZyXxULe3WOprKRFuif8WKXUMYeNvf2Yyl5Oh
/E5hyuhx3Kj7xZbOWkn4K9IUEaWErqhdVhHlteRm7LU9rbtPYv9uQ9b4Xa9I
i/0BVo3Kk8g8XTFmHf6KOO1/MWw+ewpc9b2mWoZ1pDN5wDZc6iyi/+mgcKqe
CLukaHK3nYXgFnWtDukG4q5hInvfSBnzifXJupENZA/rR8bywHNg8NzvG3ms
kXje2ZA2OXoBSjY9J7XMmsiAbp/PdVsVKMQ+Wnz1qImIHE2y+ER/EVQD4/JL
75vI8NIeSUbRS+is+bXnkVkzEW//wBNRewmmb9f/vZ7eTPxyy/5xa/2H5zuu
Xt4/0Ey4D2WZbYUqYt807ks+2kJOpvvp6N9TRTxr3ay8aQuxZbW4kNmvChFX
5dyO0BaS5H5B4c12Ndh4ZoaeKG0hDW/FD4tYqIGlSnFT4lALWdbmFLZ7qgaj
/hKOjm8thLfx69ayVTX0UMz6Rze3ktNHRtf/PKMOmXvBv6rFWol91stV+Sh1
KLx9EX7rVCvRtO8/Ujejjsw3rZfv6LYSaSxYnZHQQIE/9WyDVSvhZ19zv81H
A34/QnmVXVvJv4lto5f6NfCC13PTOp9WQi0Q39S/SxNT89lL/wJbSZP76bOX
nTSR8mnXn8PBrST/nIHneIMmhI9KM6UFtZJwbsdnxlu08COHTeuEbyu5OX9v
cdZMC5wqfmU73VuJdnnmLotyLdjFvLWRsWklsv7P9RaZtPHXLfNspEEr2aHZ
FWV/WRt1Rd2+e5RbCf2uNy0rudroGVmZ+nuwlcx9+v3P9Yc2Qg74hPNztZK2
Ws5jf5QvQ93JEb4rLeRxxH5b76TLYGid5TrW20IijRQfMi5chv337By5/Bbi
JHZ54p6sDijtY/8S77YQnVWbzewhOngXmpqmptZC5Nr9zkeP6+CjdLqN9c4W
IpCc4r1VVBdckdSO5XfNhMHyaUWyhy5yd7oFUIubSQcTZc+D7XpgPvNB44hk
Myke/Ga411YP6otJPFkfm0hsNltcQY0e4g7wp6TR+ktf6fjaMmN9SNeJVZlz
NJGFO/HTDVkGEKm7q3/hRQPpUnm89dxnA9hLJbAq6DeQp3wNFzuVDGGWuvqE
41c9cX/xqWpw1hA7b54yCxWvJ+u/qiTO7TZGnra+s4zTK7JYb9pt5WyMdCne
xeS/taQn2p1puckYP5IT0pUDaokKt2bl7yNX4Oeb5x/CRwhXufc+hsErqKio
1tr0t5IEbGc7debPFSz09kxvfv+C/PBLNA7afRVFpxVMK/oryITGk3hW56sw
kp/zckksJw8+TTBs2WYCa8pVAbqVEiIhJj2zW9cUcn3627PFM0l37AxDtacp
9u76y5qWkkKsV4P3aWaboiyAfvNMfzzJaZ+081k2Bf1H0QQ9y2DCY+X7d8r/
GlSsDi7unHAFXW4XX+JTM7gkiu8dScxBGrsrDo6Y4ethF/7stY8g6yxo2vTH
DLpG79fKWBfA6bRT/oqyOQoydhY84S3G21keGbVpcyi+eLCRqbsM3QJm2iys
FpDNNbDJqamGdRC7e9ZhCwRTK1g3dNWA+ePzNOnLFljqnAksGCVQIixvzO9b
gPnzhxrvz7UoNyx2rJe2xJ68r/zfZuug0aiboGdkCdEjVjp+evX4KLq26pOv
JXatk2dK66qHyKoWvUC3JYSHTngfeNKA9OTfkR5mVqgJOiq+TrUJx+kflm0O
sYIQS53SoZImjFheGskvtkLt09HHNzY2g1Mma+fobyv8aVZin69rxpPM8yft
BW9gxVlux0buFqgwr5ivO3sDwpqS1TxWLfAfPlMkFX0DuW2Bs4UMrRDCx96O
5zewe/naouDFVtTkJH01nbyBfY7aQerRrfhxa1Euep81ls58uN/I2Ya4ybgr
+y9Z4xWO8v+82AaJ0/CrdbRGpe3a7W3+bbDmim5fqrGGWzVvo+j7NiRffSzS
OmsNpVdLz4e3taOlqOXeA2YbvD+7ECJ2oh3ffs++vSNmA9GiUh+R6+3Yde7f
WR11Gwxkc+u132uHajxvroSLDeqOHT/P9qgdnrNSTGypNpA3erR2qaEdhYfU
zOZrbeAVJPT4xmQ7xu5YN7x6Y4NZ6qkZv8/tYG4P3JXKYosd4vsLpRk6IMX9
wMf5oC02Ra8EBXB2wMSsZkZV0xbLyweMbbd3IPLpqOIBN1vE9n2++1G4AzX/
VjIY021xyPLMA7b9HVhU2fRvus4WknEyb5poNm/yAaPKeVs8oF9fv31vB87O
n6mOZbXDkJkAN5dgB5wkTfjtDtth/uN+vsJtHbjvfef2OW07WDXs13/L0oGe
rsSxXbft4BgT9LL9Vzv+8pXJ/M2wg8fAVmfd+XaIWnYnjjTY4UXjXva4nnbo
li98f/rODioc9Zd9yttRv8a34Mw6e6hdGbfbndQOvbxN46U89qi0Dqj0cW3H
p0vpLIKi9hCa1qGka7Yj6OsB2XAFezj1Uds9xdqxM/WF5W9Ve3zbeCp379p2
lCudTbIwtUesWfto+mAbLr4baBm8ZY+cs/WMC9lteB1h8kMpyB6eb64zbXRo
A8fkncvbH9PenxFg+PevFXm+GwKDiT3y7y7WD9W1QkEkqfx7rz2UEjvGsnxa
Ye1StqXvmz3Y18g+F/vZgrU7lE5jvQPyek61rD5pQXJDt1MhnwParOsax01b
0MLxvj9A0QFjp/2539L627jCde2KugO8o/X37bZtxjcjpiNXzRwwLpufFLW1
GbsKBaOPBzugKyF/Pa9xEzzP6Kh+7HdAqsWPQ5PdDdjy4c1dwzkHBIkt7g8y
a0BhjOOTth8OyMzdKp7/ox5jlHD2h9tv4kde2Uf3bfWQut3YoXv9JmxFKpgc
pF9h8YnEufpfN+GsKNnMs6sSJeKd52rZHZF/6JPu9eUKOD++fr5ayBFZP1Nu
uj9/DrqC1AvPzzvCeLvcHr/jz8CVw3SpINkRttY3rK9sK4Z86ph6jKwTHp8c
WfVjiwM93y2NyEtOcB1uUnf6FY6WpI2aYSZO8BL2TFzf5Qv1hFNagcFOeMe3
Z+WxvBYxjy66fHvMCTsNv05nvk8g4UE+Bqbut2D0Jjmj92gJ0Vi33fBK+C2s
U8n/dSHxKeEOeG5oeP8W6mQV03K+l5L7votGl9tuQZUv6D3zk3JS7ql99QKv
MwKizr2d+FlFbv/5eFVZ3BnfWx2ePDtZTRQ9QkxOKzlD79TDU6H3akibW60p
rJzhurqZCPvVkiknEfMjlc5gOdCiNvemjjz40mB+qMsZnE/e6hS61BOLm8bX
xajOeF0z0xXN1EA+28Va7GVxgZ5+9X19vkbyfEncUniHC8rQMc+a1Ug8bFot
BSVc8Pa1o5vHribCdOOvFZ+eC5yDeVeP72gm7e8Sb3DbuoCdfkfwlfhmEmlx
xHqLjws+h9jlL7LQeMjcwmZjvgvSWQziPrxtIQev9tmt/eWCufcqRenObYSF
cnsln9UVzN8bWA61tZHXRrvd1He6wp3nUfcB3naSbODqk3XKFS9HA8/JPGkn
TuOC685ddoXl7oPM0ivt5D+99pCPlq7gmwg8cVuqgzDo7IhDhCsuOdeHFRd2
kKmhZp75LFdIKq/7FUvtIC+0HNLDy1zBZL8+8j5XJ4kd4N11tNkVxkyK3ANK
ncRWoyF3ctQVEdO+v4VtOolyn42o/yLtvp2GYlRMJ9mltq1E9J8rzm4sDNxS
3kn+dtdKDXC4Ia+yaP2TgU4ycsmq8rawG1p1eKL1lzvJ087N2HXMDTU/kj14
mLpImEp1fds5N4w1fCme5+4iFu3myjcN3MAu2pveuLeLKJ3f1Mlj54aLbSky
pRJdhL/1hdorbzc4BoqtFMt0ke9nTYcsYt0Q7un5ksh1kb4mVv1NuW543ij4
nXK8ixSeLp9+/sINdwYr3bce6yIBDcbXjDvc8NjdJcREvItcPbn+HdO0G7RF
ooeaBbuIXN1Tm6JPNDtuyOYcRxfZesLgsxaDO/qY+esXVjvJR8Lo8merO0om
px88ed1J2hWe/M7e7w66gZ+SqS2dJKdax0tFzh2nfG8tleV1Ei85esaVS+6Q
vuCW8Nevk+hVFdxLueoOkX+aSp6GnURKVov9pJM7ZtXqlWUkOsmmF3+jFwLc
cazAWFlqbSdZOJa3LTrJHUb7/9vp2tNBGsrVUmUK3fGAbvO7dckdJEPqt8BM
jTtE72T+XjDuIJpHLokceu2Ol52x1xsp7UT86fei4W/uuE8pcm9LaSfrD2cd
ubv+NqZbfp5W0GgnNeIrcl3it5E/viMm4nkb2S+S/J+12214rH3yqUS7lTA8
OjmwOfQ26PauXGOg8fzU3g86Vem3Ufko7xxjdAuJ3a1owtJwGwnW0Q+lapvJ
X4E5pzx2D0SPtu5U/9ZIRjIifv4n6IHds9lm3B6NpHSHjOf3Ix7QVEoZGPnb
QCz4QwPP6HpA59dW9Zu/60nfNonk1w88kH6Jk1Wh7xUZt327zFfhATfl4bX1
kq/I68b00xodHnCaqziyL7aWfHXc8OnVigcWMukeFcTUEO6e12czTt9BkyOj
oOHuF8QoKOGr7vwdeA7kchs+yScLP1ZVu0XuYmJO10T8v0f48l9pDhPu4r1O
5OPmB4VYzbFclde4C49gu3fx35+ATWsot/D2XUgncqyculiKQyVP/t7ruIvF
QWHGkqkXkGE213xFuYtPo4qPC+5UQcmYP//Hyl0klZU5zPNUIz+gIb+U3QtH
PQQqXYVrUSV5WFvomBf2xbml+8rVQ/EK6xqFE16Y2/T34cxqPRpC5gt0L3ih
4ch5lbLKBnRQ09ZEGXuB7nPFz73iTZiKZHn8L9ALroe0TTw+tsDk5ZvLfNFe
iOmwpStObMX8fC39sVQvKN1fl3pOvg0fFVx0bIu9kKkTOi11ux1rPsyunRzx
gh8ry5WRpk4sRKXcaaV6YduLpz2PVLrQd1Tj+7NFL6QLNYlJdHUh26tuIZzO
GxIsxVObG7oRutv92m0WbziHGX0R4u/BrbbDU9e5vGm8USX8UaMHZ7iyehX3
eWPrMbcU/5c9EH+hc0FMwhtxi1yeCh96sM1oUyOPnDeK7nm2hPL1gm5tiwLT
GW/Qc33faXW2F29z71Z8/s8bsrwpJT32vehROSYxreuNMYcjh6sSevHi01JB
u6k3VjXKhoVf9iL4uFFGtos3RBs/bzD704ublC08Ud7emOh7FiPJ2wd9/87o
OyHeUP5kcfiWZB9OifizWsV5Y4GeO0FYpQ+i3XIB2hneyD7P+kHxah+4nFb+
KT3yhoHB7a4Wxz784S50O1jqjXo7pjNVvn2Yqzb9wlftDXXrjW3bovrQZcJn
w9zsjQ0H30lPpfShfF3/3EqPNwwfvx1gz+5DRmHwlZkxb3D2GSjmP+pDkJrS
WOdrb1hXOrqVFPbB/ttPjcolbyy6bBra/bgPuiklnTk/vNH3O/Efc0EflBQt
z8bQ+0DnT92SQU4fRN4IvLrL6oOWxWvzuzL6sDl4RNZ6qw9Y61WdrsT1YVU8
skxHwAdxVgqmW+714XX/WfHTIj4wvdpee9q9D52u/3IPS/qglzNuYMWCpnf7
c8EdCj5oeui4fY9WH9LrbFNYlH3AEjp6cVKhD4HX92z5ruYDdkMD5R17aHpZ
p8Jn9X1QIGzD/4GlDzolccw9Zj5wmj259tKHXihqX/R5aecDzov0hqc7e7H/
N8NqnpsPKiM5iobze/HrlNOyd5gPFA5wL08b9YL67oClbYIP7fe46Z6xVC/a
w2epelk+yFzzzipsfS9SR9SHjjzzQSK9eBhzQQ/87rCoChAfrKtSVbvi2gMb
obpW1lYfcCQlmd4+2QMF68PVbyZ8MCSKbbtyurGH493RvjkfeOVtGT14sBsb
yzOLaz76oEbPzPxjaRco/zZmJzD44tSVfJ2XxZ1oyW7e7sfui6773esp+zpR
cu5ugj03za9StPttagd8YpaCz4n6oo5fg2mUxrO793Y6/NbwhR7XoGb5mlZw
q4SKyRv64rXl1h/dZi1gdbjwztPcF9am93PLm5rxubL1Cr2bL0wvDJ7fcbcJ
tZea/luf7ovcf3k5ve310HMmYtve+kJxcG2BcEMVLqZ4vtP55IuToczT5Ucq
oVgr/zD5ly+Ezxy69zq9AntZXvLvYPNDx9/NZhUWz7CSVrFht4QfpJkbufak
P0ZEY8k7CQ8/LEYElA5vdoDPgv1DJ38/jDoKPub9YEacNx66Wh7uB7mmrBDt
YF9ioFs0IpPlBwX1ngDZ6QQi8iG/WbHJD+bVIwFfOfJJA1f2w0ub/OHbaDIf
T19FnsuYXo3k8ceEp2HrQMVLkm8ktL1PyB+VXt9yDlnXkKi8zFgtKX9sfvyI
KfF1LTGSS/M10PPHXEL+mI1IA/lpGn/VKtsfB69+FAyRayMMX8cZnYr8MfQr
dmYzXTthDxDMv1PhD/Umj4hg0k6E8go/R3b4Y9e7wtayw51EVOZzfPKQP64M
KFoL0+bxsbZjx7Mp/rD3UcSvqC6isljn+3zFHwuxmyoNpruJ9h3mfa/++tN4
5KL0ZfSQq+yXOtqYAzBx/fMJ19Ae4nxolGuKPwALljvyl3b0Eq9XO17M7wlA
fO28z4FrvSRE/Zrhp0MBSL9r6vMkp5dkOi0/ZDgdAM+iOEbTXX0kn1HqPPt/
ATh0y+DIXcM+8izefWmbbgB6bgpOVMX2kdq9tdGCpgFgGwn8tqm1j7RVMB47
YBMAXt/pHS6/+sjAuQvjki4BeNv1Mm5+Xz+ZGou8q+AdgMVdBxQMNPvJl1W+
FrW4ADwt6+iSu99P/oZdtdbPCAAfz9rYjIZ+wrwzd5PZowCwqlQqrMz2E87i
xTLb0gBUcpaWH6MbIPwnJHRdqwPwepnD6TrPANnT5/LHuzkA/o/1bnsfHCCH
TauzQnoDwIIjun5KA0Ruhf5M3HgAVsZXttupD5Az/soL6W8C8NmYU/eE8QBR
3RoenrdMy5eQPtdviwGin9sv8fRnACIfCnan2g0Qc2me4aq1geD+ctFtr+MA
sW81ut3IFgiv6Ku2qTTbXS97Z/e2QIxdvGX/x36A+L1/Vz8iGAj2UekHKjcG
SLjHQQvqgUAY7/odEGoyQJLYbrEuSgVC1afuC9EeINnplcVfEQj6uttcC2cH
SNFBOq1/5wJB9/OMCfvRAVJRe/ons2YgFpveZhwSHCB1aiFpnEaB2GpuPqi5
foB0UHtO8FsEIra478LdpX4y7Lh1bvfNQCzRqd8r6+knVAaD4IMegYjx07v4
80k/WYzLEpcJCIQdpMLUQ/vJtz3zfUqRgcg1b7RvNOsnaypEXVSSAyGqkPzf
Zbl+snXsOTEuCoS2jbzcEqWPCNz4Y2pZEQj3Yz69f4v6yIFVJWbHukBsHtO3
of0/E8UdXaoBQ4GQSF1/M4y5j5x/svlrBCUQAUz7YlLae4mWom5S0kIg1gln
ifwM6SVWJq9nCv8GQpF7uKqaoZfE5Py62b8nCEGuqydMi7pJ3vOzuhKHgkCV
j99Kv7Wb1LTEIkomCIdvfvqg6dZF3i6Is/6nEoSqvybrLxzpJHIHTR+2OQTB
VDSD+vNWG5l73j786mUQzprcU31ysoH8buGuEWgKgvaV9/SuNvVk05hZ9t3u
IJiZ1NN/jakjsqv/7OWpQfAJz91mNFxLIhQlWV6suwc94VH1LKdKIt2aKles
fg97ZNJ2ZXLnkItj74Q2GtyDh1LWkS0894nJ+6Prbc3uwZXRgClkdyoJZesd
POB6Dyn21g3m3YFkRo3RLjftHvZ9lvVkXh+H4DGbrPS397DN+EFO48dnyHhf
Gfjn0z0M2YRaTTFWoGx1na3B73sQ53bQb+KpxPSO+7K87MGYvdCvQORqIGk6
1B93JBiV7p/HDh2px+R7BaYwz2CIpLiu06Nrh7azRdXLwGC837jrYNK7dvTQ
RdsvRgbDunyuf6S7A3Vb3oxdeBCM9I7ddW3RXchDyBOWlmAonWX5o/O9B4Jt
Zddke4NhxX1fZQtt3iVrTvFYjQWDvaBZrL2uF2GWh/1aF4PhHBV/dN6/Dzdj
hnWCOEJQrnHbT+1TPxa3r2Gv4A2Bwo2ROuUzAzDLE6mf3xWCl4e0L3QkDkCn
+o7Y2aMhmHk7knL+6CB6z+bSttkQnKLuGD7oPYjzfT0JOcohEPeJPe3cOgj5
+V30TPohuMf65vQa9SGUO1x8LnUtBBLXSq5LRg/h0KqztZlNCDa8aJh42D0E
IY62oYa7Ifjw0T1ij9IwUlO+hKwEhcDlpKbHPpdhbNmz/YRwdAhEjea5Lz0a
BvNx+wLf7BCMvLt0bplhBD6NSVdKH4fgktu1kKviI/j9X/2W2XKa3qCRwdea
I3AaW2zjrA3BZ9ue4luuI1i6ttVLqTUEyh5ivBxJI7i+DKmbfSGoNmfwLSsf
AcXNciFrPAT83u0dhr0j0GOIyeh9HYLZcP0zG96NoD/8peaapRB8q36dV/Vn
BCo8c+sPfw9B5YExLtuNo2h6sJFcoQsF3dtH7EI7RgFxGafI9aFg23L59vD+
UVRUmOyv5QxFXfa2tHCJUUicDJ1a5gvFt+ZvG5WlR1HQ+Sxm5+5QXLHVa2I4
PgphnWnl/8RDIZF3m7FJdhTpVOa/nsdC4f7309WwY6PgtpEoLVIMxe5GtZcG
h0cR9V3fYupcKBSd6+WP7hsFi4//dnaNUPTVp2vy84/SuPxJn7xBKCze7Cnh
YBvFn/iRQBuzUHQaXlfi+T0CZ0F6+TTbUKzt3H7k6NwIPhYc+NzhEooVvudz
N7pGYHlUK3fVKxRFh9y/VZeOgFrraSAaHIqAD1Pih+JHYHAhj8MgJhRlgmvD
mm6NYHCwtykkNRRgVJTzVx/BpSu/b1c9DMWT7m8x9qIjaFkQPvy+iBbPUvSW
sLUjOHHr0hxvRShOsT23mh4ehmRwlqp7Wyj0Ujy/SrsOo8FLbclhIBQCMRcY
ajEMLZc1oZZTodj06k7AVoZhOF+72qzzORQ1ysUJF32HwKTPYaa6Goq23gFH
OYUhJKi9oldmCkPR0n7Dbd8GUaEgqHCMNww7YnmWnhgMQlmqd1xcOAyqZ25d
vrNhEKMHvN32iIfBq2JUQ/v5AH5xz5RtUQqDUNvuJypMAzj+JfPAimUY9BsU
Hiv59KHjnWrre8cwnBHcKGhK2w8MKHTXZ++E4VLPL+uRJ73w6Lxyvy8qDNW3
Du1+39eDmlwBnpIXYTBaEkXH104oGWQy2a4Px2XNL68FKhvRp66abbY5HM+m
o2uPZjbA9BydkuF2mr26pTjZpx5+R6/cUTkcji7zoZhBuVdo2iSwIqIbDmPt
ALadW1/gfGPGzHxeOG7up2+/Fh4HNfGMl1eVIxCeNJcRGfKKLGZrpxapRaCF
bsr6XUkdCeJj9/itF4G3dnobzgzVkxrmO8fjbCKw56hKsxZ3ExGZ1atsiY6A
Av31pHcebaRRlzN5S2oEDq4J63UPbydXelrdTB7Szo8I3X+c2kESqqVlVp9H
4OxnbeX/iroIQ+LWioOTEXgqrDLNoNZLMti7EjzmIqC+81PalrZeIuvv79K6
HIFnPfwhw4p9RFrGPeXwmkhEqlYs7dnbT+z2vNNr3xyJKutsyW2DA+TlTEOb
A3ck8i89e9grM0hY0jJlubdHIvXMmxuVKYMkZ7MOr9meSJi3Tg9Maw+RCbrm
0b/SkUiemcnnfjRMRF7eP/dQPhLWc9NXKF+HiYuL54sLSpFw1/x81QUjhHNJ
KinxQiSOCscwLreMkCuPONZDNRLM6V5rCfMoKbr2wfWNZiR0zM6ukT89Ss6N
Z+tIGNH0Un/t3Fc2SuLjvVpGTCLR1l6peG9ulLxWM5C+ez0SEU2TBl5bxogE
m3TebutIqDvXjTCfGCNeLZu5O+wj0RHA+WCH5Rjp8l0OvHkrEp4Cfw7XhI0R
PrR/53aPhL+SgtfrojFi8SvnOvGkxTPBxhLRMUbKn/kMm/lG4oHwt9aquTHC
4GB0ljUoEgtrgqUs/4wRNVHZ509DI/FwYkYmftM4SZ/fslc3KhJsmVuklQTG
yeL9T/H/4iLBkFOwxkZ0nMgadTLlJEfixTTz4FapcRLI88hZJSMSfWtf6irK
jpOBAb+5zw8iIRPelrpwfJwIRV7RTsqj3X+6nm0bzW9/Qa4JjyNBJgNdmiXH
STUT99G5Elr+1v9c+/fAOGGp+/IwtDwSW7cJHa7eOU507nRvOVJF03PNvHcd
TV+OdIH/KImEbLnDupnVMbLyJeDr3YZIfDzFeFKFFp/SExOzPa2R8OntlL9I
iz/CSmGwo5NWvwSzH/O0/LzVN5QZ7otEkeM1qnQI7fxFj7SZYVp9dE9yxJuO
kRSFlDWLE5FY0dx9n1Ga9v7BSrNvM5EI0HVgDGceIxcFR1vp5iMRb/nyt9Tg
KMnh/CG2YTESh3LWxzCkjxKdr1Lfdn6LREZVp9oR4VFSMqepJ/I7Ej9qkxke
zIwQlhHHGkm6KNRabrPWSRkh1ZUlAedYoqA+/9u2fO0I2VrYs6CxMQrZH1Rr
7Z8OE/u05UtGXFGYGN0vEWs4TIS8xLY57oiCpf3NYblHQ+S2g8rtO7uisPSv
e2Hw3BAZMLkxHbgvCj+ZtWb+zQ2SgNOPclMlonAw4pTx4W2D5D3LbummM1Hg
P+KprKzaT06tnkztuRAFC/lR8eyhPpL+wYRuXDUKRXzf9y/r9hHVnsyWZb0o
3OzeLB10uZeUxfHr8thFIVZCyO/xlS7CFni8epdTFNg+9kQ4oJOYu+oJirtF
YddI0N01PB2EWz/xnZJvFJgGNxWxVbeSOwJc7tYJUeClZ9vf1dFAzhRsSCEk
Cm0uKuz+BmVktPbXhNmmaKw+uW/teO0FXi8F5ulsiYayq3n5MZmX+Mi/xekC
bzQkM9Zrf9pAwOR2cMNh4Wh43j+vVqpZB8nD12RWj0WjqLsyPH28GTD+xLAs
F403qk+2nD/WivNhnj0zJ6Ih3NazkTOyDVffJV5vvhCNdQ+4JjdIdyI8qzMu
2jgaQ19MDz8S60VSt95V/2vR8LhdFtTY0YvsP/OirpbR0Cn/cTjUsg9VuvQN
ho7RsJ+gn3mc0o+3HMc+7wuMxqLao9Zb04P4goZqvtBonPRLfMFlOYS/Nmr3
2KOikaiyWSZheQhb2m4IrCTT9Ajxmi9/HoaST+YlUhQN2z/xK096RnGxWIz3
aWk0xvzJQRGMQWeq8k12RTSWnu5Zff9oDHaygx7BddGgj2HuZHIah7uFifKd
5mikjwazK/WPIyB+ebN9RzQ0nj0yuCc+gdTP6wu0hqLx9vVunfWjE8gVSHBW
Ho+GwXvbNJF9k3h6SVjpOCUa2lnM2/c7TqLGo4RN/E00jAPuc/9+MYnWfIVR
gYVo5F3XS0hYncTASHv25uVoGn9eMf0mOwUKk64900o0KrPPrtt0awrvJeeO
//wRDYlp1vbJ/Cl8M3Fct/gnGtU+g8W6E1NYE0XXP0Ufg2tLVg6e66fBSsLS
e9fFYIPYHdezEtPg/sBr1cAaA/7SUkqx9jR28eVJPeeIwdYfUXbPnachfk5q
Tf7WGDRSj0bpRE9D1qWuI5UvBu0b/2pEP5rG6Yf/JUYIxODXGpZrpi+nodo/
YeqzOwaqhwhTe9s09NdYHbwlEgNK/dGtrQPTMD/4/df1gzFgFC9YNRybxk1D
vyY9yRiM3Hn/JHh8GndCOKIvytDsl2OFqiPTCHqRbqioEIOiS2u+lPRMI3b+
wP4jJ2PwIucoXUnDNDK2vFjZrRwDFivLDtWyaeSfPFPLfTEGh/pCGmMzplF5
eFi0XC0GhXqLFzWDptG+0yJJQzsGc6KTB1VtpjHB9pPxk14M0n48PhZ6aRqL
v+/dDDeOwanjF71YRafx5x3v9IFrMSjJ4HUYZJwG+0jBhVYLWnzti1Xvx6dw
sKxTmOFmDP5+3xDJdWcKiveNorKcY3CCQ3LmsPIUbXQt/1G4HYOcZh2epxun
cNOaY9jNLwZ5G/Wff4mZhI/e/ZPb7sWgTf7jn1eqk4hRPlJcFhaDOu1X71lZ
JlEmrHVvOT4Ge6YHz0jdnEAD59zX0JQYnDF6myQoOIFBOhcTkcwYrNBJXcnr
GMe3icTjZo9iEJGqPfGQZxwycRMfxqpo+a7kOKEROorzvjZ6rrUxCGLr2skg
OAo9h79NWxpj4J5/0C/h6Qg8LgpkqnbFQH4sWjKiYxg1jNfUmygxKHa4WLQy
MYiuLys1pm9o5/W/yyzoDmJ6xv/AmoUYaOY8Fd4+MAC6mlwGuS8xeLazl2pb
24+Tzu/LSxhjEf1Lfv8J9160zN3kSxOJxakHo4l1/1owMrA2SPZgLI7KDn3f
/KQZ7+piV4aPxGJi15zUqF4TWDLKOznlY+GcVhWil1ePi5d/3Q36LxZ7F3b/
vICX6Gv2fu3oFIv4of7eYwfisPRe6/Qtt1g0XVcWfErvDZZNIjnOnrH4xtkg
51hjT07q9F13C4pFkE/0m9b0NFL2Vui9Z2osHPJz80/sKCNx6xs+3WuIRaHv
s6Jz95rIU7FE9ZDWWIz6vTFtZmshXWrWpaFdsXhK6ozWRLQSpmSuWxEjsdhZ
YRj3IKCDOIuY/YhdjEWOxE6OdsFeonOB6V8GVxzuSjtv1TUeIk52Y8ZZPHHQ
mOjoWPwxRCJjimrv74jDQOtiKWPEMGkd1/Z5uC8ONT7t/ubFI2Tun8hsjlgc
ajVf8HodHyX0wv9O5knEobjMXr6ubpTIWucyFsjFYd2aR2bWjWNEO/K2eeGJ
ONTN9KQVKo6Tm2X/NT8+E4ebFf2djc/HSf7q96Bi1TishvEOySVNkCaBjncl
WnF47dn0zG3tJKGeyjxfqheHff470y5aThK+MGXW8mtxyLO+uMln7xSRLuG3
eW4ZB4nt80Etd6eI5uDHzgrbOJQ7GVEc+qeI/c8G8UrHOGzCITFHoWkSuj0p
oso1DqyZPAZ11tMk74TNx5d3aPoUS8W0n06TBrMTajU+cTAMqz6y58s0odzb
8pQExoEJm6/HbaOQ1cfvOF+FxmFO422M+BEK4e6rdqyLonF1amSSvgqFSH6L
GqiPj8OPAbF+HlMKUeU1l2pMiYMd87vf5i4UYqMgG9+UGYdu3x+iJ+5RSLAJ
+/fmh3EY4k4Yz0mkkJwA6uXW/DhkiH8cin9IIXX55RVtT+JQeIDhzKZiCpnq
CubpKItD/d57DzkrKISu1ITP9UUcwl49H1WvphDBBNntwjVxiC5rOGpTSyFK
tzl39tTR4hFV5zR5RSHXjBcEPJrjAN/p1cM0f8DJOqF9HXFoKTesnXxJIbl7
k4UHeuJw/kG3kflzCmnZcHOP12AcuA7Pb+p8QiELy+f2iY7F4ejss1ObcyiE
dUBQZGQqDqF5NqmyyRQiVvHzgN9sHDLbj344FUohl1J7xQ69jUMTwyYFSQ8K
sfd6dHBiMQ4MplVNLFYUEn3N+3DQpzjcutSw1KZFIWXKukckv8XB72qKigso
ZEj0sBTlVxyEc9uzOfdSyPdN64+F/qPpS5V5l8FKy/9XirQ0Qzx8Ln23P0WZ
JrKjFbKvmeNhYJVQKfNgmnhmWSjIccYj/OR2Xc7t0yTTX1Hx7dZ4rEh/CWYY
mCKvLLmVYvni8c+ACDAGThEGiZbTi8LxyGYPm1afmSR7tmaeTdwfj4feHVEl
QZPk7C+Xc6fE46GaO1x5QnSSBNftvZh6LB4vh5WltltMkE0agZoq5+PRKjes
OltK4/tjxto/LsXDWTN58YP8GNHgO6aTrRFPq/fle14NtP1gdk5/1SAeDy6c
GrFrHiH8TmdMC+3iIfLNJ3zh4RDZH8d4kzUuHhdgWCbX10vOu006ViTFw7Tx
OLPzgV5ibfjs1rX0eFzx/yQs7tNDinebub3MjYfi7fb8LtUucrS8wcu6Mh77
qlRdDMtaiNKwb0THdDx227Y935/4gth9SvefeB2P5Db+IXmlcpK6ofL24rt4
rPKm1ArNPyXf8PE660o8whxU1oycySMFeQaKKswJcOhVjfYrcwWXu9Sn9kMJ
2Ok2aOC6oRonYlXnx6USoCVklb8gUwvbohuT72UT4Bnz+OrFxVdooWa1bjid
AIb1O/eFnW/EnQvs9y/oJiA39tB/m9+0Y45/Xr3dOwFdVaUNJiID2HyM/tx4
QAKtExTXhb4ZgKLadrwPScDN24YC+WmDSPbXOLAhPgFbdLtHLtD2//+WyNoL
+QlY3K1ctpo7Cg/m8Z96TxIwvOe/8oyzY8gX+rZsVZaA8R+l63Vmx8BwWXQi
uCYBQUUlN3PZJ1BBEsva+hJw54991lmJKbwZLc0fG07A6/QfM1uKp8C50pW5
MJGA3uenGC/un4b1PsYwlvkEJKzn4xxhoiBJScCXdzEBa9b2lRrKUdBkcNxN
5FMCnqzRYXexo0AgysHs/G+av/PoP+UuCi4WhOrr0SXCvWGxZOUnBe6NuWpW
jImoPumlybtrBrnTdWfdWRIhldjmV3ZuBgM/J+WDNybi13udCzU2M1jD9fNI
MlciTMT38R6JmIG4OJdIPk8i4uuU29mLZmCgfFCgckci3uy2ybjYNoN7Jue3
tu1KBGOfudzi7AwsXvQ71u1LRMFRsySfXzNQ3mTYWymWCO1UltIQdir2Xp8T
L5VIBLfoK3tGASqYauxCC44lYqpriWNJnIo3XD/fPZBLhJy7neip41Q03PA5
m3oiEc95OAqYTlPxoG7Dw9gzidihvblDUoUKH544+rALiVj9WLCzS5WKq/Y7
rvirJsK+JDagT50Kxebc6jtaiWi5lX1IiWYL7DjM56yXCP7rt1K2/0fFP6dK
V1vjRNRp8kaZnaNiqv3kkPm1RIRve7OH7wQVNUKdR4wtExFaShvGR6lIc9OO
umybiICepJ8D+6jw6Jle+s8xEV4x1t0T3FTo77VUUXZNBJ+p5i1dJipkPT8/
UryTCIN1SpYXP82Ad/D2OhmfRIjvbLStGp3BzwOMZocDaXpm7cJzyAxGfMLr
9ocmYk+S5hbOBzOoGN0mIBSViIOfUmPX+M3AOVBknDMlEfS1zzZ7KMxAa6pU
ekNmIoJzWII2cs9AUko+fu3DRKj6FU0eW6bgC/U/tZWiRKQXx63qxVPQJzNa
tFiaiNfMcpevmFPwNNKE9U1FIu6/iijfKEmBvcKt5sG6RDhpBoqvj5rGf3F/
hbuaE2F0zCjz8Q4aLy8G+jR1JEI6km51JHcKH5KS5Z8PJeJlnavxn8JJWH0l
pYkLifi7dpLxgN84zqmc44haptUrr2d7yfIY9j3os723QvPfZRtTuDyGOdU3
+93/0vJZUVD7kncUpoUsmfqcSbhT9arZ6dYQlNbG/tHYloQhMVtt8/pBCOlt
11fhT0KQuq0lE/sgKOsObZXfkwRTXyXFkqR+GJhqhe6QTUK+yiqPbVgPtHkz
XWeuJqFD4ttk1Wo9ZA+LufiZJ4HrVcGGx9fqsFO58tbeG0lgorv4mdJai7e3
Bm7aOCWBz2O3fStPFdx7mW1+BiRhUwHz/O4PBcgIcrjKUZgE4UK1qQdaj4hf
xl/jsuIkPB1wcQn+84RYlIcYXX6WBJXWz0F71UqJxOuH+mk1SbT9X8LNbPkF
acCY1v7eJEh0Kp7y9aknb78pnT/xLQn0jQzft7P2kA62HuXXv5KgZF/5Rbez
h5QIG54N/JcETX2PZZvQXuKu7nKqkzkZRnzKR8rX9hO2ogIFXb5k2IqlbF8/
MEg+N0jLr+5MRr81f/1J7yEyNN54PEM4Gd+U78pHHxgmmesp0m/EklH+OOcB
h8sIkTDjOuKgmAwJWdMnyvNjZKtH1mGu08lQ9dL90uE+Tn5Hix96fi4Z3N9/
8LximSANtcpif9STweyjTy3ZOUnyhgcPZF5OxvTapxah2ZMkbMlE5KRBMuzP
LqVG754i2vx39t4zS8Zl+hN2r/lo8/QIyx5Rq2ScgB/hjJomO88nCHfbJmMg
4DgHzxoKeetSIrjFNRnrsgq4mK0ppDNcQaDCIxkuFg779dMp5OnD9h363smg
31iqEt5FIbf73/BlBSej7P3hsLv7Zoi1QDl7XkQybX/4tS9Na4YY2ASseRKb
DOcvWbW7vGaISqX2yrOkZCiyyjKy580QuXV751+m0+Jn5GG73DlDRDW/j9Y/
SEalQLv6r+UZwp/V3NGWl4yTs99Kv2ykEtalBNL7OBl9kcfsIUYlq7IWT0ee
JqPT9ePesbNUshgo/XD6eTIKi/nGa42pZGKAOXHuZTJed259+9GJSjoER4M/
vEqGJ589i0Uglby0fXRnpSkZY8XlusIJVFJY5Wb/uz0Zpc/+UxbOppJU5vOm
9L3J0FPTuG9eRCWhWrza64eSUTd1M3ThGZXcub+gvGk8GTbknc+TSiqxXa48
vo1Cy1flbZ1nL6nESC5EfMebZIjw+0itVlHJpXv6grsXaPn+zZzgV0ElCkMH
uESXk+G3/Ofif0+pRHzXKtORlWQsnXXwNHxEJTvsO37K/EzG+dqF9OI0KmGv
Tl1U/JsMeaM+l/MRVPJ3vc302bUpSGBbEhLzpJIlbfm+S8wpCFdfYdG3opKp
B2yNWmwpCHaUfD+kQSVdHyefG3CmIH5Fo/uBLJXUyBflm25LwaZzApsbd1BJ
UbBnmhV/Cibcb5ko0FFJ+vClSAfBFFCmpV9snp4hdx2Wb909kALZR0f+zMbO
EPsaYhFwKAVe4scd396YIVc2ROqHSaVA7EI9vYHiDFF8eOhEClIgHPXgR84M
hRz6TCd5/1QKEo9N2gUXUYgAevc8OpcC9vOHd311pfHvqAPrc40U7PN68e42
E4V83K30r1onBckf/p6+GEPj95ucnxsMU/D0J137e65pUstaOtx3PQU7LIeo
p1mmiLfiyv2l2ymwCOIPu0Jo+0lYQ9xXrxS4b66SWRQcJyZjsUGr/ikwyxTn
1vYaI0pOUrYskSm4rbg0yHeYtv/kOcvsyU7BlTnnEz+vDRHfjT+7DTtSsIdZ
w/G2aA9x5e803dibglShor0GnV3Edn/W99rBFKQ9YLhlL99JdE+e2yk8TcuP
TNImZ442ctAlyXbhUwpmIcfeE15Pxqdk2Fy2pULe4eqgFPJIz3u2rH38qXCw
chZvMc0iTT9mJMcEUnFc/XOaD0scKeEMNpAXSUWNp/Sc14IbAs+MFayVT0Xw
iszuxeoiHClyPx9pkgpNf2s90aONNC68NHXieipytjHuZJlswo4WoZtfbqRC
iOt44aJXC9ZT25K0b9H8dZ0vx2raMb2F7x1/UCrSvdl+pzD1YkBo2aMrNBX7
m7TGWdp70XawfpNXVCp2XCYOO8P68OzcDenZ5FRwMmyq6ls/gJA7VYGPHqfi
Y0ry6iPqELyCI/j0n6ZCdjJqLiRqGM4Jpk9Yn6dC5kZZvpr8CK6WbBi2q03F
1skHlw+HjOLYG/09R/tTsX48Luv3n3GIfj5YOT+cCi+OEq7SqAkI/Vt7KWki
Fc+aWlsfC06Cjafw1uqbVLwOt9bee3QKsyqrDXU/UvHNlrGjZBsFwfEKtQZ/
UuG8/6RFvCoFEhSvqm9r0tAgSE1xDKTAx5HxqciGNJQzL8T8W6JApPrs44aN
aYC+xpv7O2fQyxScZ8SVhjfPbs3vvTQDgWT2jOjtaQhezPhclz2DllnVZFGh
NNBbKCR3d8zATiwmrmlPGmR45sULPs9gq8tg5JUDafDwk7+vtpXGL7XbQn8d
TMMYdfsecowKcxa9wFjJNNQJ7BL9qE0Fm2aqj7hMGposZM1mHKkoS5u60yJP
05t74lVEOBUG8wJuJkppMLR7ZPsjhwqGw6ZOq2fScHcf0xh3NRUF7g/t4i+k
QcH86eOlHirUG+atDqmmYV7ybq8LlYpfbCLmbZpp6OiytXr6iYr7l62vXtNN
Q6jNlbHUv1Sczyoy+GuYhptq3URq/Sw+L3y8nGiShqGVrK+3OWaRJHlEQ+J6
Gmr/McfYbpuFouetSx030sBcoPqelW8Wb5ufnzO3T8Oxx41h2vyziOT4dYru
VhpehhecvkDzS+vLKSa7paFI9Azve9p9SrbncUnPNFiYD106yjmLwKXao10+
aeAtyzMRY5mFuPRaCYvANAjoSXH0/qNiyPu0GH1oGsyltNSFvlDh2R64LzUy
DadaLPWEXlOxe0vbrqNxaeAPiUnu66Oiw4h1Z09SGtjpftZKEiqc8i7xWqWn
wYci+OL8Iyr4P0duYXiQhuKlU4Vbo2h8e7x/U3puGqx80tekOFOxufvyur5i
WjzLTnnDslRUcifTWz9LgxqvKn08DxUmJhN/GCvT4GX1qZv72wyefr2yIlOf
hovVrPHueTPQw4Pl/uY0JF50TrzqSeP5e28WbDpo+ag037VdfQaq/FYzWYO0
ftm8/EL4CwU/zAonjo/R9M93TrvXUpDxZGl4cIrWH1Yh9S9CKFhScuxa/zYN
4gHHppn5KQi19Khy+JUG4bp/B2TPTUGytKZ8w7808OUk/uuun8T4Kt3Th2vT
ccYYj7JkJyES6Z83ypoO5rcP3h3bPoHW8vC4EzvTkTd7QZSlgrZPHeXyh3A6
Phe/4nNmHsWh8iQn+f3p8GBk+sirNYL4Z9kaMkfSwRCuouQ8OwSTskqOw2fT
MbhDU/rGcD9WS+bCBOzSYcybG6xl3QbxxwoB/2rSwX+DKeGWQyyZEW249ac+
HawVL5ouJWSR2MJzZr9b0rHzWI7J88955FeB5qnvfbTvN/mWV95ZSprzreiX
59JBnmiMC+9+Ra7kxXtOsWdgtf6XffGGbrJ5H7/txOYMLDxqL8vW6yFNuVmG
Y9wZ+H3LTmhWtJeI5RbKDQllYCKP7vbx1j7y62Hdr86jGaipT92xa2qQPN6t
vNB+PAPlavVKp1KGyJWHnaOtihngKHsY8VlzmDRlj1Q0ns9AbYy5c2T1CIl5
sORcbZSBxSK3/aJXx4nKrMs6c9MMbGpizIn8Ok4Ydq1JZLfIQOhs4k/1gAni
fH/zC2OHDFx5l1v0JHWSiFNTzzE7Z8CHq/qBiNAUmRfcM1bsngEr3mvxDQ+m
iE6W9O81fhnYz3Zamz9lmmyaeRWSH5SB4Q0ZdsbMFNIqcIFfIywDGpQ1S8In
KEQ201A+Oz4D0h7lwk6FFPJ5eq5TJSUDZnP/Tn2eopCCnfZGXzMyEDtsaHtx
I42fMnzunnmUgV3cCzcCLGfIwNSGTcuPM/Bx/OVDvZgZErYjLjPhaQbOv5Es
/VE5Q84Y7Tis+DwD4Z/0TQ0oM+RvWu6rt1UZ2FvNUe+9lkrKJw+pR9XS4nGr
5jcTphK77ZVUmcYMtJ1l/0F/kkr2GZ50pLZmQFm8hkeHxl+U1I61IV0ZuCap
5XvVjUoSJ7Rij/RnALN/b/JHUYka/7TwxHAGPIZsTANyqITFwOKZ30QGVlR6
N6S9oJK6lE+nxWZo9WhsNDZqoxL3cfehwTcZ+LX1ckTLCJUc4WO47rmQAYMm
znVjr2n8pxf2fc9yBjiLxe2jlqgkO3lrUPeXDLjnPyv+8JVKDMYyuF1/ZODl
5Yr3H35RyRbe/Y8E/mQgzzzaO+oPlcyLjqa+pssElYZEIzS7vmP7G+m1mRDX
qHd89ZtKMq1NxMIYMxGxP7jp4ncq8WDNvTWzLhPsFyeu3vlIJTqF76ulWDLB
WG44pTpPJZIqh5iCWTNR+V8mV+s4lWxadLo0xZ4Jhg/l2+c7aXpDXsRLcGSi
5VWzRmE1lbQc+DsVsDkTFs8eq/MWUMnDdqW941syIWj94IdEPJX43Ai0O8id
iX13f5r/oPGe0YaO5768mfiIanobMyrZekFLWXRnJpwjYh7bHqCSzwtJkV6C
maiIfDa9ZgON/4KnRgZ2ZWJLeG+A6tsZEth23fLOvkycv5HvdzB1hlyzKizp
FaHFo7dBuuUmjd9YPv3cLZYJbs5fvGJnZ8iPc+7BXYczobJF9T+7dxQy8K6m
T0gykzbfY89ffk4hxffW8rkczYR0CUebgC+FWLaGFuw8nonI7Uxv7LkoZEw5
o8P+VCZY+nh3+8lPkZe+jBu/n8mEep/FhoTHkyS95obanXOZ6OmVzz/KM0lM
JKWH7l3KxKnYVinH2XGysLN3+r5OJsxP65vbnxklv77RfxmwzsTfuPoJF8N+
MnHYUkrfLhP+1wJ590b3kRrrbpcZh0zYFneLbmvoJT7UlNUPzpkIiCplURDo
ISxdkkzrvDNxQfxuYK17K+F7aM4jE0d738m+WCmvnPyd7tAnCZmYXUltKmAt
JRTeI+mnkzPR4dXTxzFVRLIj/wmpZ9Dye8Xk74JxJhH1SBS98SgTRjE7B29I
JkFOow1p1ZkQumAvc+XqK+wIP+SzqzYTBwpb/Hm214OuNb7hUV0mbgzPNOoM
NqBBwfRceXMm5j7lDVyVbYGKyKp6dy/tPVJm/bC7CwZrxM3XzGXi2s3bX53c
BpGgd2Hi9ttMLGza7P5r/xD6Si3Uvy1kgm7fww/bhoegbP5A4f0yrb/Svh6t
2zMCyXbubYM/M/EipK88OGkMdsJHw/5bzcRLWz2qt+g48u9orG37m4ny0KRQ
u6pxCBwKX65ZmwWrC1er33ZMgC1ubUseWxbqm1M+Br+cgvKSgMKuTVlwzhC7
aiU2Db+zCmVpnFlY+aeWX580jV8/XTOjt2Vh4Wf6p8sSFEhpxG9l483CXY/X
fHFXKbAvLA0N5M+CD5tNvHM4BXNGS64eglnQ0VJt2zRDgWDFhuVvu7KgzTag
TphmYMCx38xhTxaUlp61/tk/gwSrM+Pv92WhcOhyTfP5GfTVm6qZH8jC2/Va
a3ksZ8C23buZIpaFSzHPij74zUDZOV1e/1AW8t7K8Cqlz8C3u6p0UCILPMJk
lvPZDGr2je5XlcrC8T9VHwxaZ/DT+1tG27Es3HQdMt4+PgPJ8c1bT8tm4UdK
dK7aAo3/JA+HErksTKjyuH2n8UB+2CV6WWSBjmdLD+saKt7M3XAtO5EFI/mc
jxHMVAgo3lsSP5WFphZri7tsNL5Lyvlfw9Udj/UXhUVkRCLqVxJSSaKQJHXI
iIoSaZFCdkhDVkmSkCRJSN497ZFV197r5fVar5mQWUIq8fv+eT733HPOfZ7n
3nOuI80Yq3eVvKFnwzC8navo2WmKA6VVe+EPmN12euhcymkcHFkuq2taPwxi
pJXqLeY48H10WtRp3TCYrmw79vocDlLVzo44rw5B6MUjOaKWOCB6WGa0zw8B
yrTeG34BByvDkfL0sSH4I3T3A+8lHGjnXTox1TkEhxxeSQVdwcGyW4NnUtUQ
eJekR/6ywUHMuOrVwswhYEg1rvGxwwHvyMtNJu+GYNTzm+/UDRyMaBvwnno0
BPK1AjNOjjgodnMeK7PH+JFXdBxywsHw12sj2QYYP/76PVddcWC3qvdATgHj
p/3aOY47Dg7cOhoitjIIJmHvdBu8cfDjpZ9tUPogPBnIzza6g4PdTSLd654M
wmdttlLpPRxsePxSfveFQdCcFJPK88fBc1Qc7T4yAF6GKpFqQTgocDz6x9l/
AOjvTdfQH+HgS/YmRyQyAPLnQqdTQjH/rvxnxXL9cO35ztyZMBwoWA4lrTL7
ILm83P/4cxxs9qw75X2oD7YcWiPY/wIHLvdlP0kc5YL41ocK29/iwOO6qdL2
bT1gbrn9m8c7HEwKiXwJieiGqKiSjJIkHMx41UcmLXbButU/ujapOGhVT1qn
WdUJK198LybRcEDXohw0Ot4Buts3y04ysPjOuysev2GDv3X+iE46DvR7Zhe2
TbTDQu387Z5sHORt6hWujWyDqbTbUf+V4KB21y6yjXML9Pi6l71txu7HvcDI
vEsVsCVLOHysFQfhSe6jpPoysJ6gmR9uxwGL0Sv8VqcUWDbjvZxOTA87Hx8s
UC6CWv2bi1JDmB73NAQ5zNEhX8RuX9xPHNi8Z7QkzlPQvOHKjy8LODjOE7FY
aZCO1B++L9BYwkG5RvNUhHE2Svvea9S+jANTNJZ+52kBInZcui4hgIfUk3vO
HnMuR7Efzr+J2YKHTvk1RVdlmhHnjqS1xDY8RPsCnvShBf1nwpaO246HUWv+
uv7oVpT6/ULCWwU8xBrwn65e24bS9S8npajgwTDqToBaExvNSW21kVPDQ+L9
Y0qOvh3o0ESPDP4gHtbv1C41lOWgklibFJIWHpTPqCR9vNGJGr7Y4Zh6eKw/
mq8YfepGYgVy9qoGeNham1v/8VQPOh81pJBphIfAV2f19dg9qEfTgZhzCg8m
iTTRC729SFZI8eYhMzwkT5Xjyy9x0Y2+kV0fz+Jh3YVUG6E2Lhp/6kQpssLD
w8eDlhMf+5DKlT0uuhex+O5+na6K/chLdVzp82U8WBB/Cb6I6keLHFd62TU8
KL6ZOxN9dgDpMJTdDW7godD77YML9AEU9GhyX5UDHn5Xn9U35RlEa5VupdW6
4EEgq6EUf3YQmSzv9zzljgfrzmUF9p1BFNk6o9p4Cw9bnvcapL0ZRM3EjFkz
bzyIy9tO7s0bRBJ+3pktPnjQkzm43bhtEFmbHbxtcQ8PBU5H/1uZGkTv5OcO
tvti+H88YGPOP4S4C9lzVv54WC62StXYNoTk6u/kcALxwBN5uZ+uis0DKZp3
Lz3C+Fhz3TwLhhDFZ0Gz5zEeNj3Z7GpoPoQmjPMXrobiIe7l3/EbV4aQ6jbf
/L4wrH58esM6xyHkM3vY1+45Vq+Dt6Wm+xDKq1g6PBSJhzVGaYKjXtg88bZw
yT4aDzl+pOJt2Lyh6+FfOBKDh/o1e8PYt4dQsN5Rf6fXeFh1dGragPlXbFrW
GX+DB6JfnUETNs8KfCv565qA4es3NrHefgid+hRUMpmIhyLcPamWi0Mo+tXx
oFvv8ZDCPOm66fQQYt1cPTb7AQ/pdy2G+o4OoU06pSveeDzYddNaVJSH0CWx
x2iOiPH7NHKAV3oIJQ/rB9+l4OHQ2nOb7VcH0UA+r/4iDQ+sjzd6zowOIoXI
ijUPmHhwPC4/WVU/iJzsQst/p+NBpbnIoxWbz+kaRk8CsvCwtGl8xCtqEM2s
EzD8l4OH+ypJx6iug+he5rMqnkI8+F4u0VqQGUQljvWci8V47P18/bF/cgDx
/ic6nv4JD5y2S8mV7wZQ9ONYYdtyPIh92GgR9a0fsQ91bMutxMO73taTTyL7
0daJzftFavBwXrZAKX5vPyKff3+2sAEPYRrK4vpX+tCUwOB18WY84LS/uPyc
4iL1YgUf51Y8+PX0n10M4CK0kxon1YEHTyf1Z3tf9qKu+ezu2/14cIsgu4pE
dSNZ2sJE7SAenOpMbvHxdSNHW+3lHV/wMP6kr6n9fhf6UfVJtnkMDzaHA4XM
LnQi4be1Dso/8HCQ77jG1Cwb6R7pnx7mI4BYZaNNml0LCpmWWz0iQIDwWbnV
G/+aUC3OQfyVIAFe/H0Wlv22EV0Q/qYOogQo/TRY9Le8Dnn2/vRNkibAHbpc
luSfCpQaJMRrtZcATvKZWQ6amWhtuaZ0lTkB6Np5u/rqPwMhTvWquAUBUkff
mPpXlcIJZ6XUq5YEyC9gXXmlUA6P18soz10kwC5RxRa99kpYseY7vuMGVo+A
v6eHMDa77f0X4uZAgOnkezNx5g2gu7xYk3eTAEWqv3cmRzdCAG7C4owbAb4+
yGWgNS2wNMm66XeHAMF32464d7Hg7ecGeuU9Amj+0N98yKUNtF5VzW54gNUr
5vTg9kIb3NMq9CMHEmDbwe3PhQXZMBec+qL9KQEEjk4vma/nQKxlYptsOFbP
PQ/3o2EcOLg7brNbBAG0KgK4mv844N3wDMfzkgAvH8jsVhjuhGkpr7z9CQRY
fnfi6+cwrD+Nu/x5kEiAc+Qe0rexblAptofKZAIY7vStbDHqAbfr1nVXcARQ
LN3zlP6rB4Q1zomRCRj+prNrok/3Ao3/lOUPEgG++1fHCCf3wjj9WN8zOgHO
qAc5Z6hz4VnQYYV2JgHUpv+LrX3Ahd3nDjrLZhDgwGfDOJtiLlQr7GO6ZhHg
Rve6x45/uHBzQfFHbg4BxmXTmd1Yv11bK6vFk0+A6oybaXm3+oCYuCXgdAEB
XGx22Mzh+mAY1vMPlxDguoxXwP3VPngsIXBqP8JsB+JCtlI/yH1djX5QRgB2
v7Smjnk/lH783V5RgfFTc957nXc/2EX83LKhGsNz9aaadHQ/rNhM216pJcAO
hRkDe2o/pKiN4Un12H5V29axz/1wjHdo7HsjprdTl00JrH7gsntUdFsIEO22
98GrwX4IoLBvP2MRwLT4XFDGZD9s9W/Ob2snYP3/UvufuX4oOlP7dzuHACof
qRa3F/vh8o5yPdcuApwk2qltxOylH8VPc3sIMHXqjED3j35IqMyrX+USQPWK
KKfmWz8cfpux4fQAAXS61db19fUDx5VmFT+E8S2p47mlGcvfWflacoQALRkb
vHEF2PmNBttiRgmw+sV4GZ/SD1XZfzeKfcP8Tb8TZYP7wU1us0XkJAEmFn8Q
pG37YUO0eozgDAFGHN4NvDjUD7l/zVqefifA3COJ2WdCWL2urmJ8Pwkg7FMs
K9TdByucULPgBUwfVLO70sQ+IBimRv37RYC+tR3ZeW59YJJd3OD/hwCN0p7X
plX6IPbFnOm9VQJcun9qzIDIhcN/RZ/PrSGC7OndmXcuc4HrsrfWay0RSvbV
ltsKc2GP4XVjNyEixAil3I+064XGrICnYyJESCC6Bo3y9YLPjreVjmJEiE/O
T1Im9kDJn6YTdpJEWLEjCZC7uuFc1lGw2k4E9pKfzQ7JLliQvfiQtYMIyCua
705CJyRG+XwyVyACWVNtRXNrJ4w4046a7iGC0koB54IkBx7IbtY+fpAID9OX
E33622F7lLpvsQYRJJLfFySatkP5b7N8bS0iDGaILo5ltcH6jlBNjaNEkE6x
nLvsz4LUyLkDSkZEWA45AUq9TVC31LRX4jJmK1ufOTpdDlvbQ7eNBmP713hv
elCSisrlFBjaT7B1o93zI9Jk5OaJdCKfEmG/6qXu1+4MVCj05/KBCCJkNf1e
DuTJQZf0vBL8XxOh5U799gzHTyg+7bLUBjJmZxddSn9Vi47/XSTeoBLh5cnb
+Tc+16FRkzjNXDoRpALk3AzH6tGhkWbLyxlEuBIqgpfZ34TYWw1jCQVEoDq0
P/lZ3ooCXYbkF4uI0FZuPutpwkKK+Q+zTD4RYcpsVfJVAwvdsShsnS4jQmUz
v1JCfRuSCFfdoN2A8XX7JsmNzkZFHQ0pEU1EOCCdcr9tWwey3+mq2teC4TdX
lBkW0YGyPhPMQthEOPwn8wvTjoMurdfvY3OI4BK6u1akmoN4rvR77OkmwrTI
8fGYvZ3o3MKWqMY+IqQHDNyaGOtESyfyt+0YJMLAycastBNdKDXGknF7GOOv
JnfibmIXmt0XXS89RoTogAc3Z/W6Ubzfviuu34jw/cvvE69fdqPjNbXfiieJ
0LDafEqmtxtF2/MJ3fhOhPzxAPMylx6klZmakDNHhFbx2tAWeg/q/3dMSWAB
46Nw8xXKtx4Udrr346VfRBAQuu9+Ylcv2v/uwUnGbyIc/0p6nmjbi9ijUp3/
/hJhMbankBbbiwI1c5zOrRBBPeC9lltlL2psmX66wEuCnoD4jd+2c9Hd7ZFS
JvwkkO1i/0k24iIZdyVS4joSjPtuPTXtykWVBVWa00IkEIwQvNIRwUXuAg6V
sJ4EGybeV56jcpGEFY9VrBgJTtgl3rxazkVFuPdfRsRJ8HXXFtsfXVxkP6tz
57AkCaR1jkpswPq78LEu3ggpEsxsENXK+stFBbveRoltIcFy3yPFLME+dFPM
Wvr1Viw+1+x67MY+JPFrU+rm7SSQGfeZs5DuQ6UD7XuTd2A23dtmGrM9a2Nz
5BRIoED2e28v2Ye2ZVkcIymSIFYk/3CmSB+qfSdes3cPCQRMEw91rHLR/ZCW
c+l7SRAcdFKNNctFiu7RPeoqJLDJmz5L7OUilqWZ40dVEnwp23P1bAUXPdRd
P3P0IAn4bppkt5O5SGVXg2+pBgl8gmMua4RxUY9oxBojLRLs+GX0z/sGFz1b
NIms0yYB5w9+8aU2F2kOrJMyP0oCOdH4c3EiXDRcU53SdowEpxxPNYb09KKY
zKdKF/VIMMbj9fU6qRcde2eY3XuChL0/hzmaHr0owa28auQkCQKjRhd6pnuQ
seXjs66nSECePH/7E7UH/Tyq1z19BjsPEnDIt+tB5qKfpxYtSNDqm7dWqrwb
LS8E3g+wIkFKx3PXV7e6Ea3/KA/PRaz+7KBMC6lutDazUFLIhgQmfQ5n2Je7
UNH5PJ1tTiSw8q9TiyrgIJejdys/uJBA93mNceNJDpJS1DBXdMfqPbkq3Nbe
gbwXMm/s9ybBtQ5pm4fDbLQ7gRkO/iTIDGxkZnLbUGwfgeMQTYLde3bT47Mb
kV61/fXxGBLUMD6oH37UgKbT5Sc8XpPgyvFzwd4m9cgk+MO/ewkk6O6YPR3D
qkErCkmK4XgS9q7u5W+pLEfuLrE+zHxMj++0vRQrM5HMwfYzAoUkSHV6dDWb
xESNvyX3XC8mwR7hhP6cCgpSiXzTK1lKAseObs4rwWQ0lZZgGFBHgvANz6jz
Vk/B82eK9CkupneD9l8Vt/NAtmTgO6GfBHEyN122f/wIzaFyDf8GSTDQeGFB
/VchqEnjH2V9xWw3CeFIp8/wXZs0vmWWBGlkad+ooArwecgoGltDht4E+/U7
bzaAwsmpOP21ZFhR5Wp+P9sIbRv2eyUJkMHxgjhy0WoCDVz6zrMiZBBqDNYQ
XGyG+YqsqPxNZAjTxilOyrKAGDXnJL6ZDC4+Pl1jj1lgdUFD3+0/MpySjH59
a5gFuaO5C9tlyZAWruY5l4TNb0IF157uIYOTcon2mu/tsLttSXtgLxm4YdaS
jsfZwEk8InlEhQwCvTffb4xgg5ZKcc3UATLcy3syceC/Dhid/4sz1iDDyBif
0hubDoj/pBuYeogMS8okwb3vO2DR/PMBKx0ybFrDuVItxQHy5lXhdF0ySOxJ
D6kw44D1IHxdB1g+kT9FnSEcEKAFoxv6WPyCcIN/uRz4eLvsXbEBGbLlBcJU
RzjgosN7V8oYO3+t7mYn8U7Ywmdg7mVChnTruIKUI51Q2/BEqe4UGWT+tlxu
t+uEB3GVvDvNyPB7WXDbakgnPA4oEb99lgxa+08wnuA7IcI+VxZZkCHzgWXz
JtQJcaZMFVErMgyPJAWnd3XC+wNEnavWZFCPM50/M9uJ1Z9sQrtEBpNZ6bgp
3i7IXHlt/esKGfwm5QUisP5d+DXS0ciWDMv+faoK8l1Q3vjE57UdGWJVlTWz
93VBQ05A8NANMpx7ER98WKML2Il3otUcyWD1NqM643AX9D92Tw5yIoNIidXa
/450wZiLA73BhQzRgbvDbmPr389eLfjPnQwpsqKTH9W74I+WZbXzLYy/pKo9
k8pdwCd7mp3nRYbqgosRwnJd2PRpMMznQ8b+/wmfpCS6QGpK57vFXTLwzWU1
rl/TBbLt6isf7pOhn4+++/tUJygVKa+feUAGwd25uNKOTjiIU9iqG0CGcZHH
Dx8Vd4JO+FaliCAyLD567K6a0gmGXhJaXY/IkFomE94S1Alm1sKGu0PI4C+V
7HzzSidYH+M9fzcUqxdWJX9qdIKd4h+78jAyTNFzxQOFO8FFZO6W+HMymJJ0
bNf2cyCge+g58wXG151btrsCORBa2v32z0syBBZ9f1lrzIFoCotkEksGG0+m
ZLAYB1LvlZWNxJPh81raZ+M3HUCzKWxRf0cGa5Wgl45WHZBtkNUXnITxm+Qo
kCveAVUbcb9lUslgv7pFWuQxGybSgg9eoJHhy0zBcJp+O/yMewAEBhl+trvp
u062wXKAt9mPNDIk1zJd6bFtsOHUddcX2WRQTkn6+6ObBZqjgKsqJsOo80yQ
jFkrHGs6nCH5mQwbvVQ+baxrAeNctU83SsnAKGCK9v9shsshO7r/VZLB/E9j
ZcexJngouyqu1UyGevGX84KUOqi1/hxMHiSDomOIN32mDDq7OsN3f8Hi+/oV
p3WWwuiVHzHkr2QQPTS2+0oQgrV2ijjyBBk6fUaOd4oVg55zRBl5ngynbyi1
zEpkQ4GvNS9FkALjfEe+7NFWQDW/vYT3iFDApYd02M0oBHECnktQRCnwvUpj
Y9aWWDT/qESBIkEBfC5ZR/UnDh0IVzCgyFBg/dB1y38FWYiWMPOEcoACJiJe
5bh9Zahgq2DUHg0KbJ2jaF1XKke1yfJxlEMU0JYxdmuQr0CjqVZEig4F7GLw
7w8LVyEFWlElxZAC9XfddoWl16KD+9iNe05SwNxwurD8RR3SS5tmU0yxeNMK
KUMu9ehaltxXijkFOm0Hpb0lGlFiYRg/9RIFSr7Ir313oAXRjqaKKl2lQM/K
G37mVAsq+FQoRbWlQPBVnae851sRp2xqF9WeArFe/IkKvCz01UBAVekmBY6p
EkueWrPQfNUOLaozBVRfTfxxo7KQRP15Y6oHBQzL/IXeG7Yh+TMe5kpeFLik
/G60J7oNHWh+ak29TQH54ofzgZw2ZN5W4ES9TwEt9w9eLNt2ZGvV5qnkRwHP
WjPZ++/bkQdn8j41gAINezMeOvS0o4ge2WfUYAooPt1lvXKajZJ1iwb+hVCg
fFRrUT2IjdJTLmhbPqXAvrWvdOYZbFTK8yOG+owCTuapJ451sRHLPurbv+cU
oF7ecEqItwMNV+45YRlFgezkUZrl3g40v7sikRpNAV2h8e7N5h1oy+Tv05av
KZAw2qCy/LIDKZu9IVLfUGDH8oFxybQOpJtx4N+/txQ4Y7BEjavpQOYbGy9Y
JlIAhwKS/Qc6kN0d53RqMgV4z9puK5/H+ncH77qVFApc+WPKdF7HQSGHU+ws
cZi+BrsEXDZzUNy7IwVUAgUet0VLlypyEPkvW3yFRIH9mWtXPNQ4qMDW29WS
SgGP0ANbPQ5zUD0SKafSKSCmU81frMtBXHnK1hUmBYzIH5IvAgdNPzlxxzKD
Ajw2R1cBs1e+9jVQszD82kzjfTB/cRM/xZUcCkyJmknPaHGQAn1TkGU+BX5v
Un6SpcpBmuszO6gFFOgu+ahRspODjD1Pq64UYfhtM+sQleagi62jYZafKODn
YOZF5sfmF/WQASqiwN4RslPYXAfyj9uuvVJGAavpPY/TuR0oarEgxrKSAt4C
1eM7KjtQyiWrb9RqCiTvalTlUjtQZtGs/kotBU4uL5p/xf4PZTKRiZYNFHh+
92L2MbcO1PZw909qEwWK7guojxt3oJHBstMrLRSI8M/7b1yuAwmSlpapbOx8
z6WSfjWy0dZ1cRdWOBj+30q2i39go32uaumW3RQQZI33vfRkI/P9TnYrfRTI
ubXhEJefja6/XFNgOUgBose2+LymduTzI1mcNkwB+2mH+g2v29GbvPYyyzEK
CBdnFNyUbkfcY/qKtO+Y3jnhg1E8bWjmAzdwZQ67P0JhYdfyWIiH90GH5QIF
msvj5/46s9DO6vSwld8UuP/DvbS2uhW5mct8s+Sjgt/MPiTZ1YyWrv1KW5Gi
wjFph5p/5bVI3CaXJ2wLFa64kdZrD9WgPZdvW4puo8LSTb8HbsvVyNpycmmb
HBV0XycKOytXodyTAwZHlKkQW6DrgXctQ94HarrvHKeCyDPuluEjOSh8f6jK
Xz0qvDMtW4qELPRBWf9RiAEVLsk2bnv1PB01KxYrvjKhgv+b9S2MFDJS+S/D
K/08FaiSlrZK3pFofM1b/m9OVDh1+uE2GgvT1arlJW9XKlyuDUlfecaAzcvi
jF/uVPiQ8cwm6VAGGC9GnBO4TYXrUT/Vr+nkAHHiYdLOACroffpAn9cpgpKx
ozP0ICrYrLdtZ08VQ/vIkp56MBXioi+Gv0v4BLwDPqN6T6nQldDPDfcshevt
TgevvaSCVCt99lZEBTxo3Rn69RUVLr5UjvYzqYSXTYMcjzgqOO07PNbAWwWf
a64EBryjQvqexay/7tUgU2Jek0CggvLi1xdksTrQLBTZKkemgnuAli9vWh2c
zq/1oFCx/eIVOnIn68E/84REfhoVrDwZas6eDdBJ1LJt/0jF/uvk6pRnTWBS
Sv9iXkSF+sjl5bM8zVDQK+tWX0KFMGn76yF3myFRYp1vWRkVJqgdYbpnW0BY
NeCfbiUViHKVNWl5LRBgOvukoJoKJk4mCYUirWAT3BmT0UCFnQEOv52dWqEx
6fTmfc1UeP/5l/neGKw/fkTvya1U+DMivz74Yyukt2koKrRTIaS32MqZ2wqy
MxT6+w4qiAvKePWstEK0kMzB/7qocCBfoJqNzberijEf43qoMLL1y4SFLgu8
9dYeF++jAl74YILZRRYMXn1QGTmA1bddN7fCiwXnfKdOrRumgjlB0CrzKQvK
Yq+zQkYwPIPuf97wjgXq6eyLK6NUiDaK9+qnsQBfZ9Lv940K8o3KMv8VsEDi
a4njwiQV8izP55VUsOAJz8FJ7xkMnxuWHtWNLJjfRro99Z0KP72e5Wu0s8Dx
8H9Lzj+xdf5rFrydLGCff/HwywIVSqN9jA90scDIcw2/3RIVjLUyZos5LMh/
fi+y5w8VeLn3/xLaWLCb9G2j9T9MX02t3mMNLIgvtU1grVKhe3tMztNyFqzj
smTNeGnAFfYMf5jPgge/jEi1a2kQfmbTf20UFoxLFO0zXEeDM0h8KTieBZdU
VbOREA1SjJiKUSEsqDPFax9dT4PDGz+ILbizQOemNMoXo4EiPvndp/MsoAdH
GKlvpMGj2Sy5cS0WbE1eaUiTpMHbSG8/3y0siPzoc36vNA2Cx4YXPX+1gsfM
FTu5bTTQsrBXI6e1Aleo5WvSdhoU605unQ1tBbNdBh6b5WigV6wak325FVRt
9vmJ7aKB55cnL0N+tcAH3w+rz/fQQP/3nQWN2BYQfy0Zxq9Mgzy+x5riSi3w
o+5v7LIqDWr3bv4ZYdQM9l+9/ntwkAYjTvN8Zk1N0MYz8uGnBg0mxgZFH59r
gtzDjcwJbRqcvPD7zyvTRrhPSq7uOkED6YVBTodgPYyWiptZGdHg+VTlhxTP
OrjIDW1vOUmDorLht+9aa0Fb8tZg9RkafA6bOZjwvAb+BB/7k2tNgxM8HL+1
7ZVwK1CDxX+ZBmukSy9P7K2EQd+9VOurNJjaRGq3flgBNZ5S1kt2NLDAr+5T
lyuHOJvprKOuNHAOc7HbEv8ZVLXfu5YH0MCJJLTtc1o22M8ud7WkYvy8vqLB
vv4WdUzMZcgRaHBL0BfHcnyPTEbHw26TaNBW8Oe8SSYOqfWxNSXpNFiOvnNB
O4WCluuZMdY5NBB3Pbk/OTkLxZNtTPqqaHD8kMH9mtgSJIQ/v0O1lgYh/5Vf
vjjwCQW+N1l8WI/lY/TYe+5ByCFOkyjXguFhOK3cxy5FB0LW8zh20UCutVq2
50gFIgTxdub20OD702spmY0VSNpvKY2/jwYv4Gd6n00lWvYauUoZokFOZu20
yL0qVGdb8nFiggZ+fxufBT6pQSfm28NvTdOglEMykBOuRcURk5e/z9Kg78vh
GJ0XtSjt49blhXmMv8fG46nhdWi3uXrTg1+YnidtKWyeevRhxDTl728axHxM
tja/V49ebfTTW7OK6TuU8vbr+QYkTI3ZGLqGDomHWz9PFTegJ8epwwJr6ZB8
Fb+8Xr4R3XPvDF0vRAfXietKngONaGbN7IWXInTwMYg7lajdhJwTBPZIiNFB
QrFjMu9FE7pcdahusyQd8MeCDeL2NaO2q2aJiVJ0SLBPqTe424xOzzm6b99C
B8U7+++XFDSjyvBA3dStdFDq3nhsYakZHdsRJ7pzOx14TcOsvmq2oPw8Rj9p
Bx3uSDVphHq0ILUzFRlKCti6tFVC3YcWRB3uCWYo0kHqpVFEWnMLkvebs1Dd
Q4eM6Uc3lH63oMQNwjuz9tJBoO7+zXcbWpEkWX5eQ4UO9JytY/ZyrShK90hV
viodRkP6XadVWxF/+7n4IwfpIOjs13HoaCt66OriXKJBh6AWd5MjRq3o1+oj
bdCiw/KI3baFM63IO/6tULk2HX6Upo44YfPyN5WMHsOjWL4IQkDUhVZkX1HN
qDlGh+rH75cdrFtR7+X+wFN6dCj6Jd84adWKrL4vmDWdoMMwf0WigkUragoT
3XHOCIs/m+Gy7nQrMt6+63vbSTpI/j39/N2JVoRydMsunKJDP62A3HW4FWmf
sortOkOHrGzzqkrlVpQ16O5w9SwdLumsGl/b1oqUfZ9o9lvQwVzx3QxJqBUR
RJP4b1jRQWyst+rIZAuSIWZzvljTwcYZ7/D8cwt6o1NPcbpMBwVKL+n4ixYk
xhp68O0qHdaK9Vhdu9iCnjn/NvW4huX7zpaekWlBfnFKU7cd6KB/4gn3QWIz
mlPW+zR/E8v3SJ765Hwzci+7GO3rQgePTYrbZQWake1M2IGgWxifWrr1+643
IU5oyhoebzp4WzBP5As0obPb8ttCfOhA/Wo7tkJtRPomX++G+9JBXNqTyTfU
gIr6l41E/OlATH5O6b/fgDTubdocHYjpYZH+OE+wAe3CGxS+fkyHpnBjdopc
PRJaxv1LiaRDyjolYsTOWhTqc3THrxd0mCosL3xBrEE839h6Z2PooCe13Jaq
UIOWOtaFrsbR4djW/qCT0tVoNOOW8PUUOtbvBMzG+ypQpcORzfJZdDBSG+Vu
4f+MHjW0HiBw6HDCWIH4xhCH/ui7nf/bRQdpB4V/w+Lv0f0CvruWvXS4YsBP
JL57izxJWh/5BrH8c7fqkuyfI5tHycccv9HhzAaHPN2Rx6Cj4XJq1zIdPu7y
UZG5S4N82hqPoBU6aM0f+3TjHwPU5ZJedPAwgCHXolESnA57RZtbn/Iz4L+B
8YKTRVmwZUzj4qgYA84V5Dm8Cc2HhcRVB4o8A+67yM9lXERQr3au8OdOBqgu
CwdYqZRCSmWqmN5uBsTH33YMpJeCyYx+YZcyA1IalbbgPpRBon6omLAmA3v3
x39s8KgALw7bwVqLAfrao88/dlWAofuuQrw2Ayx7Kj7mn6iE6bhqh6PHGFCQ
LBAZL1YFeuOChR7GDGB76u37EloNUkGXxQpNGFDyJvLHmd5qmNhId+A/zQBm
mMXROtUaeH30tFjKWQYY2ZXTexprwKU1yWHCggFWfPOL1zfXgu7NqQItK2w/
o1eSe60WRqNfOLRcYkBEAFXnzUgtFO/sL9h2lQH7HtnyVSvUQUyBqpiLLQOu
8EjJsGzrwNHskUOuHQNsyj67Zr6pgyPDLQU89hgepj2C1+rrQMxXTszMkQHz
t0fN2X/rYFjktsM7JwYcF+NtFFWuh6hDEmLq7gy4dEaCmxdYDzfq7R0e3mJA
2UXTqq24etCyyymo92KAtMjZeLXyehCe5xPb7IPF37VG4ftAPQyEWzk43GUA
T8zbkEt/6iF3O6kg4z4DHnO3y9zc2ADh2Quiyw8Y8OfV+g8SuxrA9qSxg0kA
A7Yk8ItcO9QA6tz4grggBnjsjcgyPNEA626PiQ49YsCUbq525ekG4PJrO+wP
YUASfW1Kj0UDZCaGF/iFMkC8z+RImFUDPFXrFq0OY8CwnQeqsmyAK5V7HSSe
M8Db8ahRwtkGUL3sX3AtkgFOrqon/p1sAL6ZelHGCwbwTuu9ntdtgK6QbQ6/
XjIgvYsc9FC1AdI2exQYxDLAOMIuK0mmAUKYJaIxcRhfudWnzdY1gLW+qAM3
ngFZH3b2xM3Uwz6ObYHSOwasSRWxudtWDzzu6aL3khhgIffSaCa7HtirK/Zl
7xlQefzKY/6YeqDFnS0QTWVAaWWNzyfXeni4N1X0Cp4BcUaff/2nVw+Wn7/b
k4kMsLYxdtshWQ9KlvoFc2TMbhDBtw3XAStw2D6SwYCHc066lx7UAXmjRkFn
GgNiJmeatI7XgT/5iahiJgMSx/aF9vLUgWKrYkFJLgM62FfPvwmshZXV+HVH
PzKAyA5XeqVWC91qQhcLCxmwlrQkNt5fA9EvpxfyPjPAZOP81i51TK/Izkiz
jAGB5w8/i+ysBoNZVlx2BXZffdSimx9Uw5J5vkZGLQOUftiGQVYVtD1UerK/
gQHau2fUXphUQVp6YhujiQHPeb7107iVYC/26Da1jQH1j3ez4v9WQGPTyQwc
FztfUdB1c+lyIP8rXNkxwABBazQvG18Gj/ermKcMMYCjrZp5RbIMtF6ITyeO
YvGpN5nuAqWQeqZbOe47A57kGvuO44vhboMbOWwtExS+/pmPkMsG87/chbXr
mEDnPXft45dM2LvvrNETISbsA156lGkG9EdojDwSY4Kmxc6f+VjfMjm1LO+3
hQnOLsrG2zelgkzdi/fuKkxIcTScy258jBaXVqe+qTJhm971hpQ1UYil5KPr
cpAJsH5q07bNr1FYuHWvoxYTpHX49A0136PvJ3f8d02PCc9uRjd5RFNRVXVm
3DkrrJ4WXNxIRR7Cc4iaRGsmLDmP8c6y8lHwaAL71yUmWJ2bYtRwPyIdgceb
PtgywSZAcr/neCFKN7KIm3ZiQstJ6iVf9icUecFIU9+VCTxPJnU6qz4jl5tH
2HHuTJAVmtqllIPQzqfym3S9mXBdpUEjubQUJVT+eB3hxwT7kb5Nh++Wo3vs
rxr9AUxolx2Rv9hbjs6PdLcffMjE/mEqkRv1KpDo2nLJ7hAmyPhmie3jrUQT
kvk5Kk+ZoLZwI/aeXSWq3Um3DH7GBHWjJcODRZUoxCD29Z4oJuiNGeZ0OFch
O8swjYBoJjw6crmWUVSFdB3825tjmHDloztqEq5Gv0LsJe+/YcLGmKS8Nnw1
Ysda59S9ZcKdIjYfaaIaZeNPWW5PZML69efbcWo1yKNc/XVlCua/aeTicmYN
Mm3brbEFx4RjCpr2p6dr0O7hre3uBCacpf1+R9ldi9bOid1BJCZwf8meF7at
RUNr+CQlqUyg3vqgcCumFn3e+CvbiY75h6V+qyutRcnyk+eLmEz4Mkxq3DpT
i6z122NvZGH1Dk6Oh0Ad0rCoUc/LYYLWT8W+lw51SPxGcZtgPhPindc7BYbW
oWnvDB+bAiZ0M3XkDfF1qD6YIJFZxISYW8y/wyV1iBLzNpvvExMOieloXGDX
odDUyPMXEROmfLdcejteh+wzH83Ry5jgK+dmTv5dh6D0TuxKBXb+mU9nH62r
RzKtzurnq5lwrvnF1A6JevRn4GobqRbTR2WFaNh/9ahz9qzP73om1DYZLWZs
r0e5qwYSZk1MMF0fYJgsi83LG7SzU1uY8F4w/6epTD3y3KFyfp7FhAlngm2B
dD06rSY3d5LNxPpvztEx0XqkBJtikzhMKNIPp3LW1CP+s4Lqs10Yfkpa8s/m
6tDwtWXWiV4mMANDwn4P1KFSz++34/uYoJElKatWX4fePxzZODHAhBXfD6/3
ZtUh/+iurGPDTDhh++/3RFwdupTSaPFqBNMbSDbeu1eHDqWX/hgZZUIloWi6
8Xwdkvic+0r7GxP7n71h/lSpQ11Crr6sSSa8qpiq+7lSi95f2G7rNsOEuzZS
a/mbapE9jnWC7wcT0Aytcf/bWqQ0/VQp+ScTZvVMjt3D+J/R1hE7tIjdzyap
LV921KLc0JmfTUtMyC8Rq33UX4NA5iJa/ceEbw5rUt3O1aC1LiKkBJ40aDSf
/tbIV4Pqc1DEQb408BrlPROWU42sTytZOwimQeiOzpb9gtXIw//3VLVEGiTs
ea5Y+qwSqVentdlJpUGU2dde4x2V6NdG+4KlzWkwszymGJdTgUJo9U+Ut6eB
SmUGt6qtHL3rStoavScNpl/LqD6cLkXVWsdNLuimQXp8jnf46UIUFTK3f+Z4
Gqykv1G9t6sAWTSTJZ/ppwH70M3oJ3/zEffmhoEC4zSAGI3h2uRc9DNu8J6M
BRZPXMr5q08GkvsZQvhyMw3m/5VvUt8Zj0aPH34e6JIG1UoWXi4/YxAjYtJT
yj0NjmT86r4f8gxpKVjpnPROgwMV4x5CsReQmcUuFt0/DQwJnZq6nq9B4n13
vkFQGgiR/54/+S4BusZfJHMfpUGdgpXqBHoPjsGLzmJPMTw2EBXPrhBAuZFu
RnmWBnidLZufhJNhdrOdhl5EGkwZ8+d0i9Eg10Hyv+6oNDAJvxg0EcMA/4ya
ldsvsXz+h3vMxNLhfydxQNY=
     "]]}, 
   {RGBColor[0, 
     NCache[
      Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], Opacity[1.], 
    LineBox[CompressedData["
1:eJwUV3c4kG8XliRJ0h5GQipJJS3hliIrISsJESGEjMxk7703WT9KZCY8QjYZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.63039540141816*^9, 3.630395496235725*^9, {3.630395734190292*^9, 
   3.630395748162326*^9}, {3.630398227045518*^9, 3.630398290611651*^9}, 
   3.630398321328656*^9, 3.6304095607102737`*^9, {3.6304097133960733`*^9, 
   3.630409732179648*^9}, {3.630409783077269*^9, 3.6304098062452927`*^9}, {
   3.6304098500129347`*^9, 3.630409871111631*^9}, {3.6304104427267942`*^9, 
   3.630410452422469*^9}, 3.630411912839449*^9}]
}, Open  ]],

Cell["\<\
This shows that the satellite coherences are excited by the modulated pulse, \
although with a good amount of central-transition excitation as well. \
\>", "Text",
 CellChangeTimes->{{3.630409585125308*^9, 3.630409600819336*^9}, {
  3.630409891121662*^9, 3.63040992008985*^9}, {3.6304104587709846`*^9, 
  3.630410472945498*^9}, {3.630411925053669*^9, 3.6304119526055393`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["spectrum after a satellite-selective modulated pulse", "Subchapter",
 CellChangeTimes->{{3.630395323459711*^9, 3.630395332460289*^9}, {
   3.630395414602334*^9, 3.630395417930991*^9}, {3.630409933570064*^9, 
   3.630409938023226*^9}, {3.630410731329482*^9, 3.63041073661524*^9}, 
   3.630410999229494*^9, {3.63041196474578*^9, 3.63041197277785*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "@", 
  RowBox[{"Re", "@", 
   RowBox[{"FT", "@", 
    RowBox[{"Signal1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"InitialDensityOperator", "\[Rule]", "\[Rho]ini"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Preparation", "\[Rule]", "SatelliteSelective90"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
   3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
   3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
   3.630396027075295*^9, 3.6303960409823837`*^9}, {3.6303986168297997`*^9, 
   3.630398660220437*^9}, {3.630398702294038*^9, 3.630398710640931*^9}, {
   3.630409971284046*^9, 3.630409996325594*^9}, 3.6304108846890182`*^9, {
   3.630411984926139*^9, 3.630411992108801*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411993069792*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxUfXd8TNv39tGDYBIl0UeNbvS42gpCEIw0kURy0nsy6ZPqINzoww2ij95j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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-0.0028766563628700448`, 
   0.03732860441401106}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630396042375787*^9, 3.6303960716595783`*^9}, 3.6303986852682743`*^9, 
   3.630398737135955*^9, {3.630409988583632*^9, 3.630409997325322*^9}, 
   3.630410887513607*^9, {3.6304119864210157`*^9, 3.630411993368746*^9}}]
}, Open  ]],

Cell["\<\
The two satellites are strongly excited, with almost no signal for the \
central transition\
\>", "Text",
 CellChangeTimes->{{3.630398780957326*^9, 3.6303987931408978`*^9}, {
  3.630410004290997*^9, 3.630410009228343*^9}, {3.63041090751451*^9, 
  3.630410924714551*^9}, {3.630412008388049*^9, 3.6304120312134933`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Enhancement of central transition by satellite inversion", "Chapter",
 CellChangeTimes->{{3.630395210099065*^9, 3.630395211954503*^9}, {
  3.6303955606012774`*^9, 3.6303955611066303`*^9}, {3.6303963831118307`*^9, 
  3.6303963855749483`*^9}, {3.63041217899303*^9, 3.6304121829732933`*^9}, {
  3.630412458850806*^9, 3.630412462978936*^9}}],

Cell["\<\
The central-transition excitation may be enhanced by inverting the satellite \
populations using a modulated pulse, followed by selective excitation of the \
central transition. \
\>", "Text",
 CellChangeTimes->{{3.630412186979212*^9, 3.630412213777608*^9}}],

Cell["\<\
This is readily simulated just by chaining the pulse sequence elements \
defined above. \
\>", "Text",
 CellChangeTimes->{{3.6304122170407963`*^9, 3.630412231216099*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Re", "@", 
    RowBox[{"FT", "@", 
     RowBox[{"Signal1D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"InitialDensityOperator", "\[Rule]", "\[Rho]ini"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Preparation", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "SatelliteSelective180", ",", "CentralTransitionSelective90"}], 
         "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "0.14"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
   3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
   3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
   3.630396027075295*^9, 3.6303960409823837`*^9}, {3.6303986168297997`*^9, 
   3.630398660220437*^9}, {3.630398702294038*^9, 3.630398710640931*^9}, {
   3.630409971284046*^9, 3.630409996325594*^9}, 3.6304108846890182`*^9, {
   3.630411984926139*^9, 3.630411992108801*^9}, {3.63041225927665*^9, 
   3.630412288834467*^9}, {3.63041235272631*^9, 3.630412394656073*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}, 
   3.6304122907241783`*^9, {3.630412365264176*^9, 3.630412395155765*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}, 
   3.6304122907241783`*^9, {3.630412365264176*^9, 3.630412395284045*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.008333333333333333], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxUfWdYFMvz9ZgT6poxr4qKeVVUzKUioqKuCEhQGHLGJadFx4SYcM2Y14xe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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-0.005426853937426998, 0.14}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630396042375787*^9, 3.6303960716595783`*^9}, 3.6303986852682743`*^9, 
   3.630398737135955*^9, {3.630409988583632*^9, 3.630409997325322*^9}, 
   3.630410887513607*^9, {3.6304119864210157`*^9, 3.630411993368746*^9}, 
   3.630412291190627*^9, {3.630412365724614*^9, 3.630412395641704*^9}}]
}, Open  ]],

Cell["compare this to the hard pulse excitation:", "Text",
 CellChangeTimes->{{3.630412300554263*^9, 3.630412325744729*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Re", "@", 
    RowBox[{"FT", "@", 
     RowBox[{"Signal1D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"InitialDensityOperator", "\[Rule]", "\[Rho]ini"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Preparation", "\[Rule]", "Hard90"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "0.14"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
   3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
   3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
   3.630396027075295*^9, 3.6303960409823837`*^9}, {3.6303986168297997`*^9, 
   3.630398660220437*^9}, {3.630398702294038*^9, 3.630398710640931*^9}, {
   3.630409971284046*^9, 3.630409996325594*^9}, 3.6304108846890182`*^9, {
   3.630411984926139*^9, 3.630411992108801*^9}, {3.63041225927665*^9, 
   3.630412316477068*^9}, {3.63041238312799*^9, 3.630412402676756*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}, {
   3.6304122907241783`*^9, 3.630412317475546*^9}, 3.630412403353943*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}, {
   3.6304122907241783`*^9, 3.630412317475546*^9}, 3.6304124034753532`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.006944444444444445], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxU/XdcE+vz/w8v9oIa7N2oiKiIUVGxj4qKghJpIiIsvUOAEEIo7rF3oyJ2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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-0.0004054232598972025, 0.14}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630396042375787*^9, 3.6303960716595783`*^9}, 3.6303986852682743`*^9, 
   3.630398737135955*^9, {3.630409988583632*^9, 3.630409997325322*^9}, 
   3.630410887513607*^9, {3.6304119864210157`*^9, 3.630411993368746*^9}, {
   3.630412291190627*^9, 3.630412317717598*^9}, 3.630412403607792*^9}]
}, Open  ]],

Cell["\<\
or to the case where only central-transition selective excitation is used:\
\>", "Text",
 CellChangeTimes->{{3.630412408695471*^9, 3.6304124249181957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Re", "@", 
    RowBox[{"FT", "@", 
     RowBox[{"Signal1D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "\[Pi]", " ", "1000"}], ",", "\"\<1k\>\""}], "}"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"InitialDensityOperator", "\[Rule]", "\[Rho]ini"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Preparation", "\[Rule]", "CentralTransitionSelective90"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"EvolutionBackground", "\[Rule]", "HQ"}]}], 
      "\[IndentingNewLine]", "]"}]}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "0.14"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.619787962022258*^9, 3.6197879942113028`*^9}, {
   3.619875399587668*^9, 3.6198753996909313`*^9}, {3.63021594782136*^9, 
   3.6302159755337524`*^9}, {3.630395170419098*^9, 3.63039517927223*^9}, {
   3.630396027075295*^9, 3.6303960409823837`*^9}, {3.6303986168297997`*^9, 
   3.630398660220437*^9}, {3.630398702294038*^9, 3.630398710640931*^9}, {
   3.630409971284046*^9, 3.630409996325594*^9}, 3.6304108846890182`*^9, {
   3.630411984926139*^9, 3.630411992108801*^9}, {3.63041225927665*^9, 
   3.630412288834467*^9}, {3.63041235272631*^9, 3.630412394656073*^9}, {
   3.630412437603738*^9, 3.6304124401898527`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "reportscm"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using SignalCalculationMethod \[Rule] \
\[NoBreak]\\!\\(\\\"Diagonalization\\\"\\)\[NoBreak]\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}, 
   3.6304122907241783`*^9, {3.630412365264176*^9, 3.630412395155765*^9}, 
   3.6304124409983053`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Signal1D", "::", "autolb"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using LineBroadening \[Rule] 2\[Pi] \[Times] \[NoBreak]\\!\
\\(\\\"1.43291\\\"\\)\[NoBreak] rad \\!\\(\\*SuperscriptBox[\\(s\\), \
\\(-1\\)]\\).\"\>"}]], "Message", "MSG",
 CellChangeTimes->{{3.6197879848222017`*^9, 3.619788085594739*^9}, {
   3.619788120615368*^9, 3.619788141324922*^9}, {3.6198753937157917`*^9, 
   3.6198754003996696`*^9}, 3.619933044458016*^9, 3.6301362714401684`*^9, 
   3.630164098664168*^9, 3.6301691571429996`*^9, 3.630215932147084*^9, {
   3.630215969332385*^9, 3.6302159771348653`*^9}, 3.6302211145859985`*^9, 
   3.6302216609530096`*^9, 3.630222367583377*^9, 3.6302235028509483`*^9, 
   3.630224672060613*^9, 3.630299955702036*^9, 3.630395183817432*^9, {
   3.6303960421278687`*^9, 3.630396071415674*^9}, 3.6303986850209827`*^9, 
   3.630398736889863*^9, {3.630409987978108*^9, 3.6304099970582857`*^9}, 
   3.630410887257265*^9, {3.63041198589489*^9, 3.630411992958001*^9}, 
   3.6304122907241783`*^9, {3.630412365264176*^9, 3.630412395155765*^9}, 
   3.6304124411154833`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.008333333333333333], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxUvXdcU9nzPn7tXaOCYo+9oUZFRUUYFREVIQICAsKldwgkhBAIxo5lNbpW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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[Medium, FontFamily -> "Helvetica"],
  Method->{},
  PlotRange->{{-499.51171875, 500.}, {-0.0027285238838917853`, 0.14}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.619787985441477*^9, 3.619788085973901*^9}, {
   3.6197881209961367`*^9, 3.619788141702034*^9}, {3.619875394575341*^9, 
   3.619875401049108*^9}, 3.619933045345694*^9, 3.630136274652438*^9, 
   3.6301640997579336`*^9, 3.630169157741412*^9, 3.630215932732498*^9, {
   3.630215969587531*^9, 3.630215977389045*^9}, 3.6302211148331733`*^9, 
   3.63022166145335*^9, 3.6302223681467752`*^9, 3.6302235033442745`*^9, 
   3.6302246723128033`*^9, 3.630299957425562*^9, 3.630395184462151*^9, {
   3.630396042375787*^9, 3.6303960716595783`*^9}, 3.6303986852682743`*^9, 
   3.630398737135955*^9, {3.630409988583632*^9, 3.630409997325322*^9}, 
   3.630410887513607*^9, {3.6304119864210157`*^9, 3.630411993368746*^9}, 
   3.630412291190627*^9, {3.630412365724614*^9, 3.630412395641704*^9}, 
   3.630412441266363*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{905, 714},
WindowMargins->{{181, Automatic}, {Automatic, 41}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"MHL-StyleSheet.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3630408952-7254327"->{
  Cell[12011, 424, 579, 9, 94, "Print",
   CellTags->"Info3630408952-7254327"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3630408952-7254327", 907685, 16612}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 108, 1, 92, "Title"],
Cell[691, 25, 258, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[974, 34, 100, 1, 65, "Chapter"],
Cell[CellGroupData[{
Cell[1099, 39, 126, 2, 34, "Section"],
Cell[1228, 43, 144, 2, 28, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1409, 50, 131, 2, 34, "Section"],
Cell[CellGroupData[{
Cell[1565, 56, 284, 7, 28, "Input"],
Cell[1852, 65, 815, 15, 39, "Message"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2716, 86, 130, 2, 34, "Section"],
Cell[2849, 90, 142, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[3016, 95, 125, 2, 28, "Input"],
Cell[3144, 99, 1129, 44, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4310, 148, 123, 2, 28, "Input"],
Cell[4436, 152, 333, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4806, 169, 124, 2, 28, "Input"],
Cell[4933, 173, 337, 12, 48, "Output"]
}, Open  ]],
Cell[5285, 188, 259, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[5569, 197, 430, 12, 28, "Input"],
Cell[6002, 211, 558, 13, 39, "Message"]
}, Open  ]],
Cell[6575, 227, 204, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[6804, 235, 147, 3, 28, "Input"],
Cell[6954, 240, 379, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7370, 257, 166, 4, 28, "Input"],
Cell[7539, 263, 250, 11, 47, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[7838, 280, 280, 4, 34, "Section"],
Cell[CellGroupData[{
Cell[8143, 288, 110, 1, 44, "Subsection"],
Cell[CellGroupData[{
Cell[8278, 293, 162, 3, 28, "Input"],
Cell[8443, 298, 539, 23, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9019, 326, 338, 8, 28, "Input"],
Cell[9360, 336, 848, 24, 92, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[10257, 366, 109, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[10391, 371, 443, 12, 28, "Input"],
Cell[10837, 385, 872, 24, 92, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[11758, 415, 117, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[11900, 420, 108, 2, 28, "Input"],
Cell[12011, 424, 579, 9, 94, "Print",
 CellTags->"Info3630408952-7254327"]
}, Closed]],
Cell[12605, 436, 105, 1, 27, "Text"],
Cell[CellGroupData[{
Cell[12735, 441, 534, 13, 28, "Input"],
Cell[13272, 456, 991, 28, 108, "Output"]
}, Open  ]],
Cell[14278, 487, 107, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[14410, 492, 608, 15, 28, "Input"],
Cell[15021, 509, 1039, 29, 108, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[16121, 545, 143, 2, 34, "Section"],
Cell[16267, 549, 171, 2, 30, "Text"],
Cell[16441, 553, 399, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[16865, 567, 123, 2, 28, "Input"],
Cell[16991, 571, 1537, 47, 60, "Output"]
}, Open  ]],
Cell[18543, 621, 127, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[18695, 626, 159, 3, 28, "Input"],
Cell[18857, 631, 98, 2, 28, "Output"]
}, Open  ]],
Cell[18970, 636, 103, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[19098, 641, 575, 14, 28, "Input"],
Cell[19676, 657, 944, 17, 39, "Message"],
Cell[20623, 676, 854, 15, 24, "Message"],
Cell[21480, 693, 903, 16, 26, "Message"],
Cell[22386, 711, 27155, 456, 238, "Output"]
}, Open  ]],
Cell[49556, 1170, 224, 5, 30, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[49829, 1181, 95, 1, 54, "Chapter"],
Cell[49927, 1184, 214, 4, 30, "Text"],
Cell[50144, 1190, 183, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[50352, 1198, 225, 3, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[50602, 1205, 124, 2, 34, "Section"],
Cell[50729, 1209, 186, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[50940, 1215, 211, 5, 32, "Input"],
Cell[51154, 1222, 245, 5, 70, "Output"]
}, Open  ]],
Cell[51414, 1230, 229, 4, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[51680, 1239, 132, 2, 34, "Section"],
Cell[51815, 1243, 120, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[51960, 1248, 280, 6, 28, "Input"],
Cell[52243, 1256, 237, 5, 70, "Output"]
}, Open  ]],
Cell[52495, 1264, 169, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[52689, 1270, 302, 5, 28, "Input"],
Cell[52994, 1277, 261, 5, 70, "Output"]
}, Open  ]],
Cell[53270, 1285, 145, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[53440, 1291, 301, 5, 28, "Input"],
Cell[53744, 1298, 261, 5, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[54054, 1309, 134, 2, 34, "Section"],
Cell[CellGroupData[{
Cell[54213, 1315, 307, 8, 28, "Input"],
Cell[54523, 1325, 259, 9, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54819, 1339, 307, 8, 28, "Input"],
Cell[55129, 1349, 259, 9, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55425, 1363, 307, 8, 28, "Input"],
Cell[55735, 1373, 259, 9, 48, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[56055, 1389, 227, 3, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[56307, 1396, 192, 3, 34, "Section"],
Cell[56502, 1401, 191, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[56718, 1409, 161, 3, 28, "Input"],
Cell[56882, 1414, 162, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57081, 1424, 183, 4, 28, "Input"],
Cell[57267, 1430, 1016, 31, 124, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[58332, 1467, 141, 1, 34, "Section"],
Cell[CellGroupData[{
Cell[58498, 1472, 430, 9, 28, "Input"],
Cell[58931, 1483, 652, 20, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59620, 1508, 354, 8, 28, "Input"],
Cell[59977, 1518, 9665, 169, 230, "Output"]
}, Open  ]],
Cell[69657, 1690, 134, 1, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[69828, 1696, 178, 2, 34, "Section"],
Cell[CellGroupData[{
Cell[70031, 1702, 1061, 26, 131, "Input"],
Cell[71095, 1730, 2173, 73, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73305, 1808, 1014, 26, 46, "Input"],
Cell[74322, 1836, 36501, 616, 230, "Output"]
}, Open  ]],
Cell[110838, 2455, 174, 4, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[111049, 2464, 287, 3, 34, "Section"],
Cell[CellGroupData[{
Cell[111361, 2471, 1521, 39, 131, "Input"],
Cell[112885, 2512, 1768, 57, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114690, 2574, 1114, 27, 46, "Input"],
Cell[115807, 2603, 27910, 474, 239, "Output"]
}, Open  ]],
Cell[143732, 3080, 282, 5, 49, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[144063, 3091, 261, 3, 46, "Subchapter"],
Cell[144327, 3096, 311, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[144663, 3106, 1016, 22, 97, "Input"],
Cell[145682, 3130, 906, 15, 24, "Message"],
Cell[146591, 3147, 953, 16, 26, "Message"],
Cell[147547, 3165, 27117, 454, 238, "Output"]
}, Open  ]],
Cell[174679, 3622, 250, 5, 30, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[174978, 3633, 146, 2, 54, "Chapter"],
Cell[175127, 3637, 259, 5, 30, "Text"],
Cell[175389, 3644, 206, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[175620, 3652, 225, 3, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[175870, 3659, 124, 2, 34, "Section"],
Cell[175997, 3663, 186, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[176208, 3669, 232, 4, 28, "Input"],
Cell[176443, 3675, 293, 5, 28, "Output"]
}, Open  ]],
Cell[176751, 3683, 186, 2, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[176974, 3690, 186, 3, 34, "Section"],
Cell[177163, 3695, 168, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[177356, 3701, 328, 6, 28, "Input"],
Cell[177687, 3709, 281, 5, 48, "Output"]
}, Open  ]],
Cell[177983, 3717, 169, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[178177, 3723, 352, 6, 28, "Input"],
Cell[178532, 3731, 281, 5, 48, "Output"]
}, Open  ]],
Cell[178828, 3739, 145, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[178998, 3745, 351, 6, 28, "Input"],
Cell[179352, 3753, 281, 5, 48, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[179682, 3764, 181, 3, 34, "Section"],
Cell[CellGroupData[{
Cell[179888, 3771, 358, 9, 28, "Input"],
Cell[180249, 3782, 306, 10, 82, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[180616, 3799, 275, 3, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[180916, 3806, 192, 3, 34, "Section"],
Cell[181111, 3811, 191, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[181327, 3819, 161, 3, 28, "Input"],
Cell[181491, 3824, 190, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181718, 3835, 183, 4, 28, "Input"],
Cell[181904, 3841, 1038, 31, 158, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[182991, 3878, 203, 4, 34, "Section"],
Cell[CellGroupData[{
Cell[183219, 3886, 475, 9, 28, "Input"],
Cell[183697, 3897, 676, 20, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[184410, 3922, 354, 8, 28, "Input"],
Cell[184767, 3932, 16903, 288, 235, "Output"]
}, Open  ]],
Cell[201685, 4223, 343, 8, 49, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[202065, 4236, 178, 2, 34, "Section"],
Cell[CellGroupData[{
Cell[202268, 4242, 1083, 26, 131, "Input"],
Cell[203354, 4270, 2175, 73, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[205566, 4348, 1042, 27, 46, "Input"],
Cell[206611, 4377, 91182, 1513, 234, "Output"]
}, Open  ]],
Cell[297808, 5893, 334, 6, 49, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[298179, 5904, 287, 3, 34, "Section"],
Cell[CellGroupData[{
Cell[298491, 5911, 1545, 39, 131, "Input"],
Cell[300039, 5952, 1767, 57, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301843, 6014, 1194, 29, 63, "Input"],
Cell[303040, 6045, 82737, 1373, 234, "Output"]
}, Open  ]],
Cell[385792, 7421, 251, 5, 30, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[386092, 7432, 448, 6, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[386565, 7442, 135, 1, 44, "Subsection"],
Cell[386703, 7445, 171, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[386899, 7453, 155, 3, 28, "Input"],
Cell[387057, 7458, 97, 2, 28, "Output"]
}, Open  ]],
Cell[387169, 7463, 259, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[387453, 7472, 214, 5, 28, "Input"],
Cell[387670, 7479, 860, 26, 102, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[388579, 7511, 132, 1, 36, "Subsection"],
Cell[388714, 7514, 176, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[388915, 7522, 183, 4, 28, "Input"],
Cell[389101, 7528, 91, 2, 48, "Output"]
}, Open  ]],
Cell[389207, 7533, 286, 7, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[389530, 7545, 124, 1, 36, "Subsection"],
Cell[389657, 7548, 227, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[389909, 7557, 278, 7, 28, "Input"],
Cell[390190, 7566, 255, 9, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[390506, 7582, 310, 4, 46, "Subchapter"],
Cell[390819, 7588, 393, 7, 30, "Text"],
Cell[CellGroupData[{
Cell[391237, 7599, 1067, 22, 97, "Input"],
Cell[392307, 7623, 932, 16, 24, "Message"],
Cell[393242, 7641, 983, 17, 26, "Message"],
Cell[394228, 7660, 26925, 452, 238, "Output"]
}, Open  ]],
Cell[421168, 8115, 312, 6, 30, "Text"],
Cell[421483, 8123, 350, 6, 68, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[421882, 8135, 181, 2, 54, "Chapter"],
Cell[422066, 8139, 298, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[422389, 8149, 225, 3, 62, "Subchapter"],
Cell[CellGroupData[{
Cell[422639, 8156, 186, 3, 34, "Section"],
Cell[422828, 8161, 393, 6, 30, "Text"],
Cell[423224, 8169, 405, 9, 28, "Input"],
Cell[423632, 8180, 333, 6, 30, "Text"],
Cell[CellGroupData[{
Cell[423990, 8190, 159, 3, 28, "Input"],
Cell[424152, 8195, 98, 2, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[424299, 8203, 240, 4, 34, "Section"],
Cell[424542, 8209, 445, 10, 53, "Text"],
Cell[CellGroupData[{
Cell[425012, 8223, 226, 5, 28, "Input"],
Cell[425241, 8230, 121, 3, 33, "Output"]
}, Open  ]],
Cell[425377, 8236, 196, 4, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[425610, 8245, 286, 4, 34, "Section"],
Cell[425899, 8251, 210, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[426134, 8259, 366, 8, 63, "Input"],
Cell[426503, 8269, 127, 4, 52, "Output"],
Cell[426633, 8275, 129, 4, 52, "Output"],
Cell[426765, 8281, 127, 4, 52, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[426941, 8291, 237, 4, 34, "Section"],
Cell[427181, 8297, 222, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[427428, 8306, 369, 10, 28, "Input"],
Cell[427800, 8318, 376, 11, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[428213, 8334, 418, 11, 28, "Input"],
Cell[428634, 8347, 378, 11, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[429049, 8363, 416, 11, 28, "Input"],
Cell[429468, 8376, 375, 11, 52, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[429904, 8394, 331, 4, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[430260, 8402, 192, 3, 34, "Section"],
Cell[430455, 8407, 191, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[430671, 8415, 161, 3, 28, "Input"],
Cell[430835, 8420, 214, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[431086, 8431, 183, 4, 28, "Input"],
Cell[431272, 8437, 1065, 32, 158, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[432386, 8475, 257, 5, 34, "Section"],
Cell[CellGroupData[{
Cell[432668, 8484, 521, 11, 28, "Input"],
Cell[433192, 8497, 722, 21, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[433951, 8523, 399, 10, 28, "Input"],
Cell[434353, 8535, 45833, 763, 242, "Output"]
}, Open  ]],
Cell[480201, 9301, 241, 3, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[480479, 9309, 178, 2, 34, "Section"],
Cell[CellGroupData[{
Cell[480682, 9315, 1124, 27, 131, "Input"],
Cell[481809, 9344, 2273, 74, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[484119, 9423, 1078, 27, 46, "Input"],
Cell[485200, 9452, 176827, 2918, 237, "Output"]
}, Open  ]],
Cell[662042, 12373, 274, 6, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[662353, 12384, 287, 3, 34, "Section"],
Cell[CellGroupData[{
Cell[662665, 12391, 1584, 40, 131, "Input"],
Cell[664252, 12433, 1847, 58, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[666136, 12496, 1232, 29, 63, "Input"],
Cell[667371, 12527, 114272, 1890, 237, "Output"]
}, Open  ]],
Cell[781658, 14420, 386, 6, 49, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[782093, 14432, 355, 4, 46, "Subchapter"],
Cell[CellGroupData[{
Cell[782473, 14440, 1109, 23, 97, "Input"],
Cell[783585, 14465, 977, 16, 24, "Message"],
Cell[784565, 14483, 1026, 17, 26, "Message"],
Cell[785594, 14502, 27383, 458, 238, "Output"]
}, Open  ]],
Cell[812992, 14963, 328, 6, 30, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[813369, 14975, 343, 4, 54, "Chapter"],
Cell[813715, 14981, 268, 5, 49, "Text"],
Cell[813986, 14988, 180, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[814191, 14996, 1517, 32, 148, "Input"],
Cell[815711, 15030, 1051, 17, 24, "Message"],
Cell[816765, 15049, 1100, 18, 26, "Message"],
Cell[817868, 15069, 27556, 460, 244, "Output"]
}, Open  ]],
Cell[845439, 15532, 124, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[845588, 15537, 1404, 29, 148, "Input"],
Cell[846995, 15568, 1051, 17, 24, "Message"],
Cell[848049, 15587, 1102, 18, 26, "Message"],
Cell[849154, 15607, 27227, 454, 244, "Output"]
}, Open  ]],
Cell[876396, 16064, 166, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[876587, 16071, 1478, 30, 148, "Input"],
Cell[878068, 16103, 1079, 18, 24, "Message"],
Cell[879150, 16123, 1128, 19, 26, "Message"],
Cell[880281, 16144, 27035, 452, 278, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
